@@ -43,7 +43,7 @@ void Controller::DoStart() {
 	SharedObject<LedMC> leds;
 	leds->setWeights(~FaceLEDMask,0);
 	leds->setWeights(FaceLEDMask,.75);
-	display=motman->addMotion(leds,isControlling?MotionManager::kEmergencyPriority:MotionManager::kIgnoredPriority);
+	display=motman->addPersistentMotion(leds,isControlling?MotionManager::kEmergencyPriority:MotionManager::kIgnoredPriority);
 	reset();
 }
 
@@ -58,7 +58,7 @@ void Controller::DoStop() {
 	sndman->ReleaseFile(config->controller.prev_snd);
 	sndman->ReleaseFile(config->controller.read_snd);
 	sndman->ReleaseFile(config->controller.cancel_snd);
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	reset();
 	gui_comm->printf("goodbye\n");
 	wireless->setDaemon(gui_comm,false);
@@ -452,8 +452,8 @@ bool Controller::chkCmdStack() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.36 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.40 $
  * $State: Exp $
- * $Date: 2004/03/01 21:16:48 $
+ * $Date: 2004/10/17 01:16:10 $
  */
