@@ -25,10 +25,11 @@
  *	- '<tt>!cancel</tt>' - calls ControlBase::doCancel() of the current control
  *	- '<tt>!msg </tt><i>text</i>' - sends <i>text</i> out as a TextMsgEvent; also note that any text entered on the console port while a GUI is also connected will also be sent as a TextMsgEvent, without needing the !input.
  *  - '<tt>!root </tt><i>text</i>' - calls ControlBase::takeInput(<i>text</i>) on the root control
- *  - '<tt>!hello</tt>' - responds with '<tt>hello\n</tt><i>count</i>' where <i>count</i> is the number of times '<tt>!hello</tt>' has been sent.  Good for detecting first connection after boot vs. a reconnect.
+ *  - '<tt>!hello</tt>' - responds with '<tt>hello\\n</tt><i>count</i>\\n' where <i>count</i> is the number of times '<tt>!hello</tt>' has been sent.  Good for detecting first connection after boot vs. a reconnect.
  *	- '<tt>!hilight</tt> [<i>n1</i> [<i>n2</i> [...]]]' - hilights zero, one, or more items in the menu
  *	- '<tt>!input </tt><i>text</i>' - calls ControlBase::takeInput(text) on the currently hilighted control(s)
- *	- any text not beginning with '!' - sent to ControlBase::takeInput() of the current control
+ *  - '<tt>!set </tt><i>section</i><tt>.</tt><i>key</i><tt>=</tt><i>value</i>' - will be sent to Config::setValue(<i>section</i>,<i>key</i>,<i>value</i>)
+ *	- any text not beginning with '<tt>!</tt>' - sent to ControlBase::takeInput() of the current control
  *
  *  In return, to send the menus to the GUI, the following messages are sent: (newlines are required where shown)
  *  - '<tt>push</tt>' - signals a submenu has been activated
@@ -210,10 +211,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.28 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.29 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/03/24 05:35:00 $
  */
 
 #endif
