@@ -123,12 +123,12 @@ public:
 	virtual ControlBase& setDescription(const std::string d) { description=d; return *this; } //!< sets the description of the control
 	virtual std::string getDescription() const { return description; } //!< returns a short description of what the control does
 
-	const std::vector<ControlBase*>& getSlots() const { return options; } //!< returns the vector of sub-controls
-	std::string getSlotName(unsigned int i) const; //!< returns the string that will appear in slot @a i
-	unsigned int slotsSize() const { return options.size(); } //!< returns the number of options available
-	void setSlot(unsigned int i,ControlBase* o); //!< sets @a i'th element of #options to @a o
-	void pushSlot(ControlBase* o); //!< sets next unused element of #options to @a o
-	void clearSlots(); //!< deletes each slot item and clears the slots
+	virtual const std::vector<ControlBase*>& getSlots() const { return options; } //!< returns the vector of sub-controls
+	virtual std::string getSlotName(unsigned int i) const; //!< returns the string that will appear in slot @a i
+	virtual unsigned int slotsSize() const { return options.size(); } //!< returns the number of options available
+	virtual void setSlot(unsigned int i,ControlBase* o); //!< sets @a i'th element of #options to @a o
+	virtual void pushSlot(ControlBase* o); //!< sets next unused element of #options to @a o
+	virtual void clearSlots(); //!< deletes each slot item and clears the slots
 
 	virtual const std::vector<unsigned int>& getHilights() const { return hilights; } //!< returns a vector of the indicies of hilighted slots
 	virtual void setHilights(const std::vector<unsigned int>& hi); //!< sets the hilighted slots
@@ -168,9 +168,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2004/02/18 21:11:25 $
+ * $Date: 2004/10/07 22:15:37 $
  */
 #endif
