@@ -11,6 +11,7 @@ class EventLogger : public ControlBase, public EventListener {
 public:
 	//!constructor
 	EventLogger();
+	virtual ~EventLogger() { clearSlots(); }
 
 	//!opens a custom (embedded) menu to toggle individual EGIDs
 	virtual ControlBase* doSelect();
@@ -21,6 +22,8 @@ public:
 	virtual void processEvent(const EventBase& event);
 
 protected:
+	virtual void clearSlots();
+
 	//!sets the status char of slot @a i to @a c
 	void setStatus(unsigned int i, char c);
 
@@ -42,10 +45,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.5 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:10 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.6 $
+ * $State: Exp $
+ * $Date: 2004/10/07 22:15:20 $
  */
 
 #endif
