@@ -26,7 +26,7 @@ public:
 
 	virtual void DoStop() {
 		isWarning=false;
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		BehaviorBase::DoStop();
 	}
 
@@ -66,10 +66,10 @@ protected:
  * @author ejt (object), alokl (core function)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
- * $State: Rel $
- * $Date: 2003/09/26 03:28:38 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
+ * $State: Exp $
+ * $Date: 2004/10/07 19:07:04 $
  */
 
 #endif
