@@ -1,5 +1,7 @@
 #include "HelpControl.h"
 
+//#define HelpControl_HTML_
+
 ControlBase * HelpControl::activate(MotionManager::MC_ID disp_id, Socket * gui) {
 	char * fmt="  * ";
 	if(config->main.use_VT100) {
@@ -33,7 +35,9 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
 	unsigned int numlen=1;
 	if(slots.size()>1)
 		numlen=(int)(log(slots.size()-1)/log(10))+1;
-	//sout->printf("<ol>\n");
+#ifdef HelpControl_HTML_
+	sout->printf("<ol>\n");
+#endif
 	for(unsigned int i=0; i<slots.size(); i++) {
 		if(slots[i]==NULL)
 			continue;
@@ -47,11 +51,14 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
 			len=desc.size();
 		else
 			while(len>0 && !isspace(desc[len-1])) len--;
+#ifdef HelpControl_HTML_
+		fmt="%s<li><!--%*d--><code><b>%s</b>: %s";
+#else
 		if(config->main.use_VT100)
 			fmt="\33[1m%s%*d. %s\33[0m: %s\n";
 		else
 			fmt="%s%*d. %s: %s\n";
-		//fmt="%s<li><!--%*d--><code><b>%s</b>: %s";
+#endif
 		sout->printf(fmt,prefix.c_str(),numlen,i,nm.c_str(),desc.substr(0,len).c_str());
 		while(len<desc.size() && isspace(desc[len])) len++;
 		desc=desc.substr(len);
@@ -68,15 +75,22 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
 				if(len>desc.size())
 					len=desc.size();
 			}
-			//sout->printf("\n%s",desc.substr(0,len).c_str());
+#ifdef HelpControl_HTML_
+			sout->printf("\n%s",desc.substr(0,len).c_str());
+#else
 			sout->printf("%s%s\n",std::string(prefix.size(),' ').c_str(),desc.substr(0,len).c_str());
+#endif
 			while(len<desc.size() && isspace(desc[len])) len++;
 			desc=desc.substr(len);
 		}
-		//sout->printf("</code></li>\n");
+#ifdef HelpControl_HTML_
+		sout->printf("</code></li>\n");
+#endif
 		report(slots[i],pre,depth_remain-1);
 	}
-	//sout->printf("</ol>\n");
+#ifdef HelpControl_HTML_
+	sout->printf("</ol>\n");
+#endif
 }
 
 /*! @file
@@ -84,9 +98,9 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/01/21 20:18:49 $
+ * $Date: 2004/07/14 00:50:26 $
  */
 
