@@ -36,7 +36,7 @@ class LoadPostureControl : public FileBrowserControl, public EventListener {
 	}
 	
 	virtual void deactivate() {
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 	}
 
 protected:
@@ -46,7 +46,7 @@ protected:
 		SharedObject<PostureMC> post;
 		post->LoadFile(file.c_str());
 		MMAccessor<EmergencyStopMC>(estopid)->setActive(false);
-		MotionManager::MC_ID id=motman->addMotion(post,MotionManager::kEmergencyPriority+1,true);
+		MotionManager::MC_ID id=motman->addPrunableMotion(post,MotionManager::kEmergencyPriority+1);
 		erouter->addListener(this,EventBase::motmanEGID,id,EventBase::deactivateETID);
 		return this;
 	}
@@ -60,10 +60,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.10 $
- * $State: Rel $
- * $Date: 2003/07/26 01:48:03 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.13 $
+ * $State: Exp $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
