@@ -18,12 +18,8 @@ class SaveWalkControl : public StringInputControl {
 
 	virtual ControlBase * takeInput(const std::string& msg) {
 		if(msg.size()>0) {
-			std::string filename;
-			if(msg[0]=='/')
-				filename=msg;
-			else
-				filename=config->motion.root+"/"+msg;
-			MotionManager::MC_ID id = thewalk==NULL?walk_id:thewalk->getID();
+			std::string filename=config->motion.makePath(msg);
+			MotionManager::MC_ID id = (thewalk==NULL ? walk_id : thewalk->getID() );
 			WalkMC* walk=thewalk;
 			if(id!=MotionManager::invalid_MC_ID)
 				walk = (WalkMC*)motman->checkoutMotion(id);
@@ -51,9 +47,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/10 20:10:27 $
+ * $Date: 2004/03/26 00:28:41 $
  */
 #endif
