@@ -70,7 +70,7 @@ ControlBase* SensorObserverControl::doSelect() {
 		if(numListeners>0)
 			erouter->addListener(this,EventBase::sensorEGID,0);
 		else
-			erouter->forgetListener(this);
+			erouter->removeListener(this);
 	}
 	if(ans==this)
 		refresh();
@@ -132,8 +132,8 @@ void SensorObserverControl::checkLogFile() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2003/12/23 06:33:41 $
+ * $Date: 2004/10/07 19:07:04 $
  */
