@@ -26,7 +26,10 @@ public:
 	}	
 	
 	//! returns last call to takeInput()
-	virtual std::string getLastInput() { return lastInput; }
+	virtual const std::string& getLastInput() { return lastInput; }
+
+	//! clears the last input (i.e. so you can easily tell later if new input is entered)
+	virtual void clearLastInput() { takeInput(""); }
 
 	//! sets the prompt to give to the user
 	virtual void setPrompt(const std::string& prompt) { userPrompt=prompt; }
@@ -41,10 +44,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:11 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/03/23 00:55:01 $
  */
 
 #endif
