@@ -6,7 +6,10 @@
 #include "Shared/ReferenceCounter.h"
 
 //! a simple control for turning things on and off
-/*! Can also be used for radio buttons - select one of a group */
+/*! Can also be used for radio buttons - select one of a group
+ *
+ *  By using the #externalStore (setStore()/getStore()), you can use
+ *  this instead of a ValueEditControl<bool> */
 class ToggleControl : public NullControl {
 public:
 	//! a little class for managing the currently active ToggleControl to allow radio buttons
@@ -43,9 +46,9 @@ public:
 
 	//!@name Constructors
 	//!
-	ToggleControl() : NullControl("[ ] "), rg(NULL) {}
-	ToggleControl(const std::string& n, RadioGroup * rad=NULL) : NullControl("[ ] "+n), rg(NULL) { setRadioGroup(rad); }
-	ToggleControl(const std::string& n, const std::string& d, RadioGroup * rad=NULL) : NullControl("[ ] "+n,d), rg(NULL) { setRadioGroup(rad); }
+	ToggleControl() : NullControl("[ ] "), rg(NULL), externalStore(NULL) {}
+	ToggleControl(const std::string& n, RadioGroup * rad=NULL) : NullControl("[ ] "+n), rg(NULL), externalStore(NULL) { setRadioGroup(rad); }
+	ToggleControl(const std::string& n, const std::string& d, RadioGroup * rad=NULL) : NullControl("[ ] "+n,d), rg(NULL), externalStore(NULL) { setRadioGroup(rad); }
 	//@}
 	~ToggleControl() { setRadioGroup(NULL); } //!< destructor
 
@@ -92,6 +95,8 @@ public:
 			}
 		}
 		name[1]=c;
+		if(externalStore!=NULL)
+			*externalStore=getStatus();
 	}
 
 	//! returns true if there's a non-space as the status
@@ -118,8 +123,13 @@ public:
 	//! returns the current RadioGroup
 	virtual RadioGroup * getRadioGroup() const { return rg; }
 
+	virtual void setStore(bool * s) { externalStore=s; *s=getStatus(); }  //!< sets #externalStore (and updates its current setting)
+	virtual bool * getStore() const { return externalStore; } //!< returns #externalStore
+
 protected:
 	RadioGroup * rg; //!< pointer to an optional radio group to allow one-of-many selections
+	
+	bool * externalStore; //!< an external bit which should be kept in sync with current setting
 
 private:
 	ToggleControl(const ToggleControl& ); //!< don't call
@@ -131,10 +141,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:56 $
+ * $Date: 2004/03/23 00:55:01 $
  */
 
 #endif
