@@ -35,7 +35,7 @@ class ValueEditControl : public StringInputControl, public EventListener {
 	//!reads in current value from target
 	virtual ControlBase * activate(MotionManager::MC_ID display, Socket * gui) {
 		cur=*target;
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		return StringInputControl::activate(display,gui);
 	}
 	//! will increment/decrement the current and then assign it to the target when head buttons pressed
@@ -166,10 +166,10 @@ class ValueEditControl : public StringInputControl, public EventListener {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/01/19 20:34:51 $
+ * $Date: 2004/10/07 19:07:04 $
  */
 
 #endif
