@@ -27,7 +27,7 @@ public:
 		//now do your code:
 		
 		// creates a PostureMC class to move the joint(s) and adds it to global MotionManager
-		pose_id=motman->addMotion(SharedObject<PostureMC>(),false);
+		pose_id=motman->addPersistentMotion(SharedObject<PostureMC>());
 		// subscribe to sensor updated events through the global EventRouter
 		erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
 	}
@@ -35,7 +35,7 @@ public:
 	virtual void DoStop() {
 		//do your code first:
 		motman->removeMotion(pose_id);  // removes your posture controller
-		erouter->forgetListener(this); // stops getting events (and timers, if we had any)
+		erouter->removeListener(this); // stops getting events (and timers, if we had any)
 
 		//but don't forget to call superclass at the end:
 		BehaviorBase::DoStop();
@@ -70,7 +70,7 @@ public:
 				//only really works on the ERS-210 or ERS-7 models - the others don't have a proper pressure sensor
 				//(the 220's antenna-thing is close, but doesn't give a continuous range)
 				std::cout << "Unknown model" << std::endl;
-				erouter->forgetListener(this); // stops getting events (and timers, if we had any)
+				erouter->removeListener(this); // stops getting events (and timers, if we had any)
 				return;
 			}
 			
@@ -116,10 +116,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/02/06 04:06:50 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
