@@ -26,7 +26,7 @@ public:
 	}
 	//! Stops listening for events
 	virtual void DoStop() {
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		BehaviorBase::DoStop();
 	}
 	//! Run appropriate motion script if the robot falls over
@@ -53,7 +53,7 @@ public:
 			else
 				gu=config->motion.makePath("gu_front.mot");
 			SharedObject< MotionSequenceMC<MotionSequence::SizeMedium> > getup(gu.c_str());
-			MotionManager::MC_ID id=motman->addMotion(getup,MotionManager::kHighPriority);
+			MotionManager::MC_ID id=motman->addPrunableMotion(getup,MotionManager::kHighPriority);
 			erouter->addListener(this,EventBase::motmanEGID,id,EventBase::deactivateETID);
 			waiting=true;
 		}
@@ -74,10 +74,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:22 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.12 $
+ * $State: Exp $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
