@@ -12,6 +12,7 @@
 #include "Motion/LedMC.h"
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
+#include "Shared/ERS7Info.h"
 #include "Motion/MMAccessor.h"
 
 //! A background behavior which will monitor the power level and flip the ears when appropriate on a 210, or blink the headlight if a 220
@@ -43,7 +44,7 @@ public:
 	virtual void DoStop() {
 		if(pose!=NULL)
 			stopWarning();
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		BehaviorBase::DoStop();
 	}
 	//! Adds a BatteryMonitorMC to motman if power goes low
@@ -103,11 +104,11 @@ protected:
 	//! adds a pose and a timer to get the ears flipping
 	void startWarning() {
 		serr->printf("LOW BATTERY\n");
-		pose_id=motman->addMotion(SharedObject<PostureMC>(),MotionManager::kEmergencyPriority+1,false);
+		pose_id=motman->addPersistentMotion(SharedObject<PostureMC>(),MotionManager::kEmergencyPriority+1);
 		pose=(PostureMC*)motman->peekMotion(pose_id);
 		SharedObject<LedMC> led;
 		led->displayPercent(state->sensors[PowerRemainOffset],LedEngine::major,LedEngine::major);
-		led_id=motman->addMotion(led,MotionManager::kEmergencyPriority+1);
+		led_id=motman->addPersistentMotion(led,MotionManager::kEmergencyPriority+1);
 		setFlipper(true);
 		erouter->addTimer(this,2,128,false);
 	}
@@ -137,6 +138,9 @@ protected:
 				pose->setOutputCmd(i,set?!state->outputs[i]:OutputCmd());
 		if(state->robotDesign & WorldState::ERS220Mask)
 			pose->setOutputCmd(ERS220Info::RetractableHeadLEDOffset,set?(state->outputs[ERS220Info::RetractableHeadLEDOffset]>.5?0:1):OutputCmd());
+		if(state->robotDesign & WorldState::ERS7Mask)
+			for(unsigned int i=ERS7Info::EarOffset; i<ERS7Info::EarOffset+ERS7Info::NumEarJoints; i++)
+				pose->setOutputCmd(i,set?!state->outputs[i]:OutputCmd());
 	}
 	PostureMC* pose; //!< if we are currently warning of low battery, holds a pose, NULL otherwise
 	MotionManager::MC_ID pose_id; //!< id of pose if we are currently warning, MotionManager::invalid_MC_ID otherwise
@@ -152,10 +156,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2004/01/09 04:41:05 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
