@@ -33,12 +33,12 @@ CameraBehavior::DoStart() {
 	}
 	initIndex();
 	sndman->LoadFile("camera.wav");
-	ledID=motman->addMotion(SharedObject<LedMC>());
+	ledID=motman->addPersistentMotion(SharedObject<LedMC>());
 	erouter->addListener(this,camera_click);
 }
 
 void CameraBehavior::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	sndman->ReleaseFile("camera.wav");
 	motman->removeMotion(ledID);
 	BehaviorBase::DoStop();
@@ -196,9 +196,9 @@ CameraBehavior::initIndex() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:27 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
