@@ -12,13 +12,13 @@ inline double DtoR(double deg) { return (deg/180.0*M_PI); }
 
 void ChaseBallBehavior::DoStart() {
 	BehaviorBase::DoStart();
-	headpointer_id = motman->addMotion(SharedObject<HeadPointerMC>());
-	walker_id = motman->addMotion(SharedObject<WalkMC>());
+	headpointer_id = motman->addPersistentMotion(SharedObject<HeadPointerMC>());
+	walker_id = motman->addPersistentMotion(SharedObject<WalkMC>());
 	erouter->addListener(this,EventBase::visObjEGID,ProjectInterface::visPinkBallSID);
 }
 
 void ChaseBallBehavior::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	motman->removeMotion(headpointer_id);
 	motman->removeMotion(walker_id);
 	BehaviorBase::DoStop();
@@ -64,10 +64,10 @@ void ChaseBallBehavior::processEvent(const EventBase& event) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2003/12/09 17:33:14 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 
