@@ -30,7 +30,7 @@ public:
 	
 	static std::string getClassDescription() {
 		// This string will be shown by the HelpControl or by the tooltips of the Controller GUI
-		return "A little demo of blocking output before a crash (yes, this crashes the AIBO)";
+		return "A little demo of blocking output before a crash after output #33 (yes, this crashes the AIBO)";
 	}
 	
 };
@@ -40,10 +40,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.1 $
- * $State: Rel $
- * $Date: 2003/10/03 03:40:17 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.2 $
+ * $State: Exp $
+ * $Date: 2004/08/25 01:07:45 $
  */
 
 #endif
