@@ -43,7 +43,7 @@ public:
 		}
 
 		SharedObject<WalkMC> walk;
-		walkid=motman->addMotion(walk);
+		walkid=motman->addPersistentMotion(walk);
 		WalkNode * move=NULL;
 		start=addNode(turn=new WalkNode(0,0,0.5f,this));
 		turn->setName(getName()+"::turn");
@@ -66,7 +66,7 @@ public:
 	}
 
 	virtual void DoStop() {
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		StateNode::DoStop();
 	}
 
@@ -102,10 +102,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.16 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2004/01/19 20:34:56 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
