@@ -23,7 +23,7 @@ FollowHeadBehavior::~FollowHeadBehavior() {
 void FollowHeadBehavior::DoStart() {
 	BehaviorBase::DoStart();
 	//set up the shared motions
-	walker_id=motman->addMotion(SharedObject<WalkMC>());
+	walker_id=motman->addPersistentMotion(SharedObject<WalkMC>());
 	//register for events and timers
 	erouter->addListener(this,head_release);
 	erouter->addListener(this,head_lock);
@@ -34,7 +34,7 @@ void FollowHeadBehavior::DoStart() {
 
 void FollowHeadBehavior::DoStop() {
 	//remove timers and listeners
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	//remove motion commands, set them to invalid
 	motman->removeMotion(walker_id);
 	walker_id=MotionManager::invalid_MC_ID;
@@ -52,12 +52,12 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
 
 	} else if(e==head_release) {
 		cout << "release" << endl;
-		motman->addMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0));
+		motman->addPrunableMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0));
 		erouter->addListener(this,clock);
 
 	} else if(e==head_lock) {
 		cout << "lock" << endl;
-		motman->addMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,1));
+		motman->addPrunableMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,1));
 		for(unsigned int i=HeadOffset; i<HeadOffset+NumHeadJoints; i++)
 			motman->setOutput(NULL,i,state->outputs[i]); //doing this prevents the head from jerking back when you released it to where it was before you pressed the button
 		cout << state->outputs[HeadOffset+TiltOffset]/M_PI*180 << ' ' << state->outputs[HeadOffset+PanOffset]/M_PI*180 << ' ' << state->outputs[HeadOffset+RollOffset]/M_PI*180 << endl;
@@ -74,8 +74,8 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
  *
  * $Author: ejt $
  * $Name $
- * $Revision: 1.5 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/06 01:00:44 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
