@@ -5,14 +5,14 @@
 #include "Behaviors/BehaviorBase.h"
 #include "Motion/MotionManager.h"
 #include "Motion/MMAccessor.h"
-#include "Motion/HeadPointerMC.h"
+#include "Motion/OldHeadPointerMC.h"
 #include "Motion/PIDMC.h"
 #include <math.h>
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
 #include "Shared/ERS7Info.h"
 
-//! Tests the head leveling code of HeadPointerMC
+//! Tests the head leveling code of OldHeadPointerMC
 class HeadLevelBehavior : public BehaviorBase {
  public:
 	//! constructor
@@ -43,29 +43,29 @@ class HeadLevelBehavior : public BehaviorBase {
 	virtual void DoStart() {
 		BehaviorBase::DoStart();
 		head->setJoints(state->outputs[HeadOffset+TiltOffset],state->outputs[HeadOffset+PanOffset],state->outputs[HeadOffset+RollOffset]);
-		head->setMode(HeadPointerMC::GravityRelative,true);
+		head->setMode(OldHeadPointerMC::GravityRelative,true);
 		head->noMaxSpeed(); // this is probably pretty safe - the whole point is to keep the head still
-		head_id=motman->addMotion(head);
+		head_id=motman->addPersistentMotion(head);
 		erouter->addListener(this,head_lock);
 		erouter->addListener(this,head_release);
 	}
 
 	virtual void DoStop() {
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		motman->removeMotion(head_id);
-		head->setMode(HeadPointerMC::BodyRelative,false);
+		head->setMode(OldHeadPointerMC::BodyRelative,false);
 		BehaviorBase::DoStop();
 	}
 
 	virtual void processEvent(const EventBase &event) {
 		if(event==head_lock) {
 			for(unsigned int i=HeadOffset; i<HeadOffset+NumHeadJoints; i++)
-				head->setJointValueFromMode((TPROffset_t)(i-HeadOffset),state->outputs[i],HeadPointerMC::BodyRelative);
+				head->setJointValueFromMode((TPROffset_t)(i-HeadOffset),state->outputs[i],OldHeadPointerMC::BodyRelative);
 			motman->removeMotion(pid_id);
 			pid_id=MotionManager::invalid_MC_ID;
 		} else if(event==head_release) {
-			pid_id=motman->addMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0),MotionManager::kHighPriority,false);
-			//motman->addMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0));
+			pid_id=motman->addPersistentMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0),MotionManager::kHighPriority);
+			//motman->addPersistentMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0));
 		} else
 			ASSERTRET(false,"received unasked for event "<<event.getName());
 	}
@@ -75,7 +75,7 @@ class HeadLevelBehavior : public BehaviorBase {
  protected:
 	EventBase head_release; //!< event mask for releasing head (chin button down)
 	EventBase head_lock;    //!< event mask for locking head (chin button up)
-	const SharedObject<HeadPointerMC> head; //!< might as well just hang on to the whole memory region and reuse it, we can peek for most of our stuff
+	const SharedObject<OldHeadPointerMC> head; //!< might as well just hang on to the whole memory region and reuse it, we can peek for most of our stuff
 	MotionManager::MC_ID head_id; //!< MCID of headpointer
 	MotionManager::MC_ID pid_id; //!< MCID of pid controller
 };
@@ -85,10 +85,10 @@ class HeadLevelBehavior : public BehaviorBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/01/19 07:55:27 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif 
