@@ -27,13 +27,13 @@ public:
 
 		// You could also change the priority level so that anytime
 		// a joint is not in use it goes limp (try kBackgroundPriority)
-		pidMCID=motman->addMotion(pidMC,MotionManager::kHighPriority,false);
+		pidMCID=motman->addPersistentMotion(pidMC,MotionManager::kHighPriority);
 		// the 'false' is to keep it from auto-pruning
 	}
 	virtual void DoStop() {
 		motman->removeMotion(pidMCID);
 		//this "one-shot" version of doing things will restore the PIDs
-		motman->addMotion(SharedObject<PIDMC>(1));
+		motman->addPrunableMotion(SharedObject<PIDMC>(1));
 		BehaviorBase::DoStop();
 	}
 	virtual std::string getName() const { return "RelaxBehavior"; }
@@ -49,8 +49,8 @@ protected:
  * @author ejt (Modifications)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:56 $
+ * $Date: 2004/10/17 01:16:10 $
  */
