@@ -27,13 +27,13 @@ public:
 	//! adds a headpointer and a walker, and a listens for vision events
 	virtual void DoStart() {
 		BehaviorBase::DoStart();
-		walker_id = motman->addMotion(SharedObject<WalkMC>());
+		walker_id = motman->addPersistentMotion(SharedObject<WalkMC>()); //the 'false' prevents autopruning
 		erouter->addListener(this,EventBase::visObjEGID);
 	}
 
 	//! removes motion commands and stops listening
 	virtual void DoStop() {
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		motman->removeMotion(walker_id);
 		BehaviorBase::DoStop();
 	}
@@ -60,10 +60,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2003/12/05 20:26:34 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
