@@ -18,7 +18,7 @@ public:
 		if(state->robotDesign & WorldState::ERS220Mask) {
 			SharedObject<PostureMC> pose;
 			pose->setOutputCmd(ERS220Info::RetractableHeadLEDOffset,true);
-			light_id=motman->addMotion(pose,false);
+			light_id=motman->addPersistentMotion(pose);
 		}
 	}
 
@@ -40,10 +40,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.2 $
- * $State: Rel $
- * $Date: 2003/09/02 20:58:49 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.3 $
+ * $State: Exp $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
