@@ -18,15 +18,21 @@ void WalkToTargetMachine::setup() {
 
 void WalkToTargetMachine::DoStart() {
 	StateNode::DoStart();
-	headpointer_id = motman->addMotion(SharedObject<HeadPointerMC>());
-	walker_id = motman->addMotion(SharedObject<WalkMC>());
+
+	headpointer_id = motman->addPersistentMotion(SharedObject<HeadPointerMC>());
+	walker_id = motman->addPersistentMotion(SharedObject<WalkMC>());
+
 	erouter->addListener(this,EventBase::visObjEGID,tracking);
 }
 
 void WalkToTargetMachine::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
+
 	motman->removeMotion(headpointer_id);
+	headpointer_id=MotionManager::invalid_MC_ID;
 	motman->removeMotion(walker_id);
+	walker_id=MotionManager::invalid_MC_ID;
+
 	StateNode::DoStop();
 }
 
@@ -76,9 +82,9 @@ void WalkToTargetMachine::processEvent(const EventBase& event) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2003/12/05 20:26:34 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
