@@ -78,7 +78,7 @@ class Aibo3DControllerBehavior : public BehaviorBase {
 		for(unsigned int i=0; i<NumPIDJoints; i++)
 			val[i]=state->outputs[i];
 		// Enable remote control stream
-		rcontrol_id = motman->addMotion(SharedObject<RemoteControllerMC>());
+		rcontrol_id = motman->addPersistentMotion(SharedObject<RemoteControllerMC>());
 		updateRC();
 		// Turn on wireless
 		cmdsock=wireless->socket(SocketNS::SOCK_STREAM, 2048, 2048);
@@ -130,10 +130,10 @@ int aibo3dcontrollercmd_callback(char *buf, int bytes) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:56 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif 
