@@ -18,7 +18,7 @@ void EStopControllerBehavior::DoStart() {
 
 void EStopControllerBehavior::DoStop() {
 	// Turn off timers
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	// Close socket; turn wireless off
   wireless->setDaemon(cmdsock,false);
 	wireless->close(cmdsock);
@@ -72,9 +72,9 @@ int EStopControllerBehavior::callback(char *buf, int bytes) {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/01/14 20:44:31 $
+ * $Date: 2004/10/07 19:07:04 $
  */
 
