@@ -1,6 +1,7 @@
 #include "HeadPointControllerBehavior.h"
 #include "Behaviors/Controller.h"
 #include "Motion/MMAccessor.h"
+#include "Motion/HeadPointerMC.h"
 
 HeadPointControllerBehavior* HeadPointControllerBehavior::theOne = NULL;
 
@@ -55,7 +56,7 @@ void HeadPointControllerBehavior::DoStart() {
 	// We listen to timers
 	erouter->addListener(this, EventBase::timerEGID);
 	// Enable head control
-	head_id = motman->addMotion(SharedObject<HeadPointerMC>());
+	head_id = motman->addPersistentMotion(SharedObject<HeadPointerMC>());
 	// Turn on wireless
 	theLastOne=theOne;
 	theOne=this;
@@ -71,7 +72,7 @@ void HeadPointControllerBehavior::DoStop() {
 	// Close the GUI
 	Controller::closeGUI("HeadPointGUI");
 	// Turn off timers
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	// Close socket; turn wireless off
 	wireless->setDaemon(cmdsock,false);
 	wireless->close(cmdsock);
@@ -123,9 +124,9 @@ int HeadPointControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/05 01:51:39 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
