@@ -33,7 +33,8 @@ public:
 	//! constructor
 	RawCamBehavior();
 
-	static const unsigned int WIRELESS_BUFFER_SIZE=200000; //!< 200000 bytes for use up to 416x320 + 2*208x160 (double res Y, full res UV on ERS-7)
+	static const unsigned int TCP_WIRELESS_BUFFER_SIZE=200000; //!< 200000 bytes for use up to 416x320 + 2*208x160 (double res Y, full res UV on ERS-7)
+	static const unsigned int UDP_WIRELESS_BUFFER_SIZE=64*1024; //!< 64KB is the max udp packet size
 
 	virtual void DoStart();
 
@@ -61,6 +62,7 @@ protected:
 	char * packet; //!< point to the current buffer being prepared to be sent
 	char * cur; //!< current location within that buffer
 	unsigned int avail; //!< the number of bytes remaining in the buffer
+	unsigned int max_buf; //!< the buffer size requested from Wireless when the socket was allocated
 
 private:
 	RawCamBehavior(const RawCamBehavior&); //!< don't call
@@ -72,10 +74,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:41 $
+ * $Date: 2004/09/28 22:12:30 $
  */
 
 #endif
