@@ -8,18 +8,31 @@
 #include "Vision/RLEGenerator.h"
 
 SegCamBehavior::SegCamBehavior()
-	: BehaviorBase(), visRLE(NULL), packet(NULL), cur(NULL), avail(0)
+	: BehaviorBase(), visRLE(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0)
 {
 }
 
 void
 SegCamBehavior::DoStart() {
 	BehaviorBase::DoStart();
-  visRLE=wireless->socket(SocketNS::SOCK_STREAM, 1024, WIRELESS_BUFFER_SIZE);
-  wireless->setDaemon(visRLE,true);
-  wireless->listen(visRLE,config->vision.rle_port);
+	
+	std::vector<std::string> args;
+	if(config->vision.rle_transport==0) {
+		max_buf=UDP_WIRELESS_BUFFER_SIZE;
+		visRLE=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
+		args.push_back("udp");
+	} else if(config->vision.rle_transport==1) {
+		max_buf=TCP_WIRELESS_BUFFER_SIZE;
+		visRLE=wireless->socket(SocketNS::SOCK_STREAM, 1024, max_buf);
+		wireless->setDaemon(visRLE,true);
+		args.push_back("tcp");
+	} else {
+		serr->printf("ERROR: Invalid Config::vision.rle_transport: %d\n",config->vision.rle_transport);
+		return;
+	}
+	wireless->listen(visRLE,config->vision.rle_port);
 
-	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","SegVisionGUI",config->vision.rle_port);
+	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","SegVisionGUI",config->vision.rle_port,args);
 
 	erouter->addListener(this,EventBase::visSegmentEGID,ProjectInterface::visSegmentSID);
 	erouter->addListener(this,EventBase::visRLEEGID,ProjectInterface::visRLESID);
@@ -27,12 +40,12 @@ SegCamBehavior::DoStart() {
 
 void
 SegCamBehavior::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	Controller::closeGUI("SegVisionGUI");
 
 	// this could be considered a bug in our wireless - if we don't setDaemon(...,false)
 	// it will try to listen again even though we explicitly closed the server socket...
-  wireless->setDaemon(visRLE,false);
+	wireless->setDaemon(visRLE,false);
 	wireless->close(visRLE->sock);
 	BehaviorBase::DoStop();
 }
@@ -58,7 +71,7 @@ SegCamBehavior::openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsig
 	if(packet!=NULL)
 		return false;
 
-	avail=WIRELESS_BUFFER_SIZE-1; //not sure why -1, but Alok had it, so i will too
+	avail=max_buf-1; //not sure why -1, but Alok had it, so i will too
 	ASSERT(cur==NULL,"cur non-NULL");
 	cur=NULL;
 	char * buf=packet=(char*)visRLE->getWriteBuffer(avail);
@@ -154,9 +167,9 @@ SegCamBehavior::closePacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/02/05 19:11:26 $
+ * $Date: 2004/10/07 19:07:05 $
  */
 
