@@ -7,7 +7,7 @@
 #include "Shared/Config.h"
 #include <stdio.h>
 
-//! simply launches the Watchable Memory GUI
+//! simply launches the Watchable Memory GUI, which should connect to the already-running WMMonitorBehavior
 class ViewWMVarsBehavior : public BehaviorBase {
 public:
 	//! constructor
@@ -29,19 +29,19 @@ public:
 	static std::string getClassDescription() {
 		char tmp[20];
 		sprintf(tmp,"%d",config->main.wmmonitor_port);
-		return std::string("Brings up the WatchableMemory GUI on port ")+tmp;
+		return std::string("Brings up the WatchableMemory GUI on port ")+tmp+std::string(" (connects to WMMonitorBehavior, this just launches the GUI)");
 	}
 };
 
 /*! @file
- * @brief Describes ViewWMVarsBehavior, simply launches the Watchable Memory GUI
+ * @brief Defines ViewWMVarsBehavior, simply launches the Watchable Memory GUI, which should connect to the already-running WMMonitorBehavior
  * @author ejt (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.1 $
- * $State: Rel $
- * $Date: 2003/10/10 00:47:52 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.2 $
+ * $State: Exp $
+ * $Date: 2004/04/16 20:17:22 $
  */
 
 #endif 
