@@ -26,15 +26,20 @@ WMMonitorBehavior::registerData(const std::string& s) {
           wmitem->toString());
   } else if (cmd[0]=='r') {
     WMregistry* wmreg=NULL;
-    if (var.length()==0) wmreg=&GlobalWM;
+    if (var.length()==0)
+			wmreg=&GlobalWM;
     else {
       WMitem<WMregistry>* wmitem=static_cast<WMitem<WMregistry> *> (find (var));
       if (wmitem!=NULL)
         wmreg=&wmitem->get_value();
+			else
+				serr->printf("WMMonitorBehavior: Could not find '%s'\n",var.c_str());
     }
-    if (wmreg!=NULL)
-      for (std::vector<WMentry*>::const_iterator it = wmreg->entries.begin();
-          it != wmreg->entries.end(); it++) {
+    if (wmreg==NULL)
+			serr->printf("WMMonitorBehavior: wmreg is NULL\n");
+		else {
+			//sout->printf("Reporting:\n");
+      for (std::vector<WMentry*>::const_iterator it = wmreg->entries.begin(); it != wmreg->entries.end(); it++) {
         WMentry* entry=*it;
         std::string sn(entry->item_name);
         WMregistry *temp=entry->registry;
@@ -42,8 +47,10 @@ WMMonitorBehavior::registerData(const std::string& s) {
           sn=temp->name + "." + sn;
           temp=temp->parent;
         }
+				//sout->printf("Reporting %s %s %s\n",entry->type_name.c_str(),sn.c_str(),entry->item->toString().c_str());
         report(entry->type_name, sn, entry->item->toString());
       }
+		}
   } else if (cmd[0]=='d') {    // set debug mode (blocking/nonblocking)
     // implement within this class
   }
@@ -98,9 +105,7 @@ void
 WMMonitorBehavior::report (const char* var_type, int var_type_length,
                            const char* var_name, int var_name_length,
                            const char* value, int value_length) {
-  char *buf=(char*)cmdsock->getWriteBuffer(5+ var_type_length+
-                                              var_name_length+
-                                              value_length);
+  char *buf=(char*)cmdsock->getWriteBuffer(5*sizeof(int)+var_type_length+var_name_length+value_length);
   if (buf) {
     encodeHeader(&buf, packet_wmclass);
     encode(&buf, var_type_length);
@@ -110,7 +115,8 @@ WMMonitorBehavior::report (const char* var_type, int var_type_length,
     encode(&buf, value_length);
     encode(&buf, value, value_length);
     cmdsock->write(5*sizeof(int)+var_type_length+var_name_length+value_length);
-  }
+  } else
+		serr->printf("WMMonitorBehavior: Failed to get write buffer\n");
 }
 
 int wmmonitorcmd_callback(char *buf, int bytes) {
@@ -140,8 +146,8 @@ int wmmonitorcmd_callback(char *buf, int bytes) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/01/19 20:35:31 $
+ * $Date: 2004/04/16 20:17:22 $
  */
