@@ -77,7 +77,7 @@ class WMMonitorBehavior : public BehaviorBase {
 
 	virtual void DoStop() {
 //		Controller::closeGUI(getGUIType());
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		// Close socket; turn wireless off
 		wireless->setDaemon(cmdsock,false); 
 		wireless->close(cmdsock);
@@ -106,7 +106,7 @@ class WMMonitorBehavior : public BehaviorBase {
 	}
 
 protected:
-	static const unsigned int packet_wmclass=12; //!< magic id number
+	static const unsigned int packet_wmclass=14; //!< magic id number, corresponds to Listener.java PACKET_WMCLASS
   //! writes packet type and timestamp
   inline static void encodeHeader(char **dst, unsigned int pformat) {
     encode(dst, pformat);
@@ -136,10 +136,10 @@ protected:
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/19 20:35:31 $
+ * $Date: 2004/10/07 19:07:05 $
  */
 
 #endif 
