@@ -87,7 +87,7 @@ void WalkControllerBehavior::DoStart() {
 	// We listen to timers
 	erouter->addListener(this, EventBase::timerEGID);
 	// Enable walker (the MC_ID can be accessed through the shared_walker later)
-	motman->addMotion(shared_walker);
+	motman->addPersistentMotion(shared_walker);
 	// Turn on wireless
 	theLastOne=theOne;
 	theOne=this;
@@ -103,7 +103,7 @@ void WalkControllerBehavior::DoStop() {
 	// Close the GUI
 	Controller::closeGUI("WalkGUI");
 	// Turn off timers
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	// Close socket; turn wireless off
 	wireless->setDaemon(cmdsock,false); 
 	wireless->close(cmdsock);
@@ -157,9 +157,9 @@ int WalkControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/01/19 19:43:51 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
