@@ -21,7 +21,7 @@ void WorldStateSerializerBehavior::DoStart() {
 }
 
 void WorldStateSerializerBehavior::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	BehaviorBase::DoStop(); // do this last
 }
 
@@ -53,8 +53,8 @@ void WorldStateSerializerBehavior::processEvent(const EventBase& /*e*/) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/01/24 21:28:50 $
+ * $Date: 2004/10/07 19:07:05 $
  */
