@@ -90,7 +90,7 @@ protected:
 		if(walkid==MotionManager::invalid_MC_ID) {
 			SharedObject<WalkMC> walk;
 			walk->setTargetVelocity(xvel,yvel,avel);
-			walkid=motman->addMotion(walk);
+			walkid=motman->addPersistentMotion(walk);
 			walkidIsMine=true;
 		} else {
 			MMAccessor<WalkMC> walk(walkid);
@@ -110,10 +110,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/10/29 22:36:20 $
+ * $Date: 2004/10/17 01:16:10 $
  */
 
 #endif
