@@ -18,6 +18,14 @@ void StateNode::addTransition(Transition* trans) {
 	trans->addSource(this);
 }
 
+StateNode* StateNode::addNode(StateNode* node) {
+  nodes.push_back(node);
+  node->AddReference();
+  if ( node->parent == NULL )
+    node->parent = this;
+  return node;
+}
+
 void StateNode::DoStart() {
 	BehaviorBase::DoStart();
 	if(!issetup) {
@@ -25,7 +33,7 @@ void StateNode::DoStart() {
 		issetup=true;
 	}
 	for(std::vector<Transition*>::iterator it=transitions.begin(); it!=transitions.end(); it++)
-		(*it)->DoStart();
+	  if ( !(*it)->isActive()  ) (*it)->DoStart();
 	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::activateETID,0,getName(),1);
 	if(parent!=NULL)
 		parent->transitionTo(this);
@@ -33,7 +41,6 @@ void StateNode::DoStart() {
 
 void StateNode::DoStop() {
 	for(std::vector<Transition*>::iterator it=transitions.begin(); it!=transitions.end(); it++) {
-		ASSERT((*it)->isActive(),"Inactive transition");
 		if((*it)->isActive())
 			(*it)->DoStop();
 	}
@@ -67,10 +74,10 @@ void StateNode::transitionFrom(StateNode*) {
  * @brief Describes StateNode, which is both a state machine controller as well as a node within a state machine itself
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.13 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2003/11/11 00:08:09 $
+ * $Date: 2004/10/04 22:57:56 $
  */
 
