@@ -28,8 +28,8 @@ public:
 	//!Returns the std::vector of transitions so you can modify them yourself if need be
 	std::vector<Transition*>& getTransitions() { return transitions; }
 
-	//!Adds a StateNode to #nodes so it can be automatically dereferenced later, returns what it's passed (for convenience), calls AddReference() on @a node
-	virtual StateNode* addNode(StateNode* node) { nodes.push_back(node); node->AddReference(); return node; }
+	//!Adds a StateNode to #nodes so it can be automatically dereferenced later, returns what it's passed (for convenience), calls AddReference() on @a node.  Also sets the node's parent to #this if it is null.
+	virtual StateNode* addNode(StateNode* node);
 
 	//!Returns the std::vector of nodes so you can modify them yourself if need be
 	std::vector<StateNode*>& getNodes() { return nodes; }
@@ -92,11 +92,11 @@ private:
  * @brief Describes StateNode, which is both a state machine controller as well as a node within a state machine itself
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2003/10/30 23:23:15 $
+ * $Date: 2004/10/04 22:57:56 $
  */
 
 #endif
