@@ -3,13 +3,13 @@
 #include "Wireless/Wireless.h"
 #include "SoundPlay/SoundManager.h"
 
-void Transition::activate() {
-	//serr->printf("%s activate() - enter %d\n",getName().c_str(),get_time());
+void Transition::fire() {
+	//serr->printf("%s fire() - enter %d\n",getName().c_str(),get_time());
 
 	AddReference(); //just in case a side effect of this transition is to dereference the transition, we don't want to be deleted while still transitioning
 
 	if(sound.size()!=0)
-		sndman->PlayFile(sound.c_str());
+		sndman->PlayFile(sound);
 
 	for(unsigned int i=0; i<srcs.size(); i++)
 		if(srcs[i]->isActive()) //It's usually a bad idea to call DoStop/DoStart when it's already stopped/started...
@@ -18,7 +18,7 @@ void Transition::activate() {
 		if(!dsts[i]->isActive())
 			dsts[i]->DoStart();
 
-	//serr->printf("%s activate() - leave %d\n",getName().c_str(),get_time());
+	//serr->printf("%s fire() - leave %d\n",getName().c_str(),get_time());
 	RemoveReference();
 }
 
@@ -26,10 +26,10 @@ void Transition::activate() {
  * @brief Implements Transition, represents a transition between StateNodes.
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2003/11/11 00:08:10 $
+ * $Date: 2004/10/08 00:08:34 $
  */
 
