@@ -3,6 +3,7 @@
 #define INCLUDED_Transition_h_
 
 #include "BehaviorBase.h"
+#include "Wireless/Socket.h"
 #include <vector>
 
 class StateNode;
@@ -12,7 +13,7 @@ class StateNode;
  *  conditions on the transitions.  Transitions are "smart" - they are
  *  behaviors in and of themselves and can listen for events and use
  *  the standard DoStart/DoStop interface.  Based on the events they
- *  receive, they can activate() themselves and cause a state
+ *  receive, they can fire() themselves and cause a state
  *  transition.
  *
  *  DoStart() will be called when this transition is 'active' - it
@@ -20,10 +21,10 @@ class StateNode;
  *  DoStop() is called.
  *  
  *  If the conditions are satisified for a transition, you should call
- *  activate() to do the appropriate notifications.
+ *  fire() to do the appropriate notifications.
  *
  *  Also note that a transition can have multiple sources and
- *  destinations.  See activate().
+ *  destinations.  See fire().
  *
  *  When setting up, the flow of additions follows the flow of
  *  control.  In other words, you add a transition to a source, and
@@ -51,7 +52,13 @@ public:
 	virtual ~Transition() {}
 
 	//!call this when the transition should be made, base class version simply calls StateNode::DoStop() on each active of #srcs and StateNode::DoStart() on each inactive of #dsts, but you can override.
-	virtual void activate();
+	virtual void fire();
+
+  //!deprecated: use #fire() instead
+  virtual void activate() {
+    serr->printf("Transition::activate() is deprecated.  Use Transition::fire() instead.\n");
+    fire();
+  }
 
 	virtual std::vector<StateNode*>& getSources() { return srcs; }  //!< returns a user-modifiable reference to the current source list
 	virtual const std::vector<StateNode*>& getSources() const { return srcs; } //!< returns a const reference to the current source list
@@ -78,11 +85,11 @@ protected:
  * @brief Describes Transition, represents a transition between StateNodes.
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/11/11 00:08:10 $
+ * $Date: 2004/10/04 22:59:57 $
  */
 
 #endif
