@@ -43,28 +43,28 @@ public:
 	virtual void DoStart() { Transition::DoStart(); erouter->addListener(this,poller); }
 
 	//!stops listening
-	virtual void DoStop() { erouter->forgetListener(this); Transition::DoStop(); }
+	virtual void DoStop() { erouter->removeListener(this); Transition::DoStop(); }
 
 	//!don't care about the event, just a pulse to check the values
 	virtual void processEvent(const EventBase&) {
 		switch(tst) {
 		case LT:
-			if(*mon<val) activate();
+			if(*mon<val) fire();
 			break;
 		case GT:
-			if(val<*mon) activate();
+			if(val<*mon) fire();
 			break;
 		case LTE:
-			if(!(val<*mon)) activate();
+			if(!(val<*mon)) fire();
 			break;
 		case GTE:
-			if(!(*mon<val)) activate();
+			if(!(*mon<val)) fire();
 			break;
 		case EQ:
-			if(*mon==val) activate();
+			if(*mon==val) fire();
 			break;
 		case NE:
-			if(!(*mon==val)) activate();
+			if(!(*mon==val)) fire();
 			break;
 		}
 	}
@@ -87,10 +87,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2003/11/11 00:08:18 $
+ * $Date: 2004/10/07 19:07:05 $
  */
 
 #endif
