@@ -20,9 +20,9 @@ public:
 	virtual void DoStart() { Transition::DoStart(); erouter->addListener(this,EventBase::visObjEGID,sid); }
 
 	//!called by StateNode when it becomes inactive - undo whatever you did in Enable()
-	virtual void DoStop() { erouter->forgetListener(this); Transition::DoStop(); }
+	virtual void DoStop() { erouter->removeListener(this); Transition::DoStop(); }
 
-	//!if the object is "close", calls activate()
+	//!if the object is "close", calls fire()
 	virtual void processEvent(const EventBase& e) {
 		const VisionObjectEvent* ve=dynamic_cast<const VisionObjectEvent*>(&e);
 		ASSERTRET(ve!=NULL,"Casting error");
@@ -37,8 +37,8 @@ public:
 			IRDistOffset=ERS220Info::IRDistOffset;
 		else if(state->robotDesign & WorldState::ERS7Mask)
 			IRDistOffset=ERS7Info::NearIRDistOffset;
-		if(x*x+y*y<0.02f && IRDistOffset!=-1U && state->sensors[IRDistOffset]<300)
-			activate();
+		if(x*x+y*y<0.02f && IRDistOffset!=-1U && state->sensors[IRDistOffset]<225)
+			fire();
 	}
 
 	virtual std::string getName() const { return "VisualTargetCloseTrans"; }
@@ -53,10 +53,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2003/12/23 06:33:42 $
+ * $Date: 2004/10/07 19:07:05 $
  */
 
 #endif
