@@ -26,13 +26,13 @@ public:
 	//!called by StateNode when it becomes inactive - undo whatever you did in Enable()
 	virtual void DoStop() {
 		//serr->printf("VisualTargetTrans::DoStop() - enter\n");
-		erouter->forgetListener(this);
+		erouter->removeListener(this);
 		count=0;
 		Transition::DoStop();
 		//serr->printf("VisualTargetTrans::DoStop() - leave\n");
 	}
 
-	//!if the object is "close", calls activate()
+	//!if the object is "close", calls fire()
 	virtual void processEvent(const EventBase& e) {
 		//serr->printf("VisualTargetTrans::processEvent() - enter %d\n",get_time());
 
@@ -41,7 +41,7 @@ public:
 		else
 			count++;
 		if(count>5)
-			activate();
+			fire();
 
 		//serr->printf("VisualTargetTrans::processEvent() - leave %d\n",get_time());
 	}
@@ -60,10 +60,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2003/12/08 00:21:02 $
+ * $Date: 2004/10/07 19:07:05 $
  */
 
 #endif
