@@ -1,30 +1,34 @@
 #include "EventBase.h"
 #include <stdio.h>
+#include <sstream>
 
 const char* const EventBase::EventGeneratorNames[numEGIDs] = {
-	"UnknownGen",
-	"AI",
-	"Audio",
-	"Button",
-	"EventRouter",
-	"EStop",
-	"Locomotion",
-	"MotionManager",
-	"Power",
-	"Sensor",
-	"StateMachine",
-	"TextMsg",
-	"Timer",
-	"VisionOFbkVector",
-	"VisionRawCamera",
-	"VisionInterleaver",
-	"VisionJPEGCompressor",
-	"VisionSegmenter",
-	"VisionRLEEncoder",
-	"VisionRegionConnector",
-	"VisionObjectDetector",
-	"WMVariable",
-	"WorldModel",
+	"unknownEGID",
+	"aiEGID",
+	"audioEGID",
+	"buttonEGID",
+	"erouterEGID",
+	"estopEGID",
+	"locomotionEGID",
+	"micOSndEGID",
+	"micRawEGID",
+	"micFFTEGID",
+	"motmanEGID",
+	"powerEGID",
+	"sensorEGID",
+	"stateMachineEGID",
+	"testmsgEGID",
+	"timerEGID",
+	"visOFbkEGID",
+	"visRawCameraEGID",
+	"visInterleaveEGID",
+	"visJPEGEGID",
+	"visSegmentEGID",
+	"visRLEEGID",
+	"visRegionEGID",
+	"visObjEGID",
+	"wmVarEGID",
+	"worldModelEGID",
 };
 
 
@@ -50,6 +54,29 @@ EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid
 	
 }
 
+std::string
+EventBase::getDescription(bool /*showTypeSpecific=true*/, unsigned int verbosity/*=0*/) const {
+	std::ostringstream logdata;
+	logdata << getName();
+	char hexstring[30];
+	snprintf(hexstring,sizeof(hexstring),"0x%x",getSourceID());
+	logdata << '\t' << hexstring;
+	switch(getTypeID()) {
+	case EventBase::activateETID:
+		logdata << "\tA"; break;
+	case EventBase::statusETID:
+		logdata << "\tS"; break;
+	case EventBase::deactivateETID:
+		logdata << "\tD"; break;
+	case EventBase::numETIDs:
+		logdata << "\tU"; break;  //UNKNOWN TYPE
+	}
+	if(verbosity>=1)
+		logdata << '\t' << getDuration() << '\t' << getTimeStamp();
+	if(verbosity>=2)
+		logdata << '\t' << getMagnitude();
+	return logdata.str();
+}
 
 unsigned int
 EventBase::getBinSize() const {
@@ -141,9 +168,9 @@ EventBase::genName() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2003/12/05 20:26:42 $
+ * $Date: 2004/09/28 23:07:02 $
  */
 
