@@ -12,6 +12,10 @@
  *  you have to do is add a new entry to the ID list (#EventGeneratorID_t)
  *  and then put its name in the #EventGeneratorNames[] array.
  *
+ *  The #EventGeneratorID_t list should contain links to the
+ *  generators' documentation, or will directly give information about
+ *  what to expect in events from that generator.
+ *  
  *  Alternatively, there is an 'unlicensed spectrum' available under
  *  the #unknownEGID.  You can send out events from that generator just
  *  like any other, but it should only be used for quick tests and hacking
@@ -23,14 +27,19 @@
  *  #visObjEGID) refers to seeing a particular object.  These SIDs are
  *  usually defined in the generators themselves.
  *
+ *  If more information needs to be sent along with the event, the
+ *  cleanest solution is to create a subclass of EventBase to hold the
+ *  additional information.  For example, you can see the existing
+ *  subclasses in the inheritance diagram above.  If you want to use a
+ *  quick hack however, you could assume the pointer size is the same
+ *  as an unsigned int and just pass a pointer to data as the SID.
+ *  Your funeral, err, I mean your call. ;)
+ *
  *  The #duration field is also generator specific - some may refer to
  *  the time since the last activation event (e.g. button events)
  *  where as others refer to time since last status (e.g. sensors
  *  updates)
  *
- *  The #EventGeneratorID_t list should contain links to the
- *  generators' documentation, or will directly give information about
- *  what to expect in events from that generator.
  */
 class EventBase : public LoadSave {
  public:
@@ -43,16 +52,19 @@ class EventBase : public LoadSave {
 		aiEGID,           //!< not being used, yet (might use this when AI makes decisions?)
 		audioEGID,        //!< Sends an event when a sound starts/ends playback, status events as chained sounds end; SID is SoundManager::Play_ID; duration is playtime
 		buttonEGID,       //!< Sends activate event for button down, deactivate for button up.  Status events only for when pressure sensitive buttons' reading changes. (on sensorEGID updates); SIDs are from ButtonOffset_t in the namespace of the target model (e.g. ERS210Info::ButtonOffset_t); duration is button down time
-		erouterEGID,      //!< Sends activate event on first listener, deactivate on last listener, and status on other listener changes.; SID is the generator ID affected (NOT IMPLEMENTED YET)
+		erouterEGID,      //!< Sends activate event on first listener, deactivate on last listener, and status on other listener changes.; SID is the generator ID affected
 		estopEGID,        //!< Sends an event when the estop is turned on or off; SID is the MotionManager::MC_ID of the EmergencyStopMC; duration is length of estop activation
 		locomotionEGID,   //!< Sends events regarding transportation in the world; you can/should assume these will all be LocomotionEvent classes; SID is MotionManager::MC_ID of posting MotionCommand; duration is the time since last velocity change of that MC. (You could generate these for things other than walking...)
-		motmanEGID,       //!< Sends events when a MotionCommand is added or removed, SID is is the MotionManager::MC_ID, duration is always 0
+		micOSndEGID,      //!< Sends a DataEvent<OSoundVectorData> for every audio buffer received from the system; SID and duration are always 0 (This is generated by the MainObj instantiation of MMCombo)
+		micRawEGID,       //!< reserved for future use
+		micFFTEGID,       //!< reserved for future use
+		motmanEGID,       //!< Sends events when a MotionCommand is added or removed, SID is is the MotionManager::MC_ID, duration is always 0; individual MotionCommands may throw status events to signal intermediary status
 		powerEGID,        //!< Sends events for low power warnings, temperature, etc. see PowerSourceID::PowerSourceID_t
 		sensorEGID,       //!< Sends a status event when new sensor readings are available. see SensorSourceID::SensorSourceID_t
 		stateMachineEGID, //!< Sends an event upon entering and leaving a StateNode; SID is pointer to the StateNode; duration is always 0
     textmsgEGID,      //!< Sends status events when a text msg is received on console; generated by the Controller, SID is always -1; durations is always 0 (see Controller for more information)
 		timerEGID,        //!< Sends timer events; you set timers explicitly, you don't have to listen as well. (See EventRouter::addTimer()) There's no cross-talk, only the listener which requested the timer will receive it; SID is whatever you requested it to be; duration is the time (since boot, in ms) that the timer was supposed to go off; these are always status
-		visOFbkEGID,      //!< Sends a DataEvent <OFbkImageVectorData> for every camera image received from the system; SID and duration are always 0 (This is generated by the MainObj instantiation of MMCombo)
+		visOFbkEGID,      //!< Sends a DataEvent < OFbkImageVectorData > for every camera image received from the system; SID and duration are always 0 (This is generated by the MainObj instantiation of MMCombo)
 		visRawCameraEGID, //!< Sends a FilterBankEvent when new raw camera images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visInterleaveEGID,//!< Sends a FilterBankEvent when new interleaved images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visJPEGEGID,      //!< Sends a FilterBankEvent when JPEG compressed images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
@@ -109,6 +121,15 @@ class EventBase : public LoadSave {
 	virtual const std::string& resetName() { nameisgen=true; genName(); return stim_id; } //!< resets name to generated form, overwriting any previous name
 	virtual bool isCustomName() const { return !nameisgen; } //!< returns true if not using the generated name
 
+	//! generates a description of the event with variable verbosity 
+	/*! @param showTypeSpecific will signal subclasses to add additional information
+	 *  @param verbosity can be one of the following values:
+	 *    - 0 - the name and type
+	 *    - 1 - the name, type, duration, and timestamp
+	 *    - 2 and above - the name, type, duration, and magnitude
+	 *  if showTypeSpecific, additional fields will be added after the common fields listed above. */
+	virtual std::string getDescription(bool showTypeSpecific=true, unsigned int verbosity=0) const; 
+
 	inline bool operator<(const EventBase& e) const { return timestamp<e.timestamp; }
 
 	//! is true if the genID, typeID, and sourceID's all match
@@ -155,10 +176,10 @@ class EventBase : public LoadSave {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/10/18 16:59:20 $
  */
 
 #endif
