@@ -10,7 +10,7 @@ EventGeneratorBase::DoStart() {
 
 void
 EventGeneratorBase::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	BehaviorBase::DoStop();
 }
 
@@ -19,9 +19,9 @@ EventGeneratorBase::DoStop() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2003/12/08 00:21:05 $
+ * $Date: 2004/10/07 19:07:05 $
  */
 
