@@ -38,9 +38,14 @@ void EventRouter::processTimers() {
 	//		cout << "done" << endl;
 }
 
-/*! timers are unique by EventListener and source ID - can't have two timers for the same el and sid
- *  a delay of 0 with repeating will cause an event to be sent at every opportunity, use very sparingly
- *  a delay of -1U will call removeTimer() if it already exists, otherwise is ignored
+/*! timers are unique by EventListener and source ID - can't have two timers for the same el and sid\n
+ *  a delay of 0 with repeating will cause an event to be sent at every opportunity, use sparingly\n
+ *  a delay of -1U will call removeTimer() if it already exists, otherwise is ignored\n
+ *
+ *  To add a timer, you can also call addListener() with EventBase::timerEGID and the sid
+ *  and delay (in the EventBase::duration field) - this method will simply cause this
+ *  function to be called internally.
+ *
  *  @param el the EventListener to send the timer event to
  *  @param sid the source ID to use on that event (if you need to send more info, send a pointer to a struct of your devising, typecasted as int)
  *  @param delay the delay between the first (and future) calls
@@ -66,32 +71,6 @@ void EventRouter::addTimer(EventListener* el, unsigned int sid, unsigned int del
 	//	chkTimers();
 }
 
-void EventRouter::addListener(EventListener* el, const EventBase& e) {
-	if(e.getGeneratorID()==EventBase::timerEGID)
-		addTimer(el,e.getSourceID(),e.getDuration());
-	else
-		listeners.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
-}
-void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid) {
-	listeners.addMapping(el,egid); 
-}
-void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
-	for(unsigned int et=0; et<EventBase::numETIDs; et++)
-		listeners.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
-}
-void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
-	listeners.addMapping(el,egid,sid,etid);
-}
-
-void EventRouter::removeListener(EventListener* el, const EventBase& e) {
-	if(e.getGeneratorID()==EventBase::timerEGID)
-		removeTimer(el,e.getSourceID());
-	else {
-		listeners.removeMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
-		listeners.clean();
-	}
-}
-
 void EventRouter::removeTimer(EventListener* el) {
 	for(timer_it_t it=timers.begin(); it!=timers.end(); it++)
 		if((*it)->el==el) {
@@ -116,6 +95,198 @@ void EventRouter::removeAllTimers() {
 	timers.erase(timers.begin(),timers.end());
 }
 
+void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid) {
+	bool hadListener=hasListeners(egid);
+	listeners.addMapping(el,egid); 
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+	bool hadListener=hasListeners(egid);
+	for(unsigned int et=0; et<EventBase::numETIDs; et++)
+		listeners.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+	bool hadListener=hasListeners(egid);
+	listeners.addMapping(el,egid,sid,etid);
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+void EventRouter::addListener(EventListener* el, const EventBase& e) {
+	if(e.getGeneratorID()==EventBase::timerEGID)
+		addTimer(el,e.getSourceID(),e.getDuration());
+	else {
+		bool hadListener=hasListeners(e.getGeneratorID());
+		listeners.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
+		if(!hadListener)
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID));
+		else
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+	}
+}
+
+void EventRouter::removeListener(EventListener* el) {
+	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++)
+		removeListener(el,(EventBase::EventGeneratorID_t)eg);
+}
+void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid) {
+	if(egid==EventBase::timerEGID)
+		removeTimer(el);
+	else {
+		if(!listeners.removeMapping(el,egid))
+			return; //nothing was removed, don't want to clean up or throw an event
+		listeners.clean(egid);
+		if(!hasListeners(egid))
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+		else
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+	}
+}
+void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+	if(egid==EventBase::timerEGID)
+		removeTimer(el,sid);
+	else {
+		unsigned int removed=0;
+		for(unsigned int et=0; et<EventBase::numETIDs; et++)
+			removed+=listeners.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
+		if(!removed)
+			return; //nothing was removed, don't want to clean up or throw an event
+		listeners.clean(egid);
+		if(!hasListeners(egid))
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+		else
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+	}
+}
+void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+	if(egid==EventBase::timerEGID) {
+		if(etid==EventBase::statusETID)
+			removeTimer(el,sid);
+	} else {
+		if(!listeners.removeMapping(el,egid,sid,etid))
+			return; //nothing was removed, don't want to clean up or throw an event
+		listeners.clean(egid);
+		if(!hasListeners(egid))
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+		else
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+	}
+}
+void EventRouter::removeListener(EventListener* el, const EventBase& e) {
+	if(e.getGeneratorID()==EventBase::timerEGID)
+		removeTimer(el,e.getSourceID());
+	else {
+		if(!listeners.removeMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()))
+			return; //nothing was removed, don't want to clean up or throw an event
+		listeners.clean(e.getGeneratorID());
+		if(!hasListeners(e.getGeneratorID()))
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID));
+		else
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+	}
+}
+
+void EventRouter::forgetListener(EventListener* el) {
+	removeListener(el);
+}
+
+void EventRouter::addTrapper(EventTrapper* el, const EventBase& e) {
+	bool hadListener=hasListeners(e.getGeneratorID());
+	trappers.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+}
+/*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
+void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) {
+	bool hadListener=hasListeners(egid);
+	trappers.addMapping(el,egid);
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+/*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
+void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+	bool hadListener=hasListeners(egid);
+	for(unsigned int et=0; et<EventBase::numETIDs; et++)
+		trappers.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+/*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
+void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+	bool hadListener=hasListeners(egid);
+	trappers.addMapping(el,egid,sid,etid);
+	if(!hadListener)
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+
+/*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
+void EventRouter::addTrapper(EventTrapper* el) {
+	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++)
+		addTrapper(el,(EventBase::EventGeneratorID_t)eg);
+}
+
+
+void EventRouter::removeTrapper(EventTrapper* el, const EventBase& e) {
+	if(!trappers.removeMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()))
+		return; //nothing was removed, don't want to clean up or throw an event
+	trappers.clean(e.getGeneratorID());
+	if(!hasListeners(e.getGeneratorID()))
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+}
+void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) {
+	if(!trappers.removeMapping(el,egid))
+		return; //nothing was removed, don't want to clean up or throw an event
+	trappers.clean(egid);
+	if(!hasListeners(egid))
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+	int removed=0;
+	for(unsigned int et=0; et<EventBase::numETIDs; et++)
+		removed+=trappers.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
+	if(!removed)
+		return; //nothing was removed, don't want to clean up or throw an event
+	trappers.clean(egid);
+	if(!hasListeners(egid))
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+	if(!trappers.removeMapping(el,egid,sid,etid))
+		return; //nothing was removed, don't want to clean up or throw an event
+	trappers.clean(egid);
+	if(!hasListeners(egid))
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+	else
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+}
+
+void EventRouter::removeTrapper(EventTrapper* el) {
+	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++)
+		removeTrapper(el,(EventBase::EventGeneratorID_t)eg);
+}
+
 void EventRouter::processEventBuffer() { //clears buffered events
 	if(events.size()>0)
 		doSendBuffer();
@@ -183,9 +354,11 @@ void EventRouter::EventMapper::addMapping(void* el, EventBase::EventGeneratorID_
 	elv->push_back(el); // now that everything's set up, we can add the listener
 }
 
-void EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid) {
+bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid) {
 	// remove listener from allevents
+	unsigned int numlist=allevents[egid].size();
 	allevents[egid].erase(remove(allevents[egid].begin(),allevents[egid].end(),el),allevents[egid].end());
+	bool hadListener=allevents[egid].size()!=numlist;
 	
 	// now remove listener from all of the filtered events
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
@@ -194,53 +367,64 @@ void EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGenerator
 			SIDtoListenerVectorMap_t::iterator mapit=mapping->begin();
 			for(mapit=mapping->begin(); mapit!=mapping->end(); mapit++) {// go through each sourceID, delete EL
 				std::vector<void*> * v=&(*mapit).second;
-				v->erase(remove(v->begin(),v->end(),el),v->end());
+				std::vector<void*>::iterator last=remove(v->begin(),v->end(),el);
+				if(last!=v->end()) {
+					hadListener=true;
+					v->erase(last,v->end());
+				}
 			}
 		}
 	}
+	return hadListener;
 }
 
-void EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+	bool hadListener=false;
 	SIDtoListenerVectorMap_t* mapping=filteredevents[egid][etid];
 	if(mapping!=NULL) { // if there are subscribers to this egid/etid
 		SIDtoListenerVectorMap_t::iterator mapit=mapping->find(sid);
 		if(mapit!=mapping->end()) {
 			std::vector<void*> * v=&(*mapit).second;
-			v->erase(remove(v->begin(),v->end(),el),v->end());
+			std::vector<void*>::iterator last=remove(v->begin(),v->end(),el);
+			if(last!=v->end()) {
+				hadListener=true;
+				v->erase(last,v->end());
+			}
 		}
 	}
+	return hadListener;
 }
 
 void EventRouter::EventMapper::clean() {
+	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++)
+		clean((EventBase::EventGeneratorID_t)eg);
+}
+void EventRouter::EventMapper::clean(EventBase::EventGeneratorID_t egid) {
 	// first, remove any empty sid vectors from all the mappings
-	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++) {
-		for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-			SIDtoListenerVectorMap_t* mapping=filteredevents[eg][et];
-			if(mapping!=NULL) { // if there are subscribers to this egid/etid
-				SIDtoListenerVectorMap_t::iterator mapit=mapping->begin();
-				bool done=false;
-				while(!done) {
-					done=true;
-					for(mapit=mapping->begin(); mapit!=mapping->end(); mapit++) { // go through each sourceID vector
-						if((*mapit).second.size()==0) {
-							mapping->erase(mapit);
-							done=false;
-							break;
-						}
+	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
+		SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
+		if(mapping!=NULL) { // if there are subscribers to this egid/etid
+			SIDtoListenerVectorMap_t::iterator mapit=mapping->begin();
+			bool done=false;
+			while(!done) {
+				done=true;
+				for(mapit=mapping->begin(); mapit!=mapping->end(); mapit++) { // go through each sourceID vector
+					if((*mapit).second.size()==0) {
+						mapping->erase(mapit);
+						done=false;
+						break;
 					}
 				}
 			}
 		}
 	}
 	// now remove any empty mappings
-	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++) {
-		for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-			SIDtoListenerVectorMap_t* mapping=filteredevents[eg][et];
-			if(mapping!=NULL) { // if there are subscribers to this egid/etid
-				if(mapping->size()==0) {
-					delete mapping;
-					filteredevents[eg][et]=NULL;
-				}
+	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
+		SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
+		if(mapping!=NULL) { // if there are subscribers to this egid/etid
+			if(mapping->size()==0) {
+				delete mapping;
+				filteredevents[egid][et]=NULL;
 			}
 		}
 	}
@@ -348,10 +532,10 @@ bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGe
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.10 $
- * $State: Rel $
- * $Date: 2003/10/03 03:41:01 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.13 $
+ * $State: Exp $
+ * $Date: 2004/10/07 22:14:17 $
  */
 
 
