@@ -14,8 +14,13 @@
 
 //! This class will handle distribution of events as well as management of timers
 /*! Classes must inherit from EventListener and/or EventTrapper in order to
- *  receive events.\n
- *  Use the global @c ::erouter EventRouter to post and subscribe to events\n
+ *  receive events.
+ *
+ *  Use the global @c ::erouter EventRouter to post and subscribe to
+ *  events, except if you are posting from within a MotionCommand, in
+ *  which case you should use MotionCommand::postEvent() so that it
+ *  will automatically be sent from the Motion process to the Main
+ *  process.
  *
  *  When multiple listeners are subscribed, the order in which an event is
  *  distributed among them looks like this:
@@ -28,11 +33,32 @@
  *  ...but if you're relying on that ordering, there should be a cleaner
  *  way to do whatever you're doing.
  *
- *  If one behaviors unsubscribes another one during a processEvent(), that
- *  behavior will still get the "current" event before the unsubscription
- *  takes place.
+ *  If one behaviors unsubscribes another one during a processEvent(),
+ *  that behavior may still get the "current" event before the
+ *  unsubscription takes place.  This is not a prescribed behavior,
+ *  and also should not be relied on one way or the other.
  *
- *  Buffering events has not been tested thoroughly...
+ *  Timer events are only sent to the generator which requested them.  So if 
+ *  EventListener @e A requests a timer with ID 0 at two second intervals,
+ *  and EventListener @e B requests a timer with ID 0 at three second intervals,
+ *  each will still only receive the timers they requested - no cross talk.
+ *  The timer generator is unique in this regard, which is why it is built in
+ *  as an integral component of the EventRouter.  All other events are broadcast.
+ *
+ *  If an EventListener/EventTrapper subscribes to the same event source multiple
+ *  times, it will receive multiple copies of the event.  However, the first call
+ *  to removeListener for a source will remove all subscriptions to that source.\n
+ *  Example: EventListener @e A subscribes to (buttonEGID,*,*), and twice to
+ *  (buttonEGID,0,*).
+ *    - If button 0 is pressed, @e A will get three copies of the event.
+ *    - If button 1 is pressed, @e A will get one copy.
+ *    - If removeListener(&A,buttonEGID) is called, the (buttonEGID,*,*) is
+ *      removed, <em>as well as</em> both of (buttonEGID,0,*).
+ *    - If removeListener(&A,buttonEGID,0) is called, both of (buttonEGID,0,*)
+ *      are removed, but (buttonEGID,*,*) would be untouched.
+ *
+ *  The buffered event distribution has not been tested thoroughly,
+ *  and should be considered deprecated.
  *
  *  @see EventBase::EventGeneratorID_t for a complete listing of all generators,
  *  as well as instructions on how to add new generators.
@@ -67,10 +93,11 @@ class EventRouter : public EventListener {
 	bool hasListeners(EventBase::EventGeneratorID_t egid) { return trappers.hasMapping(egid) || listeners.hasMapping(egid); }
 	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid) { return trappers.hasMapping(egid,sid) || listeners.hasMapping(egid,sid); }
 	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { return trappers.hasMapping(egid,sid,etid) || listeners.hasMapping(egid,sid,etid); }
+	bool hasListeners(const EventBase& e) { return hasListeners(e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 	//@}
 
 	//!@name Timer Management
-	void addTimer(EventListener* el, unsigned int sid, unsigned int delay, bool repeat=true); //!< adds a timer or sets a timer if it doesn't already exist.
+	void addTimer(EventListener* el, unsigned int sid, unsigned int delay, bool repeat=true); //!< adds a timer if it doesn't exist, or resets the timer if it already exists.
 	void addTimer(EventListener* el, const EventBase& e, bool repeat=true) { addTimer(el,e.getSourceID(),e.getDuration(),repeat); } //!< calls the other addTimer() with the event's source id and duration, doesn't check to see if the generator is timerEGID
 	void removeTimer(EventListener* el); //!< clears all pending timers for listener @a el
 	void removeTimer(EventListener* el, unsigned int sid); //!< clears any pending timers with source id @a sid for listener @a el
@@ -78,36 +105,44 @@ class EventRouter : public EventListener {
 	//@}
 
 	//!@name Listener Management
-	void addListener(EventListener* el, const EventBase& e); //!< Adds a listener for a specific source id and type from a given event generator, adding a Timer event will invoke addTimer(@a el, @a e.getSourceID(), @a e.getDuration(), @c true)
-	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid); //!< Adds a listener for all events from a given event generator
+	//! Adds a listener for all events from a given event generator
+	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid);
 	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< Adds a listener for all types from a specific source and generator
 	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
+	//! Adds a listener for a specific source id and type from a given event generator, adding a Timer event will invoke addTimer(@a el, @a e.getSourceID(), @a e.getDuration(), @c true)
+	void addListener(EventListener* el, const EventBase& e); 
 
+	//! stops sending ALL events to the listener, including timers
+	void removeListener(EventListener* el); 
+	//! stops sending specified events from the generator to the listener.
+	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid);
+	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< stops sending specified events from the generator to the listener.
+	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the listener.
 	//! stops sending specified events from the generator to the listener.  If a timer is passed it will invoke removeTimer(@a el, @a e.getSourceID())
 	void removeListener(EventListener* el, const EventBase& e);
-	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid) { listeners.removeMapping(el,egid); listeners.clean(); } //!< stops sending specified events from the generator to the listener.
-	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { for(unsigned int et=0; et<EventBase::numETIDs; et++) listeners.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et); listeners.clean(); } //!< stops sending specified events from the generator to the listener.
-	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { listeners.removeMapping(el,egid,sid,etid); listeners.clean(); } //!< stops sending specified events from the generator to the listener.
 
-	void removeListener(EventListener* el) { for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++) listeners.removeMapping(el,(EventBase::EventGeneratorID_t)eg); listeners.clean(); } //!< stops sending ALL events to the listener
-	void forgetListener(EventListener* el) { removeTimer(el); removeListener(el); } //!< clears timers and removes listener from all events
+	/*! @deprecated use removeListener(EventListener* el) instead
+	 *  @brief deprecated, you should call removeListener(EventListener* el) instead */
+	void forgetListener(EventListener* el) __attribute__((deprecated));
 	//@}
 
 	//!@name Trapper Management
-	void addTrapper(EventTrapper* el, const EventBase& e) { trappers.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); } //!< Adds a trapper for a specific source id and type from a given event generator
-	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) { trappers.addMapping(el,egid); } //!< Adds a trapper for all events from a given event generator
-	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { for(unsigned int et=0; et<EventBase::numETIDs; et++) trappers.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et); }  //!< Adds a trapper for all types from a specific source and generator
-	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { trappers.addMapping(el,egid,sid,etid); } //!< Adds a trapper for a specific source id and type from a given event generator
+	//! Adds a trapper for a specific source id and type from a given event generator
+	/*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
+	void addTrapper(EventTrapper* el, const EventBase& e);
+	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid); //!< Adds a trapper for all events from a given event generator
+	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid);  //!< Adds a trapper for all types from a specific source and generator
+	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a trapper for a specific source id and type from a given event generator
 
-	void addTrapper(EventTrapper* el) { for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++) trappers.addMapping(el,(EventBase::EventGeneratorID_t)eg); } //!< adds a trapper for ALL events
+	void addTrapper(EventTrapper* el); //!< adds a trapper for ALL events
 
 	//! stops sending specified events from the generator to the trapper.
-	void removeTrapper(EventTrapper* el, const EventBase& e) { trappers.removeMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); trappers.clean(); }
-	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) { trappers.removeMapping(el,egid); trappers.clean(); } //!< stops sending specified events from the generator to the trapper.
-	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { for(unsigned int et=0; et<EventBase::numETIDs; et++) trappers.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et); trappers.clean(); } //!< stops sending specified events from the generator to the trapper.
-	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { trappers.removeMapping(el,egid,sid,etid); trappers.clean(); } //!< stops sending specified events from the generator to the trapper.
+	void removeTrapper(EventTrapper* el, const EventBase& e);
+	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid); //!< stops sending specified events from the generator to the trapper.
+	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< stops sending specified events from the generator to the trapper.
+	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the trapper.
 
-	void removeTrapper(EventTrapper* el) { for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++) trappers.removeMapping(el,(EventBase::EventGeneratorID_t)eg); trappers.clean(); } //!< stops sending ALL events to the trapper
+	void removeTrapper(EventTrapper* el); //!< stops sending ALL events to the trapper
 	//@}
 
  protected:
@@ -193,15 +228,16 @@ class EventRouter : public EventListener {
 		void addMapping(void* el, EventBase::EventGeneratorID_t egid) { allevents[egid].push_back(el); } //!< Adds a listener for all events from a given event generator
 		void addMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
 
-		//! Removes a listener for all events from a given event generator
+		//! Removes a listener for all events from a given event generator, returns true if something was actually removed
 		/*! Doesn't necessarily remove the vector or mapping if this was the last listener, use clean() to do that */
-		void removeMapping(void* el, EventBase::EventGeneratorID_t egid); 
+		bool removeMapping(void* el, EventBase::EventGeneratorID_t egid); 
 
-		//! Removes a listener for a specific source id and type from a given event generator
+		//! Removes a listener for a specific source id and type from a given event generator, returns true if something was actually removed
 		/*! Doesn't necessarily remove the vector or mapping if this was the last listener, use clean() to do that */
-		void removeMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
+		bool removeMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
 
-		void clean(); //!<compresses empty data structures
+		void clean(); //!<removes empty data structures for all event generators
+		void clean(EventBase::EventGeneratorID_t egid); //!< removes empty data structures associated with a single event generator
 		void clear(); //!<Resets the mapping
 
 		//@{
@@ -263,10 +299,10 @@ extern EventRouter * erouter;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:57 $
+ * $Date: 2004/10/07 22:14:17 $
  */
 
 #endif
