@@ -28,7 +28,7 @@ EventTranslator::enqueue(const EventBase& event, Queue_t * q) {
 	}
 	void* buf=q->reserve(sizeof(TypeID_t)+len);
 	if(buf==NULL) {
-		ASSERT(false,"Queue overflow");
+		ASSERT(false,"Queue overflow "<<type<<' '<<len);
 	} else {
 		*reinterpret_cast<TypeID_t*>(buf)=type;
 		reinterpret_cast<char*>(buf)+=sizeof(TypeID_t);
@@ -86,9 +86,9 @@ EventTranslator::sendEvent(const void * entry, unsigned int size) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2003/11/22 20:33:01 $
+ * $Date: 2004/10/14 23:02:35 $
  */
 
