@@ -39,6 +39,9 @@ public:
 	//!called by trapEvent to do all the work, needed so MotionCommands can enqueue directly
 	static void enqueue(const EventBase& event, Queue_t * q);
 
+	//!called by non-MotionCommands to enqueue an event
+	void enqueue(const EventBase& event) { enqueue(event,queue); }
+
 	//!called whenever Main gets some processor time to check for events from other processes
 	void translateEvents();
 
@@ -59,10 +62,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/11/22 20:33:01 $
+ * $Date: 2004/09/16 18:35:12 $
  */
 
 #endif
