@@ -8,6 +8,7 @@
 #include "Events/EventRouter.h"
 #include "Behaviors/BehaviorBase.h"
 #include "Motion/MotionManager.h"
+#include "Motion/Kinematics.h"
 #include "SoundPlay/SoundManager.h"
 #include "Events/DataEvent.h"
 #include "Events/TextMsgEvent.h"
@@ -53,9 +54,28 @@ MMCombo::DoInit(const OSystemEvent&)
 	// make sure the library doesn't drop data "for" us on this reliable communication channel
 	observer[obsReceiveWorldState]->SetBufCtrlParam(0,1,1);
 	observer[obsReceiveMotionManager]->SetBufCtrlParam(0,1,1);
+	observer[obsReceiveSoundManager]->SetBufCtrlParam(0,1,1);
 	observer[obsMotionManagerComm]->SetBufCtrlParam(0,1,MotionManager::MAX_MOTIONS+1);
 	//+1 to MAX_MOTIONS so we can get a delete message after we've filled up
 
+	cout << objectName << ": sbjRegisterWorldState==" << sbjRegisterWorldState << " selector==" << subject[sbjRegisterWorldState]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveWorldState==" << obsReceiveWorldState << " selector==" << observer[obsReceiveWorldState]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjRegisterMotionManager==" << sbjRegisterMotionManager << " selector==" << subject[sbjRegisterMotionManager]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveMotionManager==" << obsReceiveMotionManager << " selector==" << observer[obsReceiveMotionManager]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjRegisterEventTranslatorQueue==" << sbjRegisterEventTranslatorQueue << " selector==" << subject[sbjRegisterEventTranslatorQueue]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveEventTranslatorQueue==" << obsReceiveEventTranslatorQueue << " selector==" << observer[obsReceiveEventTranslatorQueue]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjMoveJoint==" << sbjMoveJoint << " selector==" << subject[sbjMoveJoint]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsSensorFrame==" << obsSensorFrame << " selector==" << observer[obsSensorFrame]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsImage==" << obsImage << " selector==" << observer[obsImage]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsMic==" << obsMic << " selector==" << observer[obsMic]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjMotionManagerComm==" << sbjMotionManagerComm << " selector==" << subject[sbjMotionManagerComm]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsMotionManagerComm==" << obsMotionManagerComm << " selector==" << observer[obsMotionManagerComm]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveSoundManager==" << obsReceiveSoundManager << " selector==" << observer[obsReceiveSoundManager]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjSoundManagerComm==" << sbjSoundManagerComm << " selector==" << subject[sbjSoundManagerComm]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjRPOPENRSendString==" << sbjRPOPENRSendString << " selector==" << subject[sbjRPOPENRSendString]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsRPOPENRReceiveString==" << obsRPOPENRReceiveString << " selector==" << observer[obsRPOPENRReceiveString]->GetID().GetSelector() << '\n'
+			 << flush;
+
 	if(strcmp(objectName,"MainObj")==0)
 		ProcessID::setID(ProcessID::MainProcess);
 	else if(strcmp(objectName,"MotoObj")==0)
@@ -82,7 +102,7 @@ MMCombo::DoInit(const OSystemEvent&)
 			OSYSLOG1((osyslogERROR, "%s : %s %d","MMCombo::DoStart()","OPENR::ObservePowerStatus() FAILED", result));
 			return oFAIL;
 		}
-
+		
     //Setup wireless
     wireless = new Wireless();
     sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
@@ -109,11 +129,23 @@ MMCombo::DoInit(const OSystemEvent&)
     OPENR::SetMotorPower(opowerON);
 		OPENR::EnableJointGain(oprimitiveID_UNDEF); //oprimitiveID_UNDEF means enable all
 
+    //Setup wireless
+    wireless = new Wireless();
+    sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
+    serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*2);
+    wireless->setDaemon(sout);
+    wireless->setDaemon(serr);
+		serr->setFlushType(SocketNS::FLUSH_BLOCKING);
+    sout->setTextForward();
+    serr->setForward(sout);
+		
 		//motmanMemRgn -> motman setup
 		motmanMemRgn = InitRegion(sizeof(MotionManager));
 		motman = new (motmanMemRgn->Base()) MotionManager();
 		motman->InitAccess(subject[sbjMotionManagerComm]);
 	}
+	kine = new Kinematics();
+
 	ProjectInterface::startupBehavior.AddReference();
 
 	cout << objectName << "::DoInit()-DONE" << endl;
@@ -135,6 +167,11 @@ MMCombo::DoStart(const OSystemEvent&)
 		state->read(power,erouter);
 	}
 
+	if(strcmp(objectName,"MotoObj")==0) {
+		wireless->listen(sout, config->motion.console_port);
+		wireless->listen(serr, config->motion.stderr_port);
+	}
+	
 	isStopped=false;
 
 	ENABLE_ALL_SUBJECT;
@@ -475,6 +512,8 @@ MMCombo::GotImage(const ONotifyEvent& event){
 	PROFSECTION("GotImage()",state->mainProfile);
 	etrans.translateEvents();
 
+  erouter->processTimers();
+  
 	WMvari(int, frame_counter, 0);
 	++frame_counter;
 	
@@ -485,6 +524,23 @@ MMCombo::GotImage(const ONotifyEvent& event){
   observer[obsImage]->AssertReady();
 }
 
+void
+MMCombo::GotAudio(const ONotifyEvent& event){
+	if(isStopped) {
+		//cout << "BAH!GotAudio" << endl;
+		return;
+	}
+
+	PROFSECTION("GotAudio()",state->mainProfile);
+	etrans.translateEvents();
+
+	erouter->postEvent(new DataEvent<const OSoundVectorData*>(reinterpret_cast<const OSoundVectorData*>(event.Data(0)),EventBase::micOSndEGID,0,EventBase::statusETID));
+	
+  erouter->processTimers();
+  
+  observer[obsMic]->AssertReady();
+}
+
 void
 MMCombo::GotPowerEvent(void * msg){
 	if(isStopped) {
@@ -711,10 +767,10 @@ MMCombo::RPOPENR_send(char *buf, int bufsize) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.50 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.57 $
  * $State: Exp $
- * $Date: 2004/03/03 03:37:03 $
+ * $Date: 2004/10/11 22:00:19 $
  */
 
 
