@@ -51,6 +51,9 @@ public:
 	void ReadySendJoints(const OReadyEvent& event);      //!< motion only (until main does ears again, then both) calls SendJoints, if DoStart has already been called
 	void GotSensorFrame(const ONotifyEvent& event);      //!< main only, called when new sensor information is available
 	void GotImage(const ONotifyEvent& event);            //!< main only, called when a new image is available
+// paris start
+	void GotAudio(const ONotifyEvent& event);            //!< main only, called when a new audio buffer is available
+// paris end
 	void GotPowerEvent(void * msg);                      //!< main only, called when a power event occurs (can be just status events)
 	
 	void GotMotionMsg(const ONotifyEvent& event);        //!< both, called when a new MotionManagerMsg has been received
@@ -138,10 +141,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.26 $
  * $State: Exp $
- * $Date: 2004/02/03 01:17:24 $
+ * $Date: 2004/09/28 23:07:04 $
  */
 
 #endif
