@@ -105,6 +105,12 @@ void EmergencyStopMC::takeSnapshot() {
 	dirty=true;
 }
 
+void EmergencyStopMC::takeSnapshot(const WorldState* st) {
+	for(unsigned int i=0; i<NumOutputs; i++)
+		cmds[i].value=st->outputs[i];
+	dirty=true;
+}
+
 void EmergencyStopMC::setActive(bool a) {
 	if(paused) {
 		if(!a && active)
@@ -203,9 +209,9 @@ bool EmergencyStopMC::trigger() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2004/02/06 23:13:46 $
+ * $Date: 2004/08/30 20:26:45 $
  */
 
