@@ -8,29 +8,62 @@
 /*! This is "Mimic the number" style */
 const LEDBitMask_t LedEngine::ERS210numMasks[11] = {
 	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::TopBrLEDMask, //0
+	
 	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopLLEDMask,  //1
+	
 	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask, //2
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask, //3
+	
+	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::TopLLEDMask
+	|ERS210Info::TopBrLEDMask, //3
+	
 	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask,  //4
+
 	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopBrLEDMask, //5
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopBrLEDMask, //6
+
+	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::MidLLEDMask
+	|ERS210Info::TopRLEDMask|ERS210Info::TopBrLEDMask, //6
+
 	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask,  //7
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask, //8
-	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask,  //9
+
+	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::MidLLEDMask
+	|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask, //8
+
+	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask
+	|ERS210Info::TopBrLEDMask,  //9
+
 	ERS210Info::BotLLEDMask //.
 };
 /*! This is "Count the dots" style */
 const LEDBitMask_t LedEngine::ERS220numMasks[11] = {
 	ERS220Info::ModeLEDMask, //0
+
 	ERS220Info::FaceBackLeftLEDMask, //1
+
 	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask, //2
+
 	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask, //3
-	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask|ERS220Info::FaceFrontRightLEDMask, //4
-	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask, //5
-	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask, //6
-	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask|ERS220Info::FaceFrontALEDMask, //7
-	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask|ERS220Info::FaceFrontALEDMask|ERS220Info::FaceFrontBLEDMask, //8
-	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask|ERS220Info::FaceFrontALEDMask|ERS220Info::FaceFrontBLEDMask|ERS220Info::FaceFrontCLEDMask, //9
+
+	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask
+	|ERS220Info::FaceFrontRightLEDMask, //4
+
+	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask
+	|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask, //5
+
+	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask
+	|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask, //6
+
+	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask
+	|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask
+	|ERS220Info::FaceFrontALEDMask, //7
+
+	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask
+	|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask
+	|ERS220Info::FaceFrontALEDMask|ERS220Info::FaceFrontBLEDMask, //8
+
+	ERS220Info::FaceBackLeftLEDMask|ERS220Info::FaceCenterLeftLEDMask|ERS220Info::FaceFrontLeftLEDMask
+	|ERS220Info::FaceFrontRightLEDMask|ERS220Info::FaceCenterRightLEDMask|ERS220Info::FaceBackRightLEDMask
+	|ERS220Info::FaceFrontALEDMask|ERS220Info::FaceFrontBLEDMask|ERS220Info::FaceFrontCLEDMask, //9
+
 	ERS220Info::FaceFrontLeftLEDMask //.
 };
 /*
@@ -53,19 +86,37 @@ const LEDBitMask_t LedEngine::ERS7numMasks[11] = {
 const LEDBitMask_t LedEngine::ERS7numMasks[11] = {
 	0, //0
 	(ERS7Info::FaceLEDPanelMask<<11), //1
+
 	(ERS7Info::FaceLEDPanelMask<< 4)|(ERS7Info::FaceLEDPanelMask<< 5), //2
+
 	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<<11)|(ERS7Info::FaceLEDPanelMask<< 3), //3
-	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 8)|(ERS7Info::FaceLEDPanelMask<<9), //4
-	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 8)|(ERS7Info::FaceLEDPanelMask<<9)|(ERS7Info::FaceLEDPanelMask<<11), //5
-	(ERS7Info::FaceLEDPanelMask<< 0)|(ERS7Info::FaceLEDPanelMask<< 1)|(ERS7Info::FaceLEDPanelMask<< 4)|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7), //6
-	(ERS7Info::FaceLEDPanelMask<< 0)|(ERS7Info::FaceLEDPanelMask<< 1)|(ERS7Info::FaceLEDPanelMask<< 4)|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7)|(ERS7Info::FaceLEDPanelMask<<11), //7
-	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 4)|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7)|(ERS7Info::FaceLEDPanelMask<< 8)|(ERS7Info::FaceLEDPanelMask<<9), //8
-	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 4)|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7)|(ERS7Info::FaceLEDPanelMask<< 8)|(ERS7Info::FaceLEDPanelMask<<9)|(ERS7Info::FaceLEDPanelMask<<11), //9
+
+	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 8)
+	|(ERS7Info::FaceLEDPanelMask<<9), //4
+
+	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 8)
+	|(ERS7Info::FaceLEDPanelMask<<9)|(ERS7Info::FaceLEDPanelMask<<11), //5
+
+	(ERS7Info::FaceLEDPanelMask<< 0)|(ERS7Info::FaceLEDPanelMask<< 1)|(ERS7Info::FaceLEDPanelMask<< 4)
+	|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7), //6
+
+	(ERS7Info::FaceLEDPanelMask<< 0)|(ERS7Info::FaceLEDPanelMask<< 1)|(ERS7Info::FaceLEDPanelMask<< 4)
+	|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7)
+	|(ERS7Info::FaceLEDPanelMask<<11), //7
+
+	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 4)
+	|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7)
+	|(ERS7Info::FaceLEDPanelMask<< 8)|(ERS7Info::FaceLEDPanelMask<<9), //8
+
+	(ERS7Info::FaceLEDPanelMask<< 2)|(ERS7Info::FaceLEDPanelMask<< 3)|(ERS7Info::FaceLEDPanelMask<< 4)
+	|(ERS7Info::FaceLEDPanelMask<<5)|(ERS7Info::FaceLEDPanelMask<< 6)|(ERS7Info::FaceLEDPanelMask<< 7)
+	|(ERS7Info::FaceLEDPanelMask<< 8)|(ERS7Info::FaceLEDPanelMask<<9)|(ERS7Info::FaceLEDPanelMask<<11), //9
+
 	(ERS7Info::FaceLEDPanelMask<< 1) //.
 };
 
 
-LedEngine::LedEngine() : numCycling(0), dirty(true), dirtyTime((unsigned int)-1) {
+LedEngine::LedEngine() : dirty(true), numCycling(0), nextFlashEnd((unsigned int)-1) {
 	for(unsigned int i=0; i<NumLEDs; i++) {
 		infos[i].flashtime=0;
 		infos[i].starttime=0;
@@ -73,45 +124,53 @@ LedEngine::LedEngine() : numCycling(0), dirty(true), dirtyTime((unsigned int)-1)
 	clear();
 }
 
+void LedEngine::recalcFlashEnd(void) {
+  unsigned int t = get_time();
+  nextFlashEnd=(unsigned int)-1;
+  for(unsigned int i=0; i<NumLEDs; i++)
+    if(infos[i].flashtime>t && nextFlashEnd>infos[i].flashtime)
+      nextFlashEnd=infos[i].flashtime;
+}
+
 int LedEngine::isDirty() {
 	unsigned int t = get_time();
-	if(t>dirtyTime) {
-		dirty=true;
-		dirtyTime=(unsigned int)-1;
-		for(unsigned int i=0; i<NumLEDs; i++)
-			if(infos[i].flashtime>t && dirtyTime>infos[i].flashtime)
-				dirtyTime=infos[i].flashtime;
-	}
-	return (dirty || numCycling>0);
+	if(t>nextFlashEnd) {
+	  dirty=true;
+	  recalcFlashEnd();
+	};
+	return dirty;
 }
 
 int LedEngine::updateLEDs(const MotionCommand* caller, LEDBitMask_t mask/*=AllLEDMask*/) {
 	unsigned int t = get_time();
+	if (t>nextFlashEnd) recalcFlashEnd();
 	for(unsigned int i=0; i<NumLEDs; i++)
 		if((mask>>i)&1)
 			for(unsigned int f=0; f<NumFrames; f++)
 				motman->setOutput(caller, i+LEDOffset,calcValue(i,t+f*FrameTime),f);
 	bool tmp=dirty;
-	dirty=false;
+	dirty = numCycling>0;
 	return tmp;
 }
 
 int LedEngine::updateLEDs(OutputCmd cmds[NumLEDs]) {
 	unsigned int t = get_time();
+	if (t>nextFlashEnd) recalcFlashEnd();
 	for(unsigned int i=0; i<NumLEDs; i++)
 			cmds[i].value=calcValue(i,t);
 	bool tmp=dirty;
-	dirty=false;
+	dirty = numCycling>0;
 	return tmp;
 }
 
 int LedEngine::updateLEDFrames(OutputCmd cmds[NumLEDs][NumFrames]) {
 	unsigned int t = get_time();
+	if (t>nextFlashEnd) recalcFlashEnd();
 	for(unsigned int i=0; i<NumLEDs; i++)
 		for(unsigned int f=0; f<NumFrames; f++)
 			cmds[i][f].value=calcValue(i,t+f*FrameTime);
 	bool tmp=dirty;
-	dirty=false;
+	dirty = numCycling>0;
 	return tmp;
 }
 
@@ -142,8 +201,8 @@ void LedEngine::set(LEDBitMask_t leds, float value) {
 void LedEngine::cflash(LEDBitMask_t leds, float value, unsigned int ms) {
 	dirty=true;
 	unsigned int t = get_time();
-	if(t+ms<dirtyTime)
-		dirtyTime=t+ms;
+	if(t+ms<nextFlashEnd)
+	  nextFlashEnd=t+ms;
 	for(unsigned int i=0; i<NumLEDs; i++) {
 		infos[i].flashvalue=((leds>>i)&1)*value;
 		infos[i].flashtime=t+ms;
@@ -153,8 +212,8 @@ void LedEngine::flash(LEDBitMask_t leds, float value, unsigned int ms) {
 	if(leds!=0) {
 		dirty=true;
 		unsigned int t = get_time();
-		if(t+ms<dirtyTime)
-			dirtyTime=t+ms;
+		if(t+ms<nextFlashEnd)
+		  nextFlashEnd=t+ms;
 		for(unsigned int i=0; i<NumLEDs; i++)
 			if((leds>>i)&1) {
 				infos[i].flashvalue=value;
@@ -166,8 +225,8 @@ void LedEngine::flash(LEDBitMask_t leds, unsigned int ms) {
 	if(leds!=0) {
 		dirty=true;
 		unsigned int t = get_time();
-		if(t+ms<dirtyTime)
-			dirtyTime=t+ms;
+		if(t+ms<nextFlashEnd)
+		  nextFlashEnd=t+ms;
 		for(unsigned int i=0; i<NumLEDs; i++)
 			if((leds>>i)&1) {
 				infos[i].flashvalue=calcFlash(calcValue(i,t));
@@ -332,9 +391,9 @@ void LedEngine::setColumn(float x, unsigned int low, unsigned int mid, unsigned
  * @brief Implements LedEngine, which provides basic LED effects to anything that inherits or instantiates it
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.12 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2004/02/03 01:17:57 $
+ * $Date: 2004/09/12 04:22:37 $
  */
