@@ -14,8 +14,8 @@ class MotionCommand;
 /*! Provides a collection of special effects so that the code can be
  *  reused various places as feedback to to the user.
  *
- * Cycling ("pulsing") and single-value setting are mutually exclusive
- * - one will cut off the other
+ * Cycling ("pulsing") and single-value setting are mutually exclusive;
+ * one will cut off the other
  *
  * A flash will invert and override the current setting, so that it
  * will "reset" after the flash.  Flashes change mid-range values to
@@ -31,8 +31,8 @@ class MotionCommand;
  *
  * The ERS-220 and ERS-7 have enough LEDs that they just use a "count
  * the lights" style of display instead of this pseudo-arabic display.
- * (look close to see that green bar LED at the top of the 210, this
- * isn't actually too hard to read once you "see" it)
+ * (look close to see that green bar LED at the top of the 210, which 
+ * doesn't show up well in the camera image for some reason. )
  */
 
 class LedEngine {
@@ -55,7 +55,10 @@ class LedEngine {
 	/*! @param cmds on input, used for weight values - on return, holds the resulting OutputCmd's*/
 	int updateLEDFrames(OutputCmd cmds[NumLEDs][NumFrames]);
 	
-	//!returns true if there are changes since the last updateLEDs()
+	//! recalculates #nextFlashEnd so we can tell when a flash has completed
+	void recalcFlashEnd();
+
+	//! returns true if there are changes since the last updateLEDs()
 	int isDirty();
 
 	//!sets the leds specified by @a leds to the inverse of their current value
@@ -160,20 +163,20 @@ class LedEngine {
 	};
 	
 	LEDInfo infos[NumLEDs]; //!< the information regarding each of the LEDs
+	bool dirty;             //!< true if changes since last updateLEDs: either at least one LED is cycling or a flash has begun/ended
 	unsigned int numCycling;//!< the number of LEDs currently cycling (if non-zero, always dirty)
-	bool dirty;             //!< true if changes since last updateLEDs
-	unsigned int dirtyTime; //!< the time at which it becomes dirty again (if flashing)
+	unsigned int nextFlashEnd; //!< the soonest time a flash will end (and we'll become dirty)
 };
 	
 /*! @file
  * @brief Describes LedEngine, which provides basic LED effects to anything that inherits or instantiates it
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.13 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/09/12 04:22:37 $
  */
 
 #endif
