@@ -2,6 +2,8 @@
 #ifndef INCLUDED_LedMC_h
 #define INCLUDED_LedMC_h
 
+#include "Events/EventBase.h"
+#include "Events/EventRouter.h"
 #include "MotionCommand.h"
 #include "LedEngine.h"
 #include "OutputCmd.h"
@@ -13,43 +15,52 @@
  *  just use the engine component to do all the work. */
 class LedMC : public MotionCommand, public LedEngine {
  public:
-	//! constructor
-	LedMC() : MotionCommand(), LedEngine() { setWeights(AllLEDMask,1); }
-	//! destructor
-	virtual ~LedMC() {}
+  //! constructor
+  LedMC() : MotionCommand(), LedEngine(), notified(true) { setWeights(AllLEDMask,1); }
+  //! destructor
+  virtual ~LedMC() {}
+  
+  //! updates the cmds from LedEngine::updateLEDs()
+  virtual int updateOutputs() {
+    updateLEDFrames(cmds);
+    for(unsigned int i=0; i<NumLEDs; i++)
+      if(cmds[i][0].weight!=0)
+	motman->setOutput(this,i+LEDOffset,cmds[i]);
+    if (nextFlashEnd < (unsigned int)-1)  // do we have a flash in progress?
+      notified=false;
+    else if (notified == false) {  // flash has ended (nextFlashEnd == -1), but notice not yet sent
+      postEvent(EventBase(EventBase::motmanEGID,getID(),EventBase::statusETID));
+      notified=true;
+    };
+    return NumLEDs;
+  }
 
-	//! updates the cmds from LedEngine::updateLEDs()
-	virtual int updateOutputs() {
-		updateLEDFrames(cmds);
-		for(unsigned int i=0; i<NumLEDs; i++)
-			if(cmds[i][0].weight!=0)
-				motman->setOutput(this,i+LEDOffset,cmds[i]);
-		return NumLEDs;
-	}
-	virtual int isDirty() { return LedEngine::isDirty(); }
-	virtual int isAlive() { return true; } //!< @todo let's make this smarter so you can flash the LED's and have it autoprune
+  virtual int isDirty() { return LedEngine::isDirty(); }
 
-	//! Sets the JointCmd::weight of the LEDs specified by @a leds to @a weight
-	void setWeights(LEDBitMask_t leds, float weight) {
-		for(unsigned int i=0; i<NumLEDs; i++)
-			if((leds>>i)&1)
-				for(unsigned int f=0; f<NumFrames; f++)
-					cmds[i][f].weight=weight;
-	}
+  virtual int isAlive() { return LedEngine::isDirty() || nextFlashEnd < (unsigned int)-1; }
+
+  //! Sets the JointCmd::weight of the LEDs specified by @a leds to @a weight
+  void setWeights(LEDBitMask_t leds, float weight) {
+    for(unsigned int i=0; i<NumLEDs; i++)
+      if((leds>>i)&1)
+	for(unsigned int f=0; f<NumFrames; f++)
+	  cmds[i][f].weight=weight;
+  }
 
 protected:
-	OutputCmd cmds[NumLEDs][NumFrames]; //!< needed to store weight values of LEDs (useful to mark LEDs as unused)
+  OutputCmd cmds[NumLEDs][NumFrames]; //!< needed to store weight values of LEDs (useful to mark LEDs as unused)
+  bool notified; //!< set to true when we've posted a status event for completion of a flash/cflash
 };
 
 /*!@file
  * @brief Defines LedMC, which provides a basic MotionCommand wrapper to LedEngine
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.6 $
- * $State: Rel $
- * $Date: 2003/09/25 15:27:23 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.7 $
+ * $State: Exp $
+ * $Date: 2004/09/10 22:25:15 $
  */
 
 #endif
