@@ -19,11 +19,7 @@ const float MotionManager::kStdPriority        = 10;
 const float MotionManager::kHighPriority       = 50;
 const float MotionManager::kEmergencyPriority  = 100;
 
-#ifndef PLATFORM_APERIOS
-using std::cout;
-using std::endl;
-#endif
-
+using namespace std;
 
 //! just for convenience
 typedef unsigned int uint;
@@ -497,19 +493,43 @@ MotionManager::updatePIDs(OPrimitiveID primIDs[NumOutputs]) {
 	return dirty;
 }
 
-// documentation for this function is at the end of the file
+/*! @deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises */
 MotionManager::MC_ID
 MotionManager::addMotion(const SharedObjectBase& sm) {
-	//cout << "addMotion...";
-	while(numAcc<MAX_ACCESS-1) { std::cout << "WAIT" << std::flush; } //Wait for everyone to register
-	func_begin();
-	//cout << cmdlist.size() << " exist..." << endl;
-	//	cout << id << "..." << flush;
+	return doAddMotion(sm,true,kStdPriority);
+}
+/*! @deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises */
+MotionManager::MC_ID 
+MotionManager::addMotion(const SharedObjectBase& sm, bool autoprune) {
+	return doAddMotion(sm,autoprune,kStdPriority);
+}
+/*! @deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises */
+MotionManager::MC_ID
+MotionManager::addMotion(const SharedObjectBase& sm, float priority) {
+	return doAddMotion(sm,true,priority);
+}
+/*! @deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises */
+MotionManager::MC_ID 
+MotionManager::addMotion(const SharedObjectBase& sm, float priority, bool autoprune) {
+	return doAddMotion(sm,autoprune,priority);
+}
+/*! We have made this function protected because it's more readable if you
+ *  call addPrunableMotion() or addPersistentMotion() instead... we decided
+ *  requiring people to pass a true/false arguement wouldn't make it clear
+ *  what that true/false was controlling. */
+MotionManager::MC_ID 
+MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float priority) {
 	MotionCommand * mc = dynamic_cast<MotionCommand*>(reinterpret_cast<MotionManagerMsg*>(sm.data()));
 	if(mc==NULL) {
 		cout << "MotionManager::addMotion() - SharedObject does not seem to hold a MotionCommand" << endl;
 		return invalid_MC_ID;
 	}
+	mc->setAutoPrune(autoprune);
+	//cout << "addMotion...";
+	while(numAcc<MAX_ACCESS-1) { std::cout << "WAIT" << std::flush; } //Wait for everyone to register
+	func_begin();
+	//cout << cmdlist.size() << " exist..." << endl;
+	//	cout << id << "..." << flush;
 	MC_ID mc_id = pop_free();
 	if(mc_id==cmdlist.end()) {
 		cout << "MotionManager::addMotion() - Out of room, could not add" << endl;
@@ -521,7 +541,7 @@ MotionManager::addMotion(const SharedObjectBase& sm) {
 	cmdlist[mc_id].rcr[_MMaccID]->AddReference();
 	//cout << "addMotion()NOW: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
 	cmdlist[mc_id].lastAccessor=_MMaccID;
-	cmdlist[mc_id].priority=kStdPriority;
+	cmdlist[mc_id].priority=priority;
 	mc->setAdd(mc_id);
 	OStatus err;
 	/*{
@@ -537,38 +557,6 @@ MotionManager::addMotion(const SharedObjectBase& sm) {
 	//	cout << "addMotion-done" << endl;
 	return func_end(mc_id);
 }
-MotionManager::MC_ID 
-MotionManager::addMotion(const SharedObjectBase& sm, float priority) {
-	func_begin();
-	MC_ID mcid=addMotion(sm);
-	if(mcid!=end())
-		setPriority(mcid,priority);
-	return func_end(mcid);
-}
-MotionManager::MC_ID 
-MotionManager::addMotion(const SharedObjectBase& sm, bool autoprune) {
-	MotionCommand * mc = dynamic_cast<MotionCommand*>(reinterpret_cast<MotionManagerMsg*>(sm.data()));
-	if(mc==NULL) {
-		cout << "MotionManager::addMotion() - SharedObject does not seem to hold a MotionCommand" << endl;
-		return invalid_MC_ID;
-	}
-	mc->setAutoPrune(autoprune);
-	return addMotion(sm); 
-}
-MotionManager::MC_ID 
-MotionManager::addMotion(const SharedObjectBase& sm, float priority, bool autoprune) {
-	func_begin();
-	MotionCommand * mc = dynamic_cast<MotionCommand*>(reinterpret_cast<MotionManagerMsg*>(sm.data()));
-	if(mc==NULL) {
-		cout << "MotionManager::addMotion() - SharedObject does not seem to hold a MotionCommand" << endl;
-		return invalid_MC_ID;
-	}
-	mc->setAutoPrune(autoprune);
-	MC_ID mcid=addMotion(sm);
-	if(mcid!=end())
-		setPriority(mcid,priority);
-	return func_end(mcid);
-}
 
 void
 MotionManager::receivedMsg(const ONotifyEvent& event) {
@@ -588,7 +576,7 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 			//should be able to do a nice dynamic cast instead of a static one
 			// but it gives NULL for some reason - i blame having to do the fork trick
 			cmdlist[mc_id].baseaddrs[_MMaccID]=static_cast<MotionCommand*>(mminfo);
-			erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::activateETID,00));
+			erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::activateETID,0));
 			cmdlist[mc_id].baseaddrs[_MMaccID]->DoStart();
 		} break;
 		case MotionManagerMsg::deleteMotion: {
@@ -650,7 +638,7 @@ MotionManager::removeMotion(MC_ID mcid) {
 	func_begin();
 	checkoutMotion(mcid,true);
 	cmdlist[mcid].baseaddrs[_MMaccID]->DoStop();
-	erouter->postEvent(new EventBase(EventBase::motmanEGID,mcid,EventBase::deactivateETID,00));
+	erouter->postEvent(new EventBase(EventBase::motmanEGID,mcid,EventBase::deactivateETID,0));
 #ifdef PLATFORM_APERIOS
 	MotionManagerMsg dmsg;
 	dmsg.setDelete(mcid);
@@ -678,10 +666,10 @@ MotionManager::setPID(unsigned int joint, const float pids[3]) {
 	for(uint u = pidchanges.begin(); u!=pidchanges.end(); u=pidchanges.next(u)) {
 		if(pidchanges[u].joint==joint) { //found it
 			for(uint i=0; i<3; i++) {
-				pidchanges[i].pids[i]=pids[i];
+				pidchanges[u].pids[i]=pids[i];
 				if(pids[i]!=state->pids[joint][i]) { //see if we're setting back to current PID
 					for(i++; i<3; i++) //we aren't, copy over the rest
-						pidchanges[i].pids[i]=pids[i];
+						pidchanges[u].pids[i]=pids[i];
 					func_end();
 					return;
 				}
@@ -760,10 +748,10 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.34 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.38 $
  * $State: Exp $
- * $Date: 2004/02/07 01:02:29 $
+ * $Date: 2004/10/17 01:16:11 $
  */
 
 
