@@ -35,7 +35,7 @@
  *  one line:
  *
  *  @code
- *  motman->addMotion(SharedObject<YourMC>([arg1,[arg2,...]]) [, priority [, autoprune] ]);
+ *  motman->addMotion( SharedObject<YourMC>([arg1,...]) , autoprune [, priority ]);
  *  @endcode
  *  
  *  But if you want to do some more initializations not handled by the
@@ -47,7 +47,7 @@
  *  tmpvar->cmd1();
  *  tmpvar->cmd2();
  *  //...
- *  motman->addMotion(tmpvar [, ...]);
+ *  motman->addPrunableMotion(tmpvar [, ...]); //or addPersistentMotion(...)
  *  @endcode
  *
  *  Notice that tmpvar is of type SharedObject, but you're calling @c
@@ -124,14 +124,23 @@ public:
 	//!@name MotionCommand Unsafe
 	//@{
 #ifdef PLATFORM_APERIOS
-	MC_ID addMotion(const SharedObjectBase& sm); //!< @b LOCKS @b MotionManager Creates a new MotionCommand, automatically sharing it between processes (there is some lag time here)
-	MC_ID addMotion(const SharedObjectBase& sm, float priority); //!< @b LOCKS @b MotionManager allows a quick way to set a priority level of a new MotionCommand
-	MC_ID addMotion(const SharedObjectBase& sm, bool autoprune); //!< @b LOCKS @b MotionManager allows a quick was to set the autoprune flag
-	MC_ID addMotion(const SharedObjectBase& sm, float priority, bool autoprune); //!< @b LOCKS @b MotionManager Call one of these to add a MotionCommand to the MotionManager, using the SharedObject class
+	//! @b LOCKS @b MotionManager adds a new motion (wrapped in a SharedObject) and marks that it should be automatically deleted when the MotionCommand::isAlive() returns false.
+	MC_ID addPrunableMotion(const SharedObjectBase& sm, float priority=kStdPriority) { return doAddMotion(sm,true,priority); }
+	//! @b LOCKS @b MotionManager adds a new motion (wrapped in a SharedObject) and marks that it should @e not be deleted, until removeMotion(MC_ID mcid) is called.
+	MC_ID addPersistentMotion(const SharedObjectBase& sm, float priority=kStdPriority) { return doAddMotion(sm,false,priority); }
 #endif //PLATFORM_APERIOS
 	void removeMotion(MC_ID mcid); //!< @b LOCKS @b MotionManager removes the specified MotionCommand
 	//@}
 
+	//!@name Deprecated
+#ifdef PLATFORM_APERIOS
+	MC_ID addMotion(const SharedObjectBase& sm) __attribute__((deprecated)); //!< deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises
+	MC_ID addMotion(const SharedObjectBase& sm, bool autoprune) __attribute__((deprecated)); //!< deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises
+	MC_ID addMotion(const SharedObjectBase& sm, float priority) __attribute__((deprecated)); //!< deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises
+	MC_ID addMotion(const SharedObjectBase& sm, float priority, bool autoprune) __attribute__((deprecated)); //!< deprecated, we're recommending users call either addPrunableMotion() or addPersistentMotion() so there are no surprises
+#endif //PLATFORM_APERIOS
+	//@}
+
 	//@{
 	void lock()    { MMlock.lock(_MMaccID); } //!< gets an exclusive lock on MotionManager - functions marked @b LOCKS @b MotionManager will cause (and require) this to happen automatically
 	bool trylock() { return MMlock.try_lock(_MMaccID); } //!< tries to get a lock without blocking
@@ -166,6 +175,11 @@ public:
 	};
 
 protected:
+#ifdef PLATFORM_APERIOS
+	//!does the actual work of adding a motion
+	MC_ID doAddMotion(const SharedObjectBase& sm, bool autoprune, float priority);
+#endif
+	
 	//! used to request pids for a given joint
 	struct PIDUpdate {
 		//!constructor
@@ -245,10 +259,10 @@ extern MotionManager * motman;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/10/18 23:10:26 $
  */
 
 #endif
