@@ -44,21 +44,61 @@
  *  @see MotionSequence::SizeSmall, MotionSequence::SizeMedium, MotionSequence::SizeLarge, MotionSequence::SizeXLarge, 
  *  
  *  The file format used is as follows: ('<' and '>' are not meant literally)
- *  @verbatim
- *       First line: #MSq
- *  Zero or more of: delay <time-delta>              (moves playhead forward, in milliseconds)
- *               or: settime <time>                  (sets play time to specified value, in ms)
- *               or: <outputname> <value> [<weight>] (sets the specified output to the value - assumes 1 for weight)
- *               or: load <filename>                 (file is a posture, sets position)
- *               or: overlay <filename>              (file can be a posture or another motion sequence)
- *               or: degrees                         (following <value>s will be interpreted as degrees [default])
- *               or: radians                         (following <value>s will be interpreted as radians)
- *        Last line: #END
- *  @endverbatim
- *  After loading a motion sequence, the playtime is left at the end.
- *  This is to make it easy to append/overlay motion sequences
+ *  - First line: '<tt>#MSq</tt>'
+ *  - Followed by any series of:\n
+ *    - '<tt>delay </tt><i>time-delta</i>' - moves playhead forward, in milliseconds
+ *    - '<tt>settime </tt><i>time</i>' - sets play time to specified value, in ms
+ *    - '<i>outputname</i><tt> </tt><i>value</i><tt> </tt>[<i>weight</i>]' - sets the specified output to the value - assumes 1 for weight; you can view the list of valid joint names in the outputNames array within the RobotInfo extension namespace for your model.  (e.g. ERS210Info::outputNames[])
+ *    - '<tt>load </tt><i>filename</i>' - file is a posture, sets position
+ *    - '<tt>overlay </tt><i>filename</i>' - file can be a posture or another motion sequence
+ *    - '<tt>degrees</tt>' - following <i>value</i>s will be interpreted as degrees [default]
+ *    - '<tt>radians</tt>' - following <i>value</i>s will be interpreted as radians
+ *    - '<tt>#</tt><i>comment</i>' - a comment line
+ *  - Last line: '<tt>#END</tt>'
  *  
- *  Lines beginning with '#' are ignored.  Output names are defined in RobotInfo.h, RobotInfo::outputNames.
+ *  After loading a motion sequence, the playtime is left at the end.
+ *  This is to make it easy to append/overlay motion sequences.
+ *  However, the playhead will be reset to the beginning on the first
+ *  call to updateOutputs() if isPlaying() returns true.
+ *
+ *  You can also create a MotionSequence dynamically at run time:
+ *  \code
+ *  //This code sample will stand up, point the head forward and up 0.1 radians,
+ *  //and then autoprune
+ *
+ *  //First declare the MotionSequence itself:
+ *  SharedObject< MotionSequenceMC<MotionSequence::SizeSmall> > stand;
+ *
+ *  //Over the course of 700 milliseconds, go to standing posture:
+ *  standSit->setPlayTime(700);
+ *  standSit->setPose(PostureEngine("/ms/data/motion/stand.pos"));
+ *
+ *  //Then take another 700 milliseconds to straighten out the head:
+ *  standSit->setPlayTime(700);
+ *  //We'll set joints individually this time, instead of loading a posture file:
+ *  standSit->setOutputCmd(HeadOffset+PanOffset,0);
+ *  standSit->setOutputCmd(HeadOffset+RollOffset,0);
+ *  standSit->setOutputCmd(HeadOffset+TiltOffset,0.1); //look up .1 radians
+ *
+ *  //Add to MotionManager:
+ *  motman->addMotion(standSit);
+ *  //Playback will now begin automatically, and region deallocated when done
+ *  \endcode
+ *  
+ *  By default, #playing is true.  Thus, when you add a MotionSequence
+ *  to the MotionManager, it will begin executing automatically.  If
+ *  you do \e not want this behavior, simply call pause() before
+ *  adding the sequence.
+ *
+ *  When the sequence reaches the end, isAlive() will return false.
+ *  By default, the motion sequence will autoprune itself from the
+ *  MotionManager.  However, you can either pass \c false to
+ *  MotionManager::addMotion(), or call setAutoPrune(false).
+ *  
+ *  Lines beginning with '#' are ignored as comments.  Be aware if you
+ *  load the file and then save it again, these comments will be lost.
+ *  
+ *  @see PostureEngine for information on the posture files
  */
 class MotionSequence : public MotionCommand, public LoadSave {
 public:
@@ -86,6 +126,8 @@ public:
 	virtual unsigned int getBinSize() const; //!< inherited, returns the size used to save the sequence
 	virtual unsigned int LoadBuffer(const char buf[], unsigned int len); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
 	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
+	virtual unsigned int LoadFile(const char filename[]); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
+	virtual unsigned int SaveFile(const char filename[]) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
 	void setSaveDegrees() { loadSaveMode=M_PI/180; }       //!< will store angles as degrees on future saves
 	bool isSaveDegrees() const { return loadSaveMode!=1; } //!< returns true if will store angles as degrees on future saves
 	void setSaveRadians() { loadSaveMode=1; }              //!< will store angles as radians on future saves
@@ -159,12 +201,6 @@ protected:
 	//!Sets prev and next to the appropriate values for the given time and output index
 	virtual void setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const=0;
 
-	//!used by LoadBuffer()/SaveBuffer(), checks to see if the amount read/written (@a res) is nonzero, increments @a buf, decrements @a len, or displays @a msg if @a is zero
-	static bool ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg);
-
-	//!used by LoadBuffer()/SaveBuffer(), checks to see if the amount read/written (@a res) is nonzero, increments @a buf, decrements @a len, or displays @a msg with @a arg1 if @a is zero
-	static bool ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg, int arg1);
-
 	//!sets playtime to next time for which any output has a keyframe, -1 if none exists
 	unsigned int setNextFrameTime(Move_idx_t p[NumOutputs], Move_idx_t n[NumOutputs]) const;
 	
@@ -185,9 +221,19 @@ template<unsigned int MAXMOVE>
 class MotionSequenceMC : public MotionSequence {
 public:
 	//!constructor
-	MotionSequenceMC() : MotionSequence(), moves() {clear();}
+	MotionSequenceMC()
+		: MotionSequence(), moves()
+	{
+		clear();
+	}
 	//!constructor, loads from a file and then resets the playtime to beginning and begins to play
-	explicit MotionSequenceMC(const char* filename) : MotionSequence(), moves() {clear();LoadFile(filename);setPlayTime(1);}
+	explicit MotionSequenceMC(const char* filename)
+		: MotionSequence(), moves()
+	{
+		clear();
+		LoadFile(filename);
+		setPlayTime(1);
+	}
 	//!destructor
 	virtual ~MotionSequenceMC() {}
 
@@ -268,7 +314,12 @@ protected:
 
 	virtual Move& getKeyFrame(Move_idx_t x) { return moves[x]; }
 	virtual const Move& getKeyFrame(Move_idx_t x) const { return moves[x]; }
-	virtual Move_idx_t newKeyFrame() { return moves.new_front(); }
+	virtual Move_idx_t newKeyFrame() {
+		Move_idx_t i=moves.new_front();
+		if(i==invalid_move)
+			serr->printf("ERROR: MotionSequenceMC %d has run out of memory\n",getID());
+		return i;
+	}
 	virtual void eraseKeyFrame(Move_idx_t x) { moves.erase(x); }
 	void setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const {
 		if(next!=invalid_move && moves[next].starttime<=t) {
@@ -276,11 +327,11 @@ protected:
 				prev=next;
 				next=moves[prev].next;
 			} while(next!=invalid_move && moves[next].starttime<=t);
-		} else if(t<moves[prev].starttime) {
-			do {
+		} else {
+			while(moves[prev].prev!=invalid_move && t<moves[prev].starttime) {
 				next=prev;
 				prev=moves[next].prev;
-			} while(t<moves[prev].starttime);
+			} 
 		}
 	}
 };
@@ -290,10 +341,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2004/02/19 23:08:09 $
+ * $Date: 2004/10/14 19:24:46 $
  */
 
 #endif
