@@ -1,5 +1,7 @@
 #include "PostureEngine.h"
 #include "Shared/WorldState.h"
+#include "Motion/roboop/robot.h"
+#include "Shared/Config.h"
 #include <stdio.h>
 
 PostureEngine::~PostureEngine() {}
@@ -9,6 +11,11 @@ void PostureEngine::takeSnapshot() {
 		cmds[i].set(state->outputs[i],1);
 }
 
+void PostureEngine::takeSnapshot(const WorldState* st) {
+	for(unsigned int i=0; i<NumOutputs; i++)
+		cmds[i].set(st->outputs[i],1);
+}
+
 void PostureEngine::clear() {
 	for(unsigned int i=0; i<NumOutputs; i++)
 		cmds[i].unset();
@@ -109,7 +116,6 @@ float PostureEngine::maxdiff(const PostureEngine& pe) const {
 	for(unsigned int i=0; i<NumOutputs; i++)
 		if(cmds[i].weight>0 && pe.cmds[i].weight>0) {
 			float dif=cmds[i].value-pe.cmds[i].value;
-			dif*=dif;
 			if(dif>max)
 				max=dif;
 		}
@@ -128,31 +134,60 @@ unsigned int PostureEngine::getBinSize() const {
 unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
 	clear();
-	if(strncmp("#POS\n",buf,5)!=0) {
-		//		std::cout << "ERROR PostureEngine load corrupted - expected #POS header" << std::endl;
+	if(strncmp("#POS",buf,4)!=0) {
+		// we don't want to display an error here because we may be only testing file type,
+		// so it's up to the caller to decide if it's necessarily an error if the file isn't
+		// a posture
+		//std::cout << "ERROR PostureEngine load corrupted - expected #POS header" << std::endl;
 		return 0;
 	}
 	char formatstring[64];
-	snprintf(formatstring,64,"%%%dc %%f %%f\n%%n",outputNameLen); //std::cout << "Format: " << formatstring << std::endl;
+	snprintf(formatstring,64,"%%%dc %%f %%f%%n",outputNameLen); //std::cout << "Format: " << formatstring << std::endl;
 	unsigned int idx=0;
-	unsigned int linenum=2;
+	unsigned int linenum=1;
 	char jname[outputNameLen+1];
 	jname[outputNameLen]='\0';
 	while(len<=origlen && len>0) {
-		float fval, fwht;
+		float fval, fwht=1;
 		int written;
 		//		printf("%d %.9s\n",linenum+1,buf);
-		if(buf[0]=='#' || buf[0]=='\n') {
-			if(strncmp("#END\n",buf,5)==0)
-				return origlen-len;
-			else {
-				while(*buf++!='\n') {}
+		if(buf[0]=='\r') {
+			buf++; len--;
+			if(buf[0]=='\n') {
+				buf++; len--;
+			}
+			linenum++;
+			continue;
+		}
+		if(buf[0]=='\n') {
+			buf++; len--;
+			linenum++;
+			continue;
+		}
+		if(buf[0]=='#') {
+			if(strncmp("#END\n",buf,5)==0 || strncmp("#END\r",buf,5)==0) {
+				return origlen-len+5;
+			} else if(strncmp("#END\r\n",buf,6)==0) {
+				return origlen-len+6;
+			} else {
+				while(len>0 && *buf!='\n' && *buf!='\r') {len--;buf++;}
+				if(*buf=='\n') { //in case of \r\n
+					buf++;
+					len--;
+				}
+				linenum++;
 				continue;
 			}
 		}
 		written=-1;
 		sscanf(buf,formatstring,jname,&fval,&fwht,&written);
 		if(!ChkAdvance(written,&buf,&len,"*** ERROR PostureEngine load corrupted - line %d\n",linenum)) return 0;
+		while(*buf!='\n' && *buf!='\r')
+			buf++;
+		if(buf[0]=='\r' && buf[1]=='\n')
+			buf+=2;
+		else
+			buf++;
 		linenum++;
 		//std::cout << '"' << jname << "\"\t" << (float)fval << '\t' << (float)fwht << std::endl;
 		unsigned int startidx=idx+1;
@@ -168,7 +203,7 @@ unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 					break;
 			}
 			if(idx==startidx && strcmp(jname,outputNames[idx])!=0)
-				std::cout << "*** WARNING " << jname << " is not a valid joint on this model." << endl;
+				std::cout << "*** WARNING " << jname << " is not a valid joint on this model." << std::endl;
 		}
 	}
 	std::cout << "*** WARNING PostureEngine load missing #END" << std::endl;
@@ -202,25 +237,91 @@ unsigned int PostureEngine::SaveBuffer(char buf[], unsigned int len) const {
 	return origlen-len;
 }
 
-bool PostureEngine::ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg) {
-	if(res>0) {
-		*buf+=res;
-		*len-=res;
-		return true;
-	} else {
-		printf("%s",msg);
-		return false;
-	}
+unsigned int PostureEngine::LoadFile(const char filename[]) {
+	return LoadSave::LoadFile(config->motion.makePath(filename).c_str());
+}
+unsigned int PostureEngine::SaveFile(const char filename[]) const {
+	return LoadSave::SaveFile(config->motion.makePath(filename).c_str());
 }
 
-bool PostureEngine::ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg, int arg1) {
-	if(res>0) {
-		*buf+=res;
-		*len-=res;
-		return true;
-	} else {
-		printf(msg,arg1);
+/*
+NEWMAT::ReturnMatrix
+Kinematics::getOrientation(unsigned int j) {
+	unsigned int c=-1U,l=-1U;
+	if(!lookup(j,c,l)) {
+		NEWMAT::Matrix A(4,4);
+		A<<ROBOOP::fourbyfourident;
+		A.Release(); return A;
+	}
+	update(c,l);
+	NEWMAT::Matrix R;
+	NEWMAT::ColumnVector p;
+	chains[c]->kine(R,p,j);
+	R.Release(); return R;
+}
+
+NEWMAT::ReturnMatrix
+Kinematics::getPosition(unsigned int j) {
+	unsigned int c=-1U,l=-1U;
+	if(!lookup(j,c,l)) {
+		NEWMAT::Matrix A(4,4);
+		A<<ROBOOP::fourbyfourident;
+		A.Release(); return A;
+	}
+	update(c,l);
+	NEWMAT::Matrix R;
+	NEWMAT::ColumnVector p;
+	chains[c]->kine(R,p,j);
+	p.Release(); return p;
+}
+*/
+
+bool
+PostureEngine::solveLinkPosition(const NEWMAT::ColumnVector& Pobj, unsigned int j, const NEWMAT::ColumnVector& Plink) {
+	unsigned int c=-1U,l=-1U;
+	if(!lookup(j,c,l))
 		return false;
+	update(c,l);
+	bool conv=false;
+	NEWMAT::ColumnVector q=chains[c]->inv_kin_pos(Pobj,0,l,Plink,conv);
+	for(unsigned int i=1; i<=l && i<=chainMaps[c].size(); i++)
+		if(chainMaps[c][i]<NumOutputs)
+			setOutputCmd(chainMaps[c][i],chains[c]->get_q(i));
+	return conv;
+}
+
+bool
+PostureEngine::solveLinkVector(const NEWMAT::ColumnVector& Pobj, unsigned int j, const NEWMAT::ColumnVector& Plink) {
+	solveLinkPosition(Pobj,j,Plink);
+	//This method is an approximation, not entirely precise or fast as it could be
+	//Something to work on some more down the road! :)
+	NEWMAT::ColumnVector poE=baseToLink(j)*Pobj;
+	if(poE.nrows()>3 && poE(4)!=0) {
+		poE/=poE(4);
+	}
+	poE=poE.SubMatrix(1,3,1,1);
+	NEWMAT::ColumnVector plE=Plink.SubMatrix(1,3,1,1);
+	if(Plink.nrows()>3 && Plink(4)!=0)
+		plE/=Plink(4);
+	float plE2=plE.SumSquare();
+	float plE_len=sqrt(plE2);
+	float obj_comp_link=NEWMAT::DotProduct(plE,poE)/plE_len;
+	if(obj_comp_link<plE_len)
+		obj_comp_link=obj_comp_link*.975; //.975 is a bit of fudge - accounts for joints moving Plink when adjusting
+	else
+		obj_comp_link=obj_comp_link/.975; //.975 is a bit of fudge - accounts for joints moving Plink when adjusting
+	NEWMAT::ColumnVector obj_proj_link(4);
+	obj_proj_link.SubMatrix(1,3,1,1)=obj_comp_link*plE/plE_len;
+	obj_proj_link(4)=1;
+	return solveLinkPosition(Pobj,j,obj_proj_link);
+}
+
+void
+PostureEngine::update(unsigned int c, unsigned int l) {
+	for(unsigned int j=1; j<=l; j++) {
+		unsigned int tkout=chainMaps[c][j];
+		if(tkout<NumOutputs)
+			chains[c]->set_q(getOutputCmd(tkout).value,j);
 	}
 }
 
@@ -229,9 +330,9 @@ bool PostureEngine::ChkAdvance(int res, const char** buf, unsigned int* len, con
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
- * $State: Rel $
- * $Date: 2003/09/07 22:14:01 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.21 $
+ * $State: Exp $
+ * $Date: 2004/10/18 19:53:33 $
  */
 
