@@ -2,26 +2,34 @@
 #ifndef INCLUDED_PostureEngine_h
 #define INCLUDED_PostureEngine_h
 
-#include "OutputCmd.h"
+#include "Motion/OutputCmd.h"
+#include "Motion/Kinematics.h"
 #include "Shared/RobotInfo.h"
 #include "Shared/LoadSave.h"
 
+class WorldState;
+
 //! A class for storing a set of positions and weights for all the outputs
 /*! Handy for any class which wants to deal with setting joints and postures without writing a custom class
  *  @see PostureMC */
-class PostureEngine : public LoadSave {
+class PostureEngine : public LoadSave, public Kinematics {
 public:
 	//!constructor
-	PostureEngine() : LoadSave() {}
-	//!constructor, loads a position from a file - not necessarily quick!
+	PostureEngine() : LoadSave(), Kinematics(*kine) {}
+	//!constructor, loads a position from a file
 	/*! @todo might want to make a library of common positions so they don't have to be loaded repeatedly from memstick */
-	PostureEngine(const char * filename) : LoadSave() { LoadFile(filename); }
+	PostureEngine(const char * filename) : LoadSave(), Kinematics(*kine) { LoadFile(filename); }
+	//!constructor, initializes joint positions to the current state of the outputs as defined by @a state
+	PostureEngine(const WorldState* st) : LoadSave(), Kinematics(*kine) { takeSnapshot(st); }
 	//! destructor
 	virtual ~PostureEngine();
 
 	//! sets the internal #cmds to the current state of the outputs
 	virtual void takeSnapshot();
 
+	//! sets the internal #cmds to the current state of the outputs as defined by @a state
+	virtual void takeSnapshot(const WorldState* st);
+
 	//! sets all joints to unused
 	virtual void clear();
 
@@ -46,20 +54,22 @@ public:
 	virtual PostureEngine createCombine(const PostureEngine& pe) const;
 
 	//! returns the sum squared error between this and pe's output values, but only between outputs which are both not unused
-	/*! @todo create a version which looks at weights?  This doesn't use them. */
+	/*! @todo create a version which does weighted summing?  This treats weights as all or nothing */
 	float diff(const PostureEngine& pe) const;
 	
 	//! returns the average sum squared error between this and pe's output values for outputs which are both not unused
-	/*! @todo create a version which looks at weights?  This doesn't use them. */
+	/*! @todo create a version which does weighted summing?  This treats weights as all or nothing */
 	float avgdiff(const PostureEngine& pe) const;
 	
-	//! returns the max sum squared error between this and pe's output values for outputs which are both not unused
-	/*! @todo create a version which looks at weights?  This doesn't use them. */
+	//! returns the max error between this and pe's output values for outputs which are both not unused
+	/*! @todo create a version which does weighted summing?  This treats weights as all or nothing */
 	float maxdiff(const PostureEngine& pe) const;
 	
 	//! NOT VIRTUAL! You should be able to call this to set outputs without checking out, just a peekMotion().  Theoretically.
 	//!@name Output Accessors
 	inline PostureEngine& setOutputCmd(unsigned int i, const OutputCmd& c) { cmds[i]=c; return *this; } //!<sets output @a i to OutputCmd @a c, returns @c *this so you can chain them
+	inline OutputCmd& operator()(unsigned int i) { return cmds[i]; } //!< returns output @a i, returns a reference so you can also set "through" this call.
+	inline const OutputCmd& operator()(unsigned int i) const { return cmds[i]; } //!< returns output @a i
 	inline OutputCmd& getOutputCmd(unsigned int i) { return cmds[i]; } //!< returns output @a i, returns a reference so you can also set "through" this call.
 	inline const OutputCmd& getOutputCmd(unsigned int i) const { return cmds[i]; } //!< returns output @a i
 	//@}
@@ -69,14 +79,26 @@ public:
 	virtual unsigned int getBinSize() const;
 	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
 	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
+	virtual unsigned int LoadFile(const char filename[]);
+	virtual unsigned int SaveFile(const char filename[]) const;
 	//@}
 
+	//! Performs inverse kinematics to solve for positioning @a Plink on link @a j to @a Pobj in base coordinates (expects homogenous form); if solution found, stores result in this posture and returns true
+	bool solveLinkPosition(const NEWMAT::ColumnVector& Pobj, unsigned int j, const NEWMAT::ColumnVector& Plink);
+	//! Performs inverse kinematics to solve for positioning Plink on link @a j to Pobj in base coordinates; if solution found, stores result in this posture and returns true
+	bool solveLinkPosition(float Pobj_x, float Pobj_y, float Pobj_z, unsigned int j, float Plink_x, float Plink_y, float Plink_z)
+	{ return solveLinkPosition(pack(Pobj_x,Pobj_y,Pobj_z),j,pack(Plink_x,Plink_y,Plink_z)); }
+
+	//! Performs inverse kinematics to solve for positioning @a Plink on link @a j to @a Pobj in base coordinates (expects homogenous form); if solution found, stores result in this posture and returns true
+	bool solveLinkVector(const NEWMAT::ColumnVector& Pobj, unsigned int j, const NEWMAT::ColumnVector& Plink);
+	//! Performs inverse kinematics to solve for positioning Plink on link @a j to Pobj in base coordinates; if solution found, stores result in this posture and returns true
+	bool solveLinkVector(float Pobj_x, float Pobj_y, float Pobj_z, unsigned int j, float Plink_x, float Plink_y, float Plink_z)
+	{ return solveLinkVector(pack(Pobj_x,Pobj_y,Pobj_z),j,pack(Plink_x,Plink_y,Plink_z)); }
+
 protected:
-	//!used by LoadBuffer()/SaveBuffer(), checks to see if the amount read/written (@a res) is nonzero, increments @a buf, decrements @a len, or displays @a msg if @a is zero
-	static bool ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg);
-	//!used by LoadBuffer()/SaveBuffer(), checks to see if the amount read/written (@a res) is nonzero, increments @a buf, decrements @a len, or displays @a msg with @a arg1 if @a is zero
-	static bool ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg, int arg1);
-	
+	//all updates come from this posture engine's own state, not WorldState
+	virtual void update(unsigned int c, unsigned int l);
+
 	//!the table of outputs' values and weights, can be accessed through setOutputCmd() and getOutputCmd()
 	OutputCmd cmds[NumOutputs];
 };
@@ -87,10 +109,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.3 $
- * $State: Rel $
- * $Date: 2003/09/25 15:27:23 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.13 $
+ * $State: Exp $
+ * $Date: 2004/10/18 19:53:33 $
  */
 
 #endif
