@@ -6,6 +6,8 @@
 #include "PostureEngine.h"
 #include "MotionManager.h"
 
+class WorldState;
+
 //! a MotionCommand shell for PostureEngine
 /*! Will autoprune by default once it reaches the target pose.
  * 
@@ -19,6 +21,8 @@ public:
 	PostureMC() : MotionCommand(),PostureEngine(),dirty(true),tolerance(.01) { }
 	//!constructor, loads from @a filename
 	PostureMC(const char* filename) : MotionCommand(),PostureEngine(filename),dirty(true),tolerance(.01) { }
+	//!constructor, initializes joint positions to the current state of the outputs as defined by @a state
+	PostureMC(const WorldState* st) : MotionCommand(),PostureEngine(st),dirty(true),tolerance(.01) { }
 	//!destructor
 	virtual ~PostureMC() {}
 	
@@ -61,6 +65,7 @@ public:
 	//!Had to override stuff to manage a dirty flag
 	//!@name PostureEngine Stuff
 	inline virtual void takeSnapshot() { dirty=true; PostureEngine::takeSnapshot(); }
+	inline virtual void takeSnapshot(const WorldState* st) { dirty=true; PostureEngine::takeSnapshot(st); }
 	inline virtual void clear() { dirty=true; PostureEngine::clear(); }
 	inline virtual PostureEngine& setOverlay(const PostureEngine& pe) { dirty=true; PostureEngine::setOverlay(pe); return *this; }
 	inline virtual PostureEngine& setUnderlay(const PostureEngine& pe) { dirty=true; PostureEngine::setUnderlay(pe); return *this; }
@@ -87,10 +92,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/03/03 03:37:13 $
+ * $Date: 2004/08/30 20:26:45 $
  */
 
 #endif
