@@ -34,7 +34,7 @@
 
 #include "MotionCommand.h"
 #include "Geometry.h"
-#include "Kinematics.h"
+#include "OldKinematics.h"
 #include "Path.h"
 #include "Shared/get_time.h"
 #include "OutputCmd.h"
@@ -67,19 +67,18 @@
  *
  *  This portion of the code falls under CMPack's license:
  *  @verbinclude CMPack_license.txt
- *
- *  @bug the legs try (briefly) to straighten out when first starting to move
  */
 class WalkMC : public MotionCommand, public LoadSave {
 public:
-	typedef SplinePath<vector3d,double> splinepath; //!<for convenience
-	typedef HermiteSplineSegment<vector3d,double> spline; //!<for convenience
+	typedef SplinePath<vector3d,float> splinepath; //!<for convenience
+	typedef HermiteSplineSegment<vector3d,float> spline; //!<for convenience
 
 	//! holds state about each leg's path
 	struct LegWalkState {
-		LegWalkState() : airpath(), air(0) {} //!< constructor
+		LegWalkState() : airpath(), air(0), cyc(0) {} //!< constructor
 		spline airpath; //!< the path to follow
 		bool air; //!< true if in the air
+		float cyc; //!< % (0,1) of how far along the path we are
 	};
 	
 	//! holds parameters about how to move each leg
@@ -94,14 +93,16 @@ public:
 
 	//! holds more general parameters about the walk
 	struct WalkParam {
-		WalkParam() : body_height(0), body_angle(0), hop(0), sway(0), period(0), reserved() {} //!< constructor
+		WalkParam() : body_height(0), body_angle(0), hop(0), sway(0), period(0), useDiffDrive(0), sag(0), reserved() {} //!< constructor
 		LegParam leg[4]; //!< a set of LegParam's, one for each leg
 		double body_height; //!< the height to hold the body (mm)
 		double body_angle; //!< the angle to hold the body (rad - 0 is level)
 		double hop;  //!< sinusoidal hop amplitude
 		double sway; //!< sinusoidal sway in y direction
 		long period; //!< the time between steps
-		long reserved; //!< live with it
+		long useDiffDrive; //!< if non-zero, diff-drive style turning is used instead of rotational turning
+		float sag; //!< the amount to sagging to account for when a foot is lifted
+		float reserved; //!< just live with it
 	};
 
 	//! holds information to correct for slippage, non-idealities
@@ -141,6 +142,8 @@ public:
 	virtual unsigned int getBinSize() const;
 	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
 	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
+	virtual	unsigned int LoadFile(const char* filename);
+	virtual unsigned int SaveFile(const char* filename) const;
 
 	//! set the direction to walk - can specify x (forward), y (left), and angular (counterclockwise) velocities
 	void setTargetVelocity(double dx,double dy,double da);
@@ -168,6 +171,8 @@ public:
 	void setSlowMo(float p) { slowmo=p; } //!< sets slowmo
 	float* getSlowMo() { return &slowmo; } //!< gets slowmo
 
+	const vector3d& getLegPosition(LegOrder_t i) const { return legpos[i]; }
+
 	WalkParam & getWP() { return wp; }; //!< returns the current walk parameter structure
 	CalibrationParam & getCP() { return cp; }; //!< returns the current walk calibration parameter
 	
@@ -200,9 +205,11 @@ public:
 	vector3d legpos[NumLegs]; //!< current position of each leg
 	splinepath body_loc; //!< the path the body goes through while walking (?)
 	splinepath body_angle; //!< the path the body goes through while walking (?)
+	vector3d liftPos[NumLegs]; //!< position each of the feet was last lifted
+	vector3d downPos[NumLegs]; //!< position each of the feet is next going to be set down
 
 	vector3d pos_delta; //!< how much we've moved
-	double angle_delta; //!< how much we've turned
+	float angle_delta; //!< how much we've turned
 	
 	unsigned int travelTime; //!< the time of the last call to setTargetVelocity - handy to check the time we've been traveling current vector
 	int time; //!< time of last call to updateJointCmds() (scaled by slowmo)
@@ -262,10 +269,10 @@ public:
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2004/03/03 18:42:16 $
+ * $Date: 2004/08/05 20:29:04 $
  */
 
 #endif
