@@ -4,8 +4,16 @@
 #include <stdio.h>
 #include <string>
 #include <ctype.h>
-#include <OPENR/OPrimitiveControl.h>
-#include <OPENR/OPENRAPI.h>
+#ifdef PLATFORM_APERIOS
+#  include <OPENR/OPrimitiveControl.h>
+#  include <OPENR/OPENRAPI.h>
+#else
+  typedef unsigned int OSpeakerVolume;
+  const OSpeakerVolume ospkvolinfdB = 0x8000;
+  const OSpeakerVolume ospkvol25dB  = 0xe700;
+  const OSpeakerVolume ospkvol18dB  = 0xee00;
+  const OSpeakerVolume ospkvol10dB  = 0xf600;
+#endif
 
 Config* config=NULL;
 
@@ -27,6 +35,7 @@ void* Config::setValue(section_t section, const char *key, const char *value,
         } else if (strncasecmp(value,"outdoor",49)==0) {
           vision.white_balance=2;
         }
+#ifdef PLATFORM_APERIOS
 				//this will actually send the new setting to the system
 				OPrimitiveID fbkID = 0;
 				if(OPENR::OpenPrimitive(CameraLocator, &fbkID) != oSUCCESS){
@@ -38,6 +47,7 @@ void* Config::setValue(section_t section, const char *key, const char *value,
 					}
 					OPENR::ClosePrimitive(fbkID);
 				}
+#endif
         return &vision.white_balance;
       } else if (strncasecmp(key,"gain",29)==0) {
         if (strncasecmp(value,"low",49)==0) {
@@ -47,6 +57,7 @@ void* Config::setValue(section_t section, const char *key, const char *value,
         } else if (strncasecmp(value,"high",49)==0) {
           vision.gain=3;
         }
+#ifdef PLATFORM_APERIOS
 				//this will actually send the new setting to the system
 				OPrimitiveID fbkID = 0;
 				if(OPENR::OpenPrimitive(CameraLocator, &fbkID) != oSUCCESS){
@@ -57,6 +68,7 @@ void* Config::setValue(section_t section, const char *key, const char *value,
 						std::cout << "CAM_SET_GAIN : Failed!" << std::endl;
 					OPENR::ClosePrimitive(fbkID);
 				}
+#endif
         return &vision.gain;
       } else if (strncasecmp(key,"shutter_speed",29)==0) {
         if (strncasecmp(value,"slow",49)==0) {
@@ -66,6 +78,7 @@ void* Config::setValue(section_t section, const char *key, const char *value,
         } else if (strncasecmp(value,"fast",49)==0) {
           vision.shutter_speed=3;
         }
+#ifdef PLATFORM_APERIOS
 				//this will actually send the new setting to the system
 				OPrimitiveID fbkID = 0;
 				if(OPENR::OpenPrimitive(CameraLocator, &fbkID) != oSUCCESS){
@@ -76,6 +89,7 @@ void* Config::setValue(section_t section, const char *key, const char *value,
 						std::cout << "CAM_SET_SHUTTER_SPEED : Failed!" << std::endl;
 					OPENR::ClosePrimitive(fbkID);
 				}
+#endif
         return &vision.shutter_speed;
       } else if (strncasecmp(key,"resolution",29)==0) {
         if (strncasecmp(value,"full",49)==0) {
@@ -86,6 +100,15 @@ void* Config::setValue(section_t section, const char *key, const char *value,
           vision.resolution=3;
         }
         return &vision.resolution;
+      } else if (strncasecmp(key,"horizFOV",29)==0) {
+				vision.horizFOV=atof(value)*M_PI/180;
+        return &vision.horizFOV;
+      } else if (strncasecmp(key,"vertFOV",29)==0) {
+				vision.vertFOV=atof(value)*M_PI/180;
+        return &vision.vertFOV;
+      } else if (strncasecmp(key,"focal_length",29)==0) {
+				vision.focal_length=atof(value);
+        return &vision.focal_length;
       } else if (strncasecmp(key,"thresh",29)==0) {
 				vision.thresh.push_back(value);
         return &vision.thresh;
@@ -95,9 +118,21 @@ void* Config::setValue(section_t section, const char *key, const char *value,
       } else if (strncasecmp(key,"raw_port",29)==0) {
         vision.rawcam_port=atoi(value);
         return &vision.rawcam_port;
+      } else if (strncasecmp(key,"raw_transport",29)==0) {
+        if (strncasecmp(value,"udp",49)==0)
+          vision.rawcam_transport=0;
+        else if (strncasecmp(value,"tcp",49)==0)
+          vision.rawcam_transport=1;
+        return &vision.rawcam_transport;
       } else if (strncasecmp(key,"rle_port",29)==0) {
         vision.rle_port=atoi(value);
         return &vision.rle_port;
+      } else if (strncasecmp(key,"rle_transport",29)==0) {
+        if (strncasecmp(value,"udp",49)==0)
+          vision.rle_transport=0;
+        else if (strncasecmp(value,"tcp",49)==0)
+          vision.rle_transport=1;
+        return &vision.rle_transport;
       } else if (strncasecmp(key,"obj_port",29)==0) {
         vision.obj_port=atoi(value);
         return &vision.obj_port;
@@ -111,8 +146,8 @@ void* Config::setValue(section_t section, const char *key, const char *value,
           vision.jpeg_dct_method=JDCT_IFAST;
         } else if (strncasecmp(value,"float",49)==0) {
           vision.jpeg_dct_method=JDCT_FLOAT;
-				}
-				return &vision.jpeg_dct_method;
+		}
+		return &vision.jpeg_dct_method;
       } else if (strncasecmp(key,"rawcam_encoding",29)==0) {
         if (strncasecmp(value,"color",49)==0) {
           vision.rawcam_encoding=vision_config::ENCODE_COLOR;
@@ -246,6 +281,12 @@ void* Config::setValue(section_t section, const char *key, const char *value,
 			} else if (strncasecmp(key,"walk",29)==0) {
         motion.walk=value;
         return &motion.walk;
+			} else if (strncasecmp(key,"kinematics",29)==0) {
+        motion.kinematics=value;
+        return &motion.walk;
+      } else if (strncasecmp(key,"kinematic_chains",29)==0) {
+				motion.kinematic_chains.push_back(value);
+        return &motion.kinematic_chains;
       } else if (strncasecmp(key,"estop_on_snd",29)==0) {
         strncpy(motion.estop_on_snd,value,49);
         return &motion.estop_on_snd;
@@ -253,26 +294,20 @@ void* Config::setValue(section_t section, const char *key, const char *value,
         strncpy(motion.estop_off_snd,value,49);
         return &motion.estop_off_snd;
       } else if (strncasecmp(key,"max_head_tilt_speed",29)==0) {
-					motion.max_head_tilt_speed=atof(value);
+				motion.max_head_tilt_speed=atof(value);
+				return &motion.max_head_tilt_speed;
       } else if (strncasecmp(key,"max_head_pan_speed",29)==0) {
-					motion.max_head_pan_speed=atof(value);
+				motion.max_head_pan_speed=atof(value);
+				return &motion.max_head_pan_speed;
       } else if (strncasecmp(key,"max_head_roll_speed",29)==0) {
-					motion.max_head_roll_speed=atof(value);
-      }
-      break;
-    case sec_worldmodel2:
-      if (strncasecmp(key,"dm_port",29)==0) {
-        worldmodel2.dm_port = atoi(value);
-        return &worldmodel2.dm_port ;
-      } else if (strncasecmp(key,"hm_port",29)==0) {
-        worldmodel2.hm_port = atoi(value);
-        return &worldmodel2.hm_port ;
-      } else if (strncasecmp(key,"gm_port",29)==0) {
-        worldmodel2.gm_port = atoi(value);
-        return &worldmodel2.gm_port ;
-      } else if (strncasecmp(key,"fs_port",29)==0) {
-        worldmodel2.fs_port = atoi(value);
-        return &worldmodel2.fs_port ;
+				motion.max_head_roll_speed=atof(value);
+				return &motion.max_head_roll_speed;
+      } else if (strncasecmp(key,"console_port",29)==0) {
+        motion.console_port = atoi(value);
+        return &motion.console_port;
+      } else if (strncasecmp(key,"stderr_port",29)==0) {
+        motion.stderr_port = atoi(value);
+        return &motion.stderr_port ;
       }
       break;
     case sec_sound:
@@ -321,8 +356,6 @@ Config::section_t Config::parseSection(const char* key) {
     return sec_controller;
   } else if (strncasecmp(key,"motion",29)==0) {
     return sec_motion;
-  } else if (strncasecmp(key,"worldmodel2",29)==0) {
-    return sec_worldmodel2;
   } else if (strncasecmp(key,"sound",29)==0) {
     return sec_sound;
   } else {
@@ -338,12 +371,29 @@ void Config::readConfig(const char* filename) {
 
 	bool ignoring=false;
 	std::vector<std::string> curmodel;
+#ifdef PLATFORM_APERIOS
 	char rdStr[orobotdesignNAME_MAX];
 	memset(rdStr, 0, sizeof(rdStr));
 	if (OPENR::GetRobotDesign(rdStr) != oSUCCESS) {
 		printf("OPENR::GetRobotDesign() failed.\n");
 		rdStr[0]='\0';
 	}
+#else
+#  if TGT_ERS7
+	char rdStr[]="ERS-7";
+#  elif TGT_ERS210
+	char rdStr[]="ERS-210";
+#  elif TGT_ERS220
+	char rdStr[]="ERS-220";
+#  elif TGT_ERS2xx
+#    warning "TGT_2xx is not specific for simulation purposes - defaulting to ERS210"
+	char rdStr[]="ERS-210";
+#  else
+#    warning "TGT_<model> undefined - defaulting to ERS210"
+	char rdStr[]="ERS-210";
+#  endif
+#endif
+
 
 	unsigned int lineno=0;
   while (fscanf(fp,"%79[^\n]\n", buf)!=EOF) {
@@ -449,9 +499,9 @@ bool Config::extractBool(const char * value) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.30 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.36 $
  * $State: Exp $
- * $Date: 2004/01/21 03:53:01 $
+ * $Date: 2004/10/11 22:01:34 $
  */
 
