@@ -13,7 +13,7 @@ class Config {
 	//!constructor
 	Config(const char* filename)
 		: wireless(), vision(), main(), behaviors(), controller(), motion(),
-		worldmodel2(), sound()
+		sound()
 		{ readConfig(filename); }
 	//!destructor
 	~Config() {}
@@ -26,7 +26,6 @@ class Config {
 		sec_behaviors,   //!< denotes behaviors section of config file
 		sec_controller,  //!< denotes controller section of config file
 		sec_motion,      //!< denotes motion section of config file
-		sec_worldmodel2, //!< denotes worldmodel section of config file
 		sec_sound,       //!< denotes sound section of config file
 		sec_invalid      //!< denotes an invalid section of config file
 	};
@@ -44,10 +43,15 @@ class Config {
 		int gain;             //!< gain
 		int shutter_speed;    //!< shutter speed
 		int resolution;       //!< resolution
+		float horizFOV;       //!< horizontal field of view of camera, in radians
+		float vertFOV;        //!< vertical field of view of camera, in radians
+		float focal_length;   //!< focal length of the camera (mm)
 		std::vector<std::string> thresh;      //!< thresholds
 		char colors[50];      //!< colors
 		int rawcam_port;      //!< port to send raw frames on
+		int rawcam_transport; //!< transport protocol: 0 for udp, 1 for tcp
 		int rle_port;         //!< port to send RLE frames on
+		int rle_transport;    //!< transport protocol: 0 for udp, 1 for tcp
 		int obj_port;         //!< port to send object info on
 		bool restore_image;   //!< if true, replaces pixels holding image info with actual image pixels (as much as possible anyway)
 		J_DCT_METHOD jpeg_dct_method;  //!< pick between dct methods for jpeg compression
@@ -74,9 +78,22 @@ class Config {
     int rlecam_skip;       //!< resolution level to transmit segmented images at
     int rlecam_channel;    //!< channel of RLEGenerator to send
 		compression_t rlecam_compression; //!< what compression to use on the segmented image
+
+		//!provides a ray from camera through pixel in image
+		/*! Hopefully we'll eventually upgrade this to account for lens distortion
+		 *  @param[in] x x position in range [-1,1]
+		 *  @param[in] y y position in range [-1,1]
+		 *  @param[out] r_x x value of the ray
+		 *  @param[out] r_y y value of the ray
+		 *  @param[out] r_z z value of the ray (always 1) */
+		void computeRay(float x, float y, float& r_x, float& r_y, float& r_z) {
+			r_x=x*tan(horizFOV/2);
+			r_y=y*tan(vertFOV/2);
+			r_z=1;
+		}
       
 		//!constructor
-		vision_config() : white_balance(3), gain(2), shutter_speed(2), resolution(2), thresh(), colors(), rawcam_port(0), rle_port(0), obj_port(0), restore_image(true), jpeg_dct_method(JDCT_IFAST), rawcam_encoding(ENCODE_COLOR), rawcam_channel(0), rawcam_compression(COMPRESS_NONE), rawcam_compress_quality(75), rawcam_y_skip(0), rawcam_uv_skip(0), rlecam_skip(1), rlecam_channel(0), rlecam_compression(COMPRESS_RLE) {}
+		vision_config() : white_balance(3), gain(2), shutter_speed(2), resolution(2), horizFOV(0), vertFOV(0), focal_length(0), thresh(), colors(), rawcam_port(0), rawcam_transport(0), rle_port(0), rle_transport(0), obj_port(0), restore_image(true), jpeg_dct_method(JDCT_IFAST), rawcam_encoding(ENCODE_COLOR), rawcam_channel(0), rawcam_compression(COMPRESS_NONE), rawcam_compress_quality(75), rawcam_y_skip(0), rawcam_uv_skip(0), rlecam_skip(1), rlecam_channel(0), rlecam_compression(COMPRESS_RLE) {}
 	} vision;
 	
 	//!core functionality information
@@ -128,14 +145,18 @@ class Config {
 	struct motion_config {
 		std::string root;       //!< path on memory stick to "motion" files - for instance, position (.pos) and motion sequence (.mot)
 		std::string walk;       //!< the walk parameter file to load by default for new WalkMC's
+		std::string kinematics;  //!< the kinematics description file to load
+		std::vector<std::string> kinematic_chains; //!< list of chains to load from #kinematics
 		char estop_on_snd[50];  //!< sound file to use when e-stop turned on
 		char estop_off_snd[50]; //!< sound file to use when e-stop turned off
 		float max_head_tilt_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
 		float max_head_pan_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
 		float max_head_roll_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
+		int console_port;  //!< port to send/receive "console" information on (separate from system console)
+		int stderr_port;   //!< port to send error information to
 
 		//!returns an absolute path if @a is relative (to root), otherwise just @a name
-		std::string makePath(std::string name) { 
+		std::string makePath(const std::string& name) { 
 			if(name[0]=='/')
 				return name;
 			if(root[root.size()-1]=='/')
@@ -145,7 +166,7 @@ class Config {
 		}
 
 		//!constructor
-		motion_config() : root(), walk(), max_head_tilt_speed(0), max_head_pan_speed(0), max_head_roll_speed(0) {
+		motion_config() : root(), walk(), kinematics(), kinematic_chains(), max_head_tilt_speed(0), max_head_pan_speed(0), max_head_roll_speed(0), console_port(0), stderr_port(0) {
 			estop_on_snd[0]=estop_off_snd[0]='\0';
 			max_head_tilt_speed=0;
 			max_head_pan_speed=0;
@@ -153,16 +174,6 @@ class Config {
 		}
 	} motion;
 
-	//!world model information
-	struct worldmodel2_config {
-		//@{
-		//!ports to use for sending world model information
-		int dm_port, hm_port, gm_port, fs_port; //@}
-
-		//!constructor
-		worldmodel2_config() : dm_port(0), hm_port(0), gm_port(0), fs_port(0) {}
-	} worldmodel2;
-	
 	//!sound information
 	struct sound_config {
 		std::string root;         //!< path to sound clips
@@ -172,7 +183,7 @@ class Config {
 		std::vector<std::string> preload; //!< list of sounds to preload at boot
 			
 		//!returns an absolute path if @a is relative (to root), otherwise just @a name
-		std::string makePath(std::string name) { 
+		std::string makePath(const std::string& name) { 
 			if(name[0]=='/')
 				return name;
 			if(root[root.size()-1]=='/')
@@ -209,10 +220,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.28 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.35 $
  * $State: Exp $
- * $Date: 2004/01/30 01:30:07 $
+ * $Date: 2004/10/11 22:01:34 $
  */
 
 #endif
