@@ -36,16 +36,6 @@ namespace ERS210Info {
 	//!Corresponds to entries in ERS210Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
-	const unsigned NumPIDJoints   = 18; //!< The number of joints which use PID motion - everything except ears
-	const unsigned NumLEDs        =  9; //!< The number LEDs which can be controlled
-	const unsigned NumBinJoints   =  2; //!< The number of binary joints - just the ears
-	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
-
-	const bool IsFastOutput[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false }; //!< true for joints which can be updated every 32 ms (all but the ears)
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
-	const bool IsRealERS210[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true };
-	//@}
-
 	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
 	const unsigned NumLegs        =  4; //!< The number of legs
 	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
@@ -55,7 +45,18 @@ namespace ERS210Info {
 	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
 	const unsigned NumButtons     =  8; //!< the number of buttons that are available, see ERS210Info::ButtonOffset_t
 	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS210Info::SensorOffset_t
+	const unsigned NumLEDs        =  9; //!< The number of LEDs which can be controlled
 	
+	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything except ears
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears
+	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
+	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 1; //!< for the base, paw, camera, and IR sensor reference frames
+
+	const bool IsFastOutput[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false }; //!< true for joints which can be updated every 32 ms (all but the ears)
+	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
+	const bool IsRealERS210[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true };
+	//@}
+
 
 	// *******************************
 	//         OUTPUT OFFSETS
@@ -76,6 +77,11 @@ namespace ERS210Info {
 	const unsigned BinJointOffset = LEDOffset + NumLEDs; //!< The beginning of the binary joints
 	const unsigned EarOffset   = BinJointOffset;           //!< the offset of the beginning of the ear joints - note that ears aren't sensed.  They can be flicked by the environment and you won't know.  Nor will they be flicked back
 
+	const unsigned BaseFrameOffset   = NumOutputs; //!< Use with kinematics to refer to base reference frame
+	const unsigned PawFrameOffset    = BaseFrameOffset+1; //!< Use with kinematics to refer to paw reference frames (add appropriate LegOrder_t to specify which paw)
+	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
+	const unsigned IRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to infrared (distance) sensor reference frame
+	
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -158,6 +164,11 @@ namespace ERS210Info {
 		HeadFrButOffset, //!< not in reliable pressure units, but 1.0 is fairly stiff pressure, 0 is none
 		HeadBkButOffset //!< not in reliable pressure units, but 1.0 is fairly stiff pressure, 0 is none
 	};
+	
+	//! Provides a string name for each button
+	const char* const ButtonNames[NumButtons] = {
+		"LFrPaw","RFrPaw","LBkPaw","ChinBut","BackBut","HeadFrBut","HeadBkBut"
+	};
 
 	//! holds offset to different sensor values in WorldState::sensors[]
 	/*! @see WorldState::sensors[] */
@@ -458,10 +469,10 @@ namespace ERS210Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/09/16 18:35:12 $
  */
 
 #endif
