@@ -39,10 +39,21 @@ namespace ERS220Info {
 	//!Corresponds to entries in ERS220Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
-	const unsigned NumPIDJoints   = 15; //!< The number of joints which use PID motion - everything
-	const unsigned NumLEDs        = 20; //!< The number LEDs which can be controlled
-	const unsigned NumBinJoints   =  0; //!< The number of binary joints (210 has ears)
+	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
+	const unsigned NumLegs        =  4; //!< The number of legs
+	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
+	const unsigned NumHeadJoints  =  3; //!< The number of joints in the neck
+	const unsigned NumTailJoints  =  0; //!< The number of joints assigned to the tail
+	const unsigned NumMouthJoints =  0; //!< the number of joints that control the mouth
+	const unsigned NumEarJoints   =  0; //!< The number of joints which control the ears (NOT per ear, is total)
+	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ERS220Info::ButtonOffset_t
+	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS220Info::SensorOffset_t
+	const unsigned NumLEDs        = 20; //!< The number of LEDs which can be controlled
+	
+	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears (which the 220 doesn't have)
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
+	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 1; //!< for the base, paw, camera, and IR sensor reference frames
 
 	const bool IsFastOutput[NumOutputs] = {
 		// for PID joints
@@ -83,16 +94,6 @@ namespace ERS220Info {
 		// for binary joints (none supported/exist on 220)
 	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
 
-	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
-	const unsigned NumLegs        =  4; //!< The number of legs
-	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
-	const unsigned NumHeadJoints  =  3; //!< The number of joints in the neck
-	const unsigned NumTailJoints  =  0; //!< The number of joints assigned to the tail
-	const unsigned NumMouthJoints =  0; //!< the number of joints that control the mouth
-	const unsigned NumEarJoints   =  0; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ERS220Info::ButtonOffset_t
-	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS220Info::SensorOffset_t
-	
 
 	// *******************************
 	//         OUTPUT OFFSETS
@@ -109,6 +110,11 @@ namespace ERS220Info {
 
 	const unsigned BinJointOffset = NumOutputs; //!< The beginning of the binary joints
 
+	const unsigned BaseFrameOffset   = NumOutputs; //!< Use with kinematics to refer to base reference frame
+	const unsigned PawFrameOffset    = BaseFrameOffset+1; //!< Use with kinematics to refer to paw reference frames (add appropriate LegOrder_t to specify which paw)
+	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
+	const unsigned IRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to infrared (distance) sensor reference frame
+
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -253,6 +259,11 @@ namespace ERS220Info {
 		TailRightButOffset,
 	};
 
+	//! Provides a string name for each button
+	const char* const ButtonNames[NumButtons] = {
+		"LFrPaw","RFrPaw","LBkPaw","ChinBut","BackBut","HeadFrBut","HeadBkBut","TailLeftBut","TailCenterBut","TailRightBut"
+	};
+
 	//! holds offset to different sensor values in WorldState::sensors[]
 	/*! @see WorldState::sensors[] */
 	enum SensorOffset_t {
@@ -481,7 +492,7 @@ namespace ERS220Info {
 			{ RAD(-117),RAD(117) },{ RAD(-11),RAD(89) },{ RAD(-27),RAD(147) }, //left back REK
 			{ RAD(-117),RAD(117) },{ RAD(-11),RAD(89) },{ RAD(-27),RAD(147) }, //right back REK
 
-			{ RAD(-82),RAD(43) },{ RAD(-89.6),RAD(89.6) },{ RAD(-29),RAD(29) }, //neck TPR
+			{ RAD(-88.5),RAD(43) },{ RAD(-89.6),RAD(89.6) },{ RAD(-29),RAD(29) }, //neck TPR
 				
 			{0,1},{0,1},{0,1},        // face left side LEDs x3
 			{0,1},{0,1},{0,1},        // face right side LEDs x3
@@ -501,7 +512,7 @@ namespace ERS220Info {
 			{ RAD(-120),RAD(120) },{ RAD(-14),RAD(92) },{ RAD(-30),RAD(150) }, //left back jsk
 			{ RAD(-120),RAD(120) },{ RAD(-14),RAD(92) },{ RAD(-30),RAD(150) }, //right back jsk
 
-			{ RAD(-85),RAD(46) },{ RAD(-92.6),RAD(92.6) },{ RAD(-32),RAD(32) }, //neck tpr
+			{ RAD(-91.5),RAD(46) },{ RAD(-92.6),RAD(92.6) },{ RAD(-32),RAD(32) }, //neck tpr
 				
 			{0,1},{0,1},{0,1},        // face left side LEDs x3
 			{0,1},{0,1},{0,1},        // face right side LEDs x3
@@ -562,10 +573,10 @@ namespace ERS220Info {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/09/17 18:29:54 $
  */
 
 #endif
