@@ -35,10 +35,21 @@ namespace ERS2xxInfo {
 	//!Corresponds to entries in ERS2xxInfo::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
-	const unsigned NumPIDJoints   = 18; //!< The number of joints which use PID motion - everything
-	const unsigned NumLEDs        = 22; //!< The number LEDs which can be controlled
-	const unsigned NumBinJoints   =  2; //!< The number of binary joints (210 has ears)
+	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
+	const unsigned NumLegs        =  4; //!< The number of legs
+	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
+	const unsigned NumHeadJoints  =  3; //!< The number of joints in the neck
+	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
+	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
+	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
+	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ERS2xxInfo::ButtonOffset_t
+	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS2xxInfo::SensorOffset_t
+	const unsigned NumLEDs        =  22; //!< The number of LEDs which can be controlled
+	
+	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything except ears
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
+	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 1; //!< for the base, paw, camera, and IR sensor reference frames
 
 	const bool IsFastOutput[NumOutputs] = {
 		// for PID joints
@@ -111,16 +122,6 @@ namespace ERS2xxInfo {
 		false, false
 	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
 
-	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
-	const unsigned NumLegs        =  4; //!< The number of legs
-	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
-	const unsigned NumHeadJoints  =  3; //!< The number of joints in the neck
-	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
-	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
-	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ERS2xxInfo::ButtonOffset_t
-	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS2xxInfo::SensorOffset_t
-	
 
 	// *******************************
 	//         OUTPUT OFFSETS
@@ -140,6 +141,11 @@ namespace ERS2xxInfo {
 	const unsigned BinJointOffset = LEDOffset+NumLEDs; //!< The beginning of the binary joints
 	const unsigned EarOffset   = BinJointOffset;           //!< the offset of the beginning of the ear joints - note that ears aren't sensed.  They can be flicked by the environment and you won't know.  Nor will they be flicked back
 
+	const unsigned BaseFrameOffset   = NumOutputs; //!< Use with kinematics to refer to base reference frame
+	const unsigned PawFrameOffset    = BaseFrameOffset+1; //!< Use with kinematics to refer to paw reference frames (add appropriate LegOrder_t to specify which paw)
+	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
+	const unsigned IRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to infrared (distance) sensor reference frame
+
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -604,10 +610,10 @@ namespace ERS2xxInfo {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/08/31 19:48:41 $
  */
 
 #endif
