@@ -29,10 +29,21 @@ namespace ERS7Info {
 	//!Corresponds to entries in ERS7Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
-	const unsigned NumPIDJoints   = 18; //!< The number of joints which use PID motion - everything except ears
-	const unsigned NumLEDs        = 27; //!< The number LEDs which can be controlled
-	const unsigned NumBinJoints   =  2; //!< The number of binary joints - just the ears
+	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
+	const unsigned NumLegs        =  4; //!< The number of legs
+	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
+	const unsigned NumHeadJoints  =  3; //!< The number of joints in the neck
+	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
+	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
+	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
+	const unsigned NumButtons     =  2+4+3+1; //!< the number of buttons that are available, 2 head, 4 paws, 3 back, 1 underbelly see ERS7Info::ButtonOffset_t
+	const unsigned NumSensors     =  3+3+5;  //!< 3 IR (distance), 3 accel (force), 5 from power, see ERS7Info::SensorOffset_t
+	const unsigned NumLEDs        =  27; //!< The number of LEDs which can be controlled
+	
+	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything except ears
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
+	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 3; //!< for the base, paws (NumLegs), camera, and IR sensors (3) reference frames
 
 	//! true for joints which can be updated every 32 ms (all but the ears)
 	const bool IsFastOutput[NumOutputs] = {
@@ -48,17 +59,6 @@ namespace ERS7Info {
 	};
 	//@}
 
-	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
-	const unsigned NumLegs        =  4; //!< The number of legs
-	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
-	const unsigned NumHeadJoints  =  3; //!< The number of joints in the neck
-	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
-	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
-	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  2+4+3+1; //!< the number of buttons that are available, 2 head, 4 paws, 3 back, 1 underbelly see ERS7Info::ButtonOffset_t
-	const unsigned NumSensors     =  3+3+5;  //!< 3 IR (distance), 3 accel (force), 5 from power, see ERS7Info::SensorOffset_t
-	
-
 	// *******************************
 	//         OUTPUT OFFSETS
 	// *******************************
@@ -75,9 +75,17 @@ namespace ERS7Info {
 
 	const unsigned LEDOffset   = PIDJointOffset + NumPIDJoints; //!< the offset of LEDs in WorldState::outputs and MotionCommand functions
 
-	const unsigned BinJointOffset = LEDOffset + NumLEDs; //!< The beginning of the binary joints
+	const unsigned BinJointOffset = LEDOffset + NumLEDs;   //!< The beginning of the binary joints
 	const unsigned EarOffset   = BinJointOffset;           //!< the offset of the beginning of the ear joints - note that ears aren't sensed.  They can be flicked by the environment and you won't know.  Nor will they be flicked back
 
+	const unsigned BaseFrameOffset   = NumOutputs; //!< Use with kinematics to refer to base reference frame
+	const unsigned PawFrameOffset    = BaseFrameOffset+1; //!< Use with kinematics to refer to paw reference frames (add appropriate LegOrder_t to specify which paw)
+	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
+	const unsigned NearIRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to short-range infrared (distance) sensor reference frame
+	const unsigned FarIRFrameOffset = NearIRFrameOffset+1; //!< Use with kinematics to refer to long-range infrared (distance) sensor reference frame
+	const unsigned ChestIRFrameOffset = FarIRFrameOffset+1; //!< Use with kinematics to refer to chest-mounted infrared (distance) sensor reference frame
+
+
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -178,18 +186,24 @@ namespace ERS7Info {
 		RBkPawOffset = RBkLegOrder,
 		ChinButOffset= 4,
 		HeadButOffset,
+		HeadFrButOffset=HeadButOffset,
 		FrontBackButOffset,
 		MiddleBackButOffset,
 		RearBackButOffset,
 		WirelessSwOffset
 	};
 
+	//! Provides a string name for each button
+	const char* const ButtonNames[NumButtons] = {
+		"LFrPaw","RFrPaw","LBkPaw","ChinBut","HeadBut","FrontBackBut","MiddleBackBut","RearBackBut","WirelessSw"
+	};
+
 	//! holds offset to different sensor values in WorldState::sensors[]
 	/*! @see WorldState::sensors[] */
 	enum SensorOffset_t {
-		NearIRDistOffset = 0,  //!< in millimeters
-		FarIRDistOffset,  //!< in millimeters
-		ChestIRDistOffset,  //!< in millimeters
+		NearIRDistOffset = 0,  //!< in millimeters, ranges from 50 to 500
+		FarIRDistOffset,  //!< in millimeters, ranges from 200 to 1500
+		ChestIRDistOffset,  //!< in millimeters, ranges from 100 to 900
 		BAccelOffset, //!< backward acceleration, in @f$m/s^2@f$, negative if sitting on butt (positive for faceplant)
 		LAccelOffset, //!< acceleration to the robot's left, in @f$m/s^2@f$, negative if lying on robot's left side
 		DAccelOffset, //!< downward acceleration, in @f$m/s^2@f$, negative if standing up... be careful about the signs on all of these...
@@ -354,7 +368,7 @@ namespace ERS7Info {
 
 			{ 0x0A/(double)(1<<(16-0xE)), 0x04/(double)(1<<(16-0x2)), 0x02/(double)(1<<(16-0xF)) },
 			{ 0x08/(double)(1<<(16-0xE)), 0x02/(double)(1<<(16-0x2)), 0x04/(double)(1<<(16-0xF)) },
-			{ 0x08/(double)(1<<(16-0xE)), 0x04/(double)(1<<(16-0x2)), 0x02/(double)(1<<(16-0xF)) },
+			{ 0x08/(double)(1<<(16-0xE)), 0x08/(double)(1<<(16-0x2)), 0x02/(double)(1<<(16-0xF)) }, // 'I' value changed to 0x08 instead of standard 0x04
 
 			{ 0x0A/(double)(1<<(16-0xE)), 0x04/(double)(1<<(16-0x2)), 0x04/(double)(1<<(16-0xF)) },
 			{ 0x0A/(double)(1<<(16-0xE)), 0x04/(double)(1<<(16-0x2)), 0x04/(double)(1<<(16-0xF)) },
@@ -372,29 +386,29 @@ namespace ERS7Info {
 	 *  These limits are <b>not</b> enforced by the framework.  They are simply available for you to use as you see fit.
 	 *  HeadPointerMC is (as of v1.6) the only included MotionCommand to actually use these values.
 	 *  
-	 *  This is disabled for the ERS-7 until Sony gives us values to use */
+	 *  These values were obtained from the administrators of the Sony OPEN-R BBS */
 	const float MaxOutputSpeed[NumOutputs] = {
-		0,     //Legs LR,FB,REK
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
+		4.86510529e-3, //Legs LR,FB,REK
+		5.27962099e-3,
+		5.27962099e-3,
+		4.86510529e-3,
+		5.27962099e-3,
+		5.27962099e-3,
+		4.86510529e-3,
+		5.27962099e-3,
+		5.27962099e-3,
+		4.86510529e-3,
+		5.27962099e-3,
+		5.27962099e-3,
 	
-		0,     //Head TPR
-		0,
-		0,
+		3.18522588e-3, //Head TPR
+		1.00574598e-2,
+		5.78140315e-3,
 	
-		0,     //Tail
-		0,
+		1.51625479e-2, //Tail
+		1.51625479e-2,
 	
-		0,     //Mouth
+		1.01447263e-2, //Mouth
 		
 		0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, //LEDs
 		
@@ -416,8 +430,8 @@ namespace ERS7Info {
 		{
 			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left front REK
 			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //right front REK
-			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left back REK
-			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //right back REK
+			{ RAD(-130),RAD(115) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left back REK
+			{ RAD(-130),RAD(115) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //right back REK
 
 			{ RAD(-75),RAD(0) },{ RAD(-88),RAD(88) },{ RAD(-15),RAD(45) }, //neck Tilt-pan-nod
 				
@@ -503,10 +517,10 @@ namespace ERS7Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/10/19 07:37:09 $
  */
 
 #endif
