@@ -132,14 +132,38 @@ unsigned int LoadSave::SaveFileStream(FILE* f) const {
 	return resp;
 }
 
+bool LoadSave::ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg) {
+	if(res>0) {
+		*buf+=res;
+		*len-=res;
+		return true;
+	} else {
+		printf("%s",msg);
+		return false;
+	}
+}
+
+bool LoadSave::ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg, int arg1) {
+	if(res>0) {
+		*buf+=res;
+		*len-=res;
+		return true;
+	} else {
+		printf(msg,arg1);
+		return false;
+	}
+}
+
+
+
 /*! @file
  * @brief Implements LoadSave, inherit from this to use a standard interface for loading and saving
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/02/03 01:19:05 $
+ * $Date: 2004/03/25 17:07:44 $
  */
 
