@@ -112,7 +112,6 @@ class LoadSave {
 	//!@name Constructors/Destructors
 	/*! @brief constructor */
 	LoadSave() {}
-	LoadSave(const char* filename) { LoadFile(filename); }
 	virtual ~LoadSave(); //!< destructor
 	//@}
 
@@ -161,8 +160,28 @@ class LoadSave {
 	virtual unsigned int SaveFileStream(FILE* f) const;
 	//@}
 
+	//! Handy for checking results from functions which manipulate the buffer
+	/*! @param res number of bytes used
+	 *  @param buf pointer to address of current place in buffer, will be incremented by @a res bytes
+	 *  @param len number of bytes remain between current place and end of buffer, will be decremented by @a res bytes
+	 *  @param msg Error to display if res is less than or equal to zero
+	 *  @return true if everything worked, false otherwise */
+	static bool ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg);
+
+	//! Handy for checking results from functions which manipulate the buffer
+	/*! This really should be rewritten to use variable number of arguments which can be passed
+	 *  directly on to printf...
+	 *  @param res number of bytes used
+	 *  @param buf pointer to address of current place in buffer, will be incremented by @a res bytes
+	 *  @param len number of bytes remain between current place and end of buffer, will be decremented by @a res bytes
+	 *  @param msg Error to display if res is less than or equal to zero
+	 *  @param arg1 An additional argument to be displayed (using %d in the @a msg); intended for things such as line number of error in file being read
+	 *  @return true if everything worked, false otherwise */
+	static bool ChkAdvance(int res, const char** buf, unsigned int* len, const char* msg, int arg1);
+
 	//! These are for putting creator codes at the beginning of your data to check for sanity, just optional
 	//!@name Creator Utilities
+
 	/*!@brief Returns size of the creator code
 	 * @param creator a string to use for the creator
 	 * @return the size to leave for the creator code */
@@ -330,10 +349,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:45 $
+ * $Date: 2004/04/08 16:28:06 $
  */
 
 #endif
