@@ -21,6 +21,7 @@
 
 class BehaviorBase;
 class FilterBankGenerator;
+class SegmentedColorGenerator;
 
 namespace ProjectInterface {
 	
@@ -37,7 +38,7 @@ namespace ProjectInterface {
 	extern FilterBankGenerator * defInterleavedYUVGenerator;
 	extern FilterBankGenerator * defColorJPEGGenerator;
 	extern FilterBankGenerator * defGrayscaleJPEGGenerator;
-	extern FilterBankGenerator * defSegmentedColorGenerator;
+	extern SegmentedColorGenerator * defSegmentedColorGenerator;
 	extern FilterBankGenerator * defRLEGenerator;
 	extern FilterBankGenerator * defRegionGenerator;
 	//@}
@@ -73,10 +74,10 @@ namespace ProjectInterface {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/12/11 05:49:30 $
+ * $Date: 2004/07/16 19:25:10 $
  */
 
 #endif
