@@ -45,6 +45,7 @@ WorldState::WorldState()
 	memset(powerFlags,0,sizeof(unsigned int)*PowerSourceID::NumPowerSIDs);
 	memset(button_times,0,sizeof(unsigned int)*NumButtons);
 
+#ifdef PLATFORM_APERIOS
 	//Thanks Daishi:
 	char robotDesignStr[orobotdesignNAME_MAX];
 	memset(robotDesignStr, 0, sizeof(robotDesignStr));
@@ -62,6 +63,22 @@ WorldState::WorldState()
 			robotDesign=ERS210Mask;
 		}
 	}
+#else
+# if TGT_ERS220
+	robotDesign=ERS220Mask;
+# elif TGT_ERS210
+	robotDesign=ERS210Mask;
+# elif TGT_ERS7
+	robotDesign=ERS7Mask;
+# else //default case, ERS2xx
+#	 if TGT_ERS2xx==0
+#		warning "TGT_<model> undefined - defaulting to TGT_ERS210"
+#  else
+#   warning "TGT_ERS2xx can't be determined on non-Aperios - defaulting to TGT_ERS210"
+#	 endif
+	robotDesign=ERS210Mask;
+# endif //model selection
+#endif
 }
 
 #ifdef PLATFORM_APERIOS
@@ -71,6 +88,7 @@ WorldState::WorldState()
 void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 	curtime=get_time();
 
+	std::vector<EventBase*> evtBuf;
 	unsigned int lastFrame=sensor.GetInfo(0)->numFrames-1;
 
 	if(robotDesign&ERS210Mask) {
@@ -119,16 +137,16 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		pidduties[ERS210Info::MouthOffset] = GETDUTY(ERS210Info::CPCJointMouth);
 
 		// Get foot switches
-		chkEvent(er,LFrPawOffset,GETB(ERS210Info::CPCSensorLFPaw),"LFrPaw");
-		chkEvent(er,RFrPawOffset,GETB(ERS210Info::CPCSensorRFPaw),"RFrPaw");
-		chkEvent(er,LBkPawOffset,GETB(ERS210Info::CPCSensorLHPaw),"LBkPaw");
-		chkEvent(er,RBkPawOffset,GETB(ERS210Info::CPCSensorRHPaw),"RBkPaw");
+		chkEvent(evtBuf,LFrPawOffset,GETB(ERS210Info::CPCSensorLFPaw),"LFrPaw");
+		chkEvent(evtBuf,RFrPawOffset,GETB(ERS210Info::CPCSensorRFPaw),"RFrPaw");
+		chkEvent(evtBuf,LBkPawOffset,GETB(ERS210Info::CPCSensorLHPaw),"LBkPaw");
+		chkEvent(evtBuf,RBkPawOffset,GETB(ERS210Info::CPCSensorRHPaw),"RBkPaw");
 
 		// Get buttons
-		chkEvent(er,ERS210Info::ChinButOffset,  GETB(ERS210Info::CPCSensorChinSwitch),"ChinBut");
-		chkEvent(er,ERS210Info::BackButOffset,  GETB(ERS210Info::CPCSensorBackSwitch),"BackBut");
-		chkEvent(er,ERS210Info::HeadFrButOffset,GETD(ERS210Info::CPCSensorHeadFrontPressure),"HeadFrBut");
-		chkEvent(er,ERS210Info::HeadBkButOffset,GETD(ERS210Info::CPCSensorHeadBackPressure),"HeadBkBut");
+		chkEvent(evtBuf,ERS210Info::ChinButOffset,  GETB(ERS210Info::CPCSensorChinSwitch),"ChinBut");
+		chkEvent(evtBuf,ERS210Info::BackButOffset,  GETB(ERS210Info::CPCSensorBackSwitch),"BackBut");
+		chkEvent(evtBuf,ERS210Info::HeadFrButOffset,GETD(ERS210Info::CPCSensorHeadFrontPressure),"HeadFrBut");
+		chkEvent(evtBuf,ERS210Info::HeadBkButOffset,GETD(ERS210Info::CPCSensorHeadBackPressure),"HeadBkBut");
 
 		// Get IR distance sensor
 		sensors[ERS210Info::IRDistOffset]=GETSENSOR(ERS210Info::CPCSensorPSD) / 1000.0f;
@@ -179,21 +197,21 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		pidduties[HeadOffset+PanOffset ] = GETDUTY(ERS220Info::CPCJointNeckPan);
 		pidduties[HeadOffset+RollOffset] = GETDUTY(ERS220Info::CPCJointNeckRoll);
 
-	 	chkEvent(er, ERS220Info::TailLeftButOffset, GETB(ERS220Info::CPCSensorTailLeftSwitch),  "LBkBut");
-	 	chkEvent(er, ERS220Info::TailCenterButOffset, GETB(ERS220Info::CPCSensorTailCenterSwitch),"CBkBut");
-	 	chkEvent(er, ERS220Info::TailRightButOffset, GETB(ERS220Info::CPCSensorTailRightSwitch), "RBkBut");
+	 	chkEvent(evtBuf, ERS220Info::TailLeftButOffset, GETB(ERS220Info::CPCSensorTailLeftSwitch),  "LBkBut");
+	 	chkEvent(evtBuf, ERS220Info::TailCenterButOffset, GETB(ERS220Info::CPCSensorTailCenterSwitch),"CBkBut");
+	 	chkEvent(evtBuf, ERS220Info::TailRightButOffset, GETB(ERS220Info::CPCSensorTailRightSwitch), "RBkBut");
 
 		// Get foot switches
-		chkEvent(er,LFrPawOffset,GETB(ERS220Info::CPCSensorLFPaw),"LFrPaw");
-		chkEvent(er,RFrPawOffset,GETB(ERS220Info::CPCSensorRFPaw),"RFrPaw");
-		chkEvent(er,LBkPawOffset,GETB(ERS220Info::CPCSensorLHPaw),"LBkPaw");
-		chkEvent(er,RBkPawOffset,GETB(ERS220Info::CPCSensorRHPaw),"RBkPaw");
+		chkEvent(evtBuf,LFrPawOffset,GETB(ERS220Info::CPCSensorLFPaw),"LFrPaw");
+		chkEvent(evtBuf,RFrPawOffset,GETB(ERS220Info::CPCSensorRFPaw),"RFrPaw");
+		chkEvent(evtBuf,LBkPawOffset,GETB(ERS220Info::CPCSensorLHPaw),"LBkPaw");
+		chkEvent(evtBuf,RBkPawOffset,GETB(ERS220Info::CPCSensorRHPaw),"RBkPaw");
 
 		// Get buttons
-		chkEvent(er,ERS220Info::ChinButOffset,  GETB(ERS220Info::CPCSensorChinSwitch),"ChinBut");
-		chkEvent(er,ERS220Info::BackButOffset,  GETB(ERS220Info::CPCSensorBackSwitch),"BackBut");
-		chkEvent(er,ERS220Info::HeadFrButOffset,GETD(ERS220Info::CPCSensorHeadFrontPressure),"HeadFrBut");
-		chkEvent(er,ERS220Info::HeadBkButOffset,GETD(ERS220Info::CPCSensorHeadBackPressure),"HeadBkBut");
+		chkEvent(evtBuf,ERS220Info::ChinButOffset,  GETB(ERS220Info::CPCSensorChinSwitch),"ChinBut");
+		chkEvent(evtBuf,ERS220Info::BackButOffset,  GETB(ERS220Info::CPCSensorBackSwitch),"BackBut");
+		chkEvent(evtBuf,ERS220Info::HeadFrButOffset,GETD(ERS220Info::CPCSensorHeadFrontPressure),"HeadFrBut");
+		chkEvent(evtBuf,ERS220Info::HeadBkButOffset,GETD(ERS220Info::CPCSensorHeadBackPressure),"HeadBkBut");
 
 		// Get IR distance sensor
 		sensors[ERS220Info::IRDistOffset]=GETSENSOR(ERS220Info::CPCSensorPSD) / 1000.0f;
@@ -253,19 +271,19 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		pidduties[ERS7Info::MouthOffset] = GETDUTY(ERS7Info::CPCJointMouth);
 
 		// Get foot switches
-		chkEvent(er,LFrPawOffset,GETB(ERS7Info::CPCSwitchLFPaw),"LFrPaw");
-		chkEvent(er,RFrPawOffset,GETB(ERS7Info::CPCSwitchRFPaw),"RFrPaw");
-		chkEvent(er,LBkPawOffset,GETB(ERS7Info::CPCSwitchLHPaw),"LBkPaw");
-		chkEvent(er,RBkPawOffset,GETB(ERS7Info::CPCSwitchRHPaw),"RBkPaw");
+		chkEvent(evtBuf,LFrPawOffset,GETB(ERS7Info::CPCSwitchLFPaw),"LFrPaw");
+		chkEvent(evtBuf,RFrPawOffset,GETB(ERS7Info::CPCSwitchRFPaw),"RFrPaw");
+		chkEvent(evtBuf,LBkPawOffset,GETB(ERS7Info::CPCSwitchLHPaw),"LBkPaw");
+		chkEvent(evtBuf,RBkPawOffset,GETB(ERS7Info::CPCSwitchRHPaw),"RBkPaw");
 
 		// Get buttons/switches
 		// the sensors are scaled to be relatively similar to the pressure values given by the head on the 210
-		chkEvent(er, ERS7Info::ChinButOffset,       GETSENSOR(ERS7Info::CPCSwitchChin),      "ChinBut");
-		chkEvent(er, ERS7Info::HeadButOffset,       GETSENSOR(ERS7Info::CPCSensorHead)/120,      "HeadBut");
-	 	chkEvent(er, ERS7Info::FrontBackButOffset,  GETSENSOR(ERS7Info::CPCSensorBackFront)/150, "BkFrBut");
-	 	chkEvent(er, ERS7Info::MiddleBackButOffset, GETSENSOR(ERS7Info::CPCSensorBackMiddle)/150,"BkMdBut");
-	 	chkEvent(er, ERS7Info::RearBackButOffset,   GETSENSOR(ERS7Info::CPCSensorBackRear)/150,  "BkRrBut");
-	 	chkEvent(er, ERS7Info::WirelessSwOffset,GETSENSOR(ERS7Info::CPCSwitchWireless),  "WirelessSw");
+		chkEvent(evtBuf, ERS7Info::ChinButOffset,       GETSENSOR(ERS7Info::CPCSwitchChin),      "ChinBut");
+		chkEvent(evtBuf, ERS7Info::HeadButOffset,       GETSENSOR(ERS7Info::CPCSensorHead)/120,      "HeadBut");
+	 	chkEvent(evtBuf, ERS7Info::FrontBackButOffset,  GETSENSOR(ERS7Info::CPCSensorBackFront)/150, "BkFrBut");
+	 	chkEvent(evtBuf, ERS7Info::MiddleBackButOffset, GETSENSOR(ERS7Info::CPCSensorBackMiddle)/150,"BkMdBut");
+	 	chkEvent(evtBuf, ERS7Info::RearBackButOffset,   GETSENSOR(ERS7Info::CPCSensorBackRear)/150,  "BkRrBut");
+	 	chkEvent(evtBuf, ERS7Info::WirelessSwOffset,GETSENSOR(ERS7Info::CPCSwitchWireless),  "WirelessSw");
 
 		// Get IR distance sensor
 		sensors[ERS7Info::NearIRDistOffset] = GETSENSOR(ERS7Info::CPCSensorNearPSD) / 1000.0f;
@@ -280,6 +298,9 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 
 	unsigned int dif=curtime-lastSensorUpdateTime;
 	lastSensorUpdateTime=curtime;
+	for(unsigned int i=0; i<evtBuf.size(); i++)
+		er->postEvent(evtBuf[i]);
+	//we don't delete the events in evtBuf - we're handing them off to erouter, which will delete them itself
 	er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif);
 }
 
@@ -358,20 +379,20 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
 
 #endif //PLATFORM_APERIOS
 
-void WorldState::chkEvent(EventRouter* er, unsigned int sid, float newval, const char* name) {
+void WorldState::chkEvent(std::vector<EventBase*>& evtBuf, unsigned int sid, float newval, const char* name) {
 	if(newval>=0.1) { //now on
 		if(buttons[sid]<0.1) { //was off: activation
-			er->postEvent(EventBase::buttonEGID,sid,EventBase::activateETID,0,name,newval);
+			evtBuf.push_back(new EventBase(EventBase::buttonEGID,sid,EventBase::activateETID,0,name,newval));
 			button_times[sid]=curtime;
 		} else if(alwaysGenerateStatus || buttons[sid]!=newval) { //already on - always or change? : status
 			unsigned int dur=curtime-button_times[sid];
-			er->postEvent(EventBase::buttonEGID,sid,EventBase::statusETID,dur,name,newval);
+			evtBuf.push_back(new EventBase(EventBase::buttonEGID,sid,EventBase::statusETID,dur,name,newval));
 		}
 	} else { //now off
 		if(buttons[sid]>=0.1) { //was on: deactivation
 			unsigned int dur=curtime-button_times[sid];
 			button_times[sid]=0;
-			er->postEvent(EventBase::buttonEGID,sid,EventBase::deactivateETID,dur,name,0);
+			evtBuf.push_back(new EventBase(EventBase::buttonEGID,sid,EventBase::deactivateETID,dur,name,0));
 		}
 	}
 	//update value
@@ -383,8 +404,8 @@ void WorldState::chkEvent(EventRouter* er, unsigned int sid, float newval, const
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.22 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.24 $
  * $State: Exp $
- * $Date: 2004/01/19 20:36:48 $
+ * $Date: 2004/05/08 03:03:32 $
  */
