@@ -14,8 +14,10 @@
 #include "Events/EventBase.h"
 #include "Shared/Profiler.h"
 #include <math.h>
+#include <vector>
 
 class EventRouter;
+class EventBase;
 
 //The following SourceIDs are for events created by WorldState's event generators
 
@@ -103,7 +105,9 @@ namespace PowerSourceID {
  * WorldState takes power and sensor updates from the system and
  * maintains the last known values in its member fields.  It throws
  * events when some of these values change, listed in the
- * ButtonSourceID, SensorSourceID, and PowerSourceID namespaces.
+ * SensorSourceID, PowerSourceID namespaces, and the ButtonOffset_t
+ * enumeration for your robot model's info
+ * namespace. (e.g. ERS210Info::ButtonOffset_t)
  *
  * Status events for buttons only generated if the
  * WorldState::alwaysGenerateStatus flag is turned on, otherwise, by
@@ -124,9 +128,9 @@ public:
 	float pids[NumPIDJoints][3];   //!< current PID settings (same ordering as the #outputs)
 	float pidduties[NumPIDJoints]; //!< duty cycles - -1 means the motor is trying to move full power in negative direction, 1 means full power in positive direction, in practice, these values stay rather small - 0.15 is significant force. (same ordering as the #outputs)
 	
-	float vel_x; //!< the current, egocentric rate of forward locomotion
-	float vel_y; //!< the current, egocentric rate of sideways (leftward is positive) locomotion
-	float vel_a; //!< the current, egocentric rate of rotational (counterclockwise is positive) locomotion
+	float vel_x; //!< the current, egocentric rate of forward locomotion, mm/second
+	float vel_y; //!< the current, egocentric rate of sideways (leftward is positive) locomotion, mm/second
+	float vel_a; //!< the current, egocentric rate of rotational (counterclockwise is positive) locomotion, radian/second
 	unsigned int vel_time; //!< the time at which we began moving along the current velocity vector
 
 	unsigned int robotStatus;       //!< bitmask, see OPENR/OPower.h
@@ -167,7 +171,7 @@ protected:
 	unsigned int curtime; //!< set by read(OSensorFrameVectorData& sensor, EventRouter* er) for chkEvent() so each call doesn't have to
 
 	//! Tests to see if the button status has changed and post events as needed
-	void chkEvent(EventRouter* er, unsigned int off, float newval, const char* name);
+	void chkEvent(std::vector<EventBase*>& evtBuf, unsigned int off, float newval, const char* name);
 
 	//! sets the names of the flags that will be generating events
 	/*! note that this function does not actually do the event posting,
@@ -210,10 +214,10 @@ extern WorldState * state; //!< the global state object, is a shared memory regi
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/07/27 14:36:50 $
  */
 
 #endif
