@@ -27,12 +27,9 @@ SoundManager::InitAccess(OSubject* subj) {
 
 //!@todo this does one more copy than it really needs to
 SoundManager::Snd_ID
-SoundManager::LoadFile(const char* name) {
-	if(name==NULL || name[0]=='\0')
-		return invalid_Snd_ID;
+SoundManager::LoadFile(std::string const &name) {
 	AutoLock autolock(lock,ProcessID::getID());
-	char tmp[MAX_NAME_LEN];
-	const char* path=makePath(name,tmp);
+	std::string path(config->sound.makePath(name));
 	Snd_ID id=lookupPath(path);
 	if(id!=invalid_Snd_ID) {
 		//		cout << "add reference to pre-existing" << endl;
@@ -40,12 +37,12 @@ SoundManager::LoadFile(const char* name) {
 	} else {
 		//		cout << "load new file" << endl;
 		struct stat buf;
-		if(stat(path,&buf)==-1) {
-			cout << "SoundManager::LoadFile(): Sound file not found " << path << endl;
+		if(stat(path.c_str(),&buf)==-1) {
+			cout << "SoundManager::LoadFile(): Sound file not found " << name << endl;
 			return invalid_Snd_ID;
 		}
 		byte * sndbuf=new byte[buf.st_size];
-		std::ifstream file(path);
+		std::ifstream file(path.c_str());
 		file.read(reinterpret_cast<char*>(sndbuf),buf.st_size);
 		WAV wav;
 		WAVError error = wav.Set(sndbuf);
@@ -59,7 +56,7 @@ SoundManager::LoadFile(const char* name) {
 		}
 		id=LoadBuffer(reinterpret_cast<char*>(wav.GetDataStart()),wav.GetDataEnd()-wav.GetDataStart());
 		delete [] sndbuf;
-		strncpy(sndlist[id].name,path,MAX_NAME_LEN);
+		strncpy(sndlist[id].name,path.c_str(),MAX_NAME_LEN);
 	}
 	return id;
 }
@@ -103,11 +100,9 @@ SoundManager::LoadBuffer(const char buf[], unsigned int len) {
 }
 	
 void
-SoundManager::ReleaseFile(const char* name) {
-	if(name==NULL || name[0]=='\0')
-		return;
+SoundManager::ReleaseFile(std::string const &name) {
 	AutoLock autolock(lock,ProcessID::getID());
-	Release(lookup(name));
+	Release(lookupPath(name));
 }
 
 void
@@ -140,8 +135,8 @@ SoundManager::Release(Snd_ID id) {
 }
 
 SoundManager::Play_ID
-SoundManager::PlayFile(const char* name) {
-	if(playlist.size()>=playlist_t::MAX_ENTRIES || name==NULL || name[0]=='\0')
+SoundManager::PlayFile(std::string const &name) {
+  if(playlist.size()>=playlist_t::MAX_ENTRIES)
 		return invalid_Play_ID;	
 	AutoLock autolock(lock,ProcessID::getID());
 	Snd_ID sndid=LoadFile(name);
@@ -198,8 +193,8 @@ SoundManager::Play(Snd_ID id) {
 }
 	
 SoundManager::Play_ID
-SoundManager::ChainFile(Play_ID base, const char * next) {
-	if(base==invalid_Play_ID || next==NULL || next[0]=='\0')
+SoundManager::ChainFile(Play_ID base, std::string const &next) {
+       if(base==invalid_Play_ID)
 		return base;
 	Play_ID orig=base;
 	while(playlist[base].next_id!=invalid_Play_ID)
@@ -545,31 +540,14 @@ SoundManager::initRegion(unsigned int size) {
 }
 
 SoundManager::Snd_ID 
-SoundManager::lookup(const char* name) const {
-	char tmp[MAX_NAME_LEN];
-	return lookupPath(makePath(name,tmp));
-}
-SoundManager::Snd_ID 
-SoundManager::lookupPath(const char* path) const {
+SoundManager::lookupPath(std::string const &name) const {
+        std::string const path(config->sound.makePath(name));
 	for(sndlist_t::index_t it=sndlist.begin(); it!=sndlist.end(); it=sndlist.next(it))
-		if(strncasecmp(path,sndlist[it].name,MAX_NAME_LEN)==0)
+		if(strncasecmp(path.c_str(),sndlist[it].name,MAX_NAME_LEN)==0)
 			return it;
 	return invalid_Snd_ID;
 }
 
-const char*
-SoundManager::makePath(const char* name, char tmp[MAX_NAME_LEN]) {
-	const char* path=name;
-	if(name[0]!='/') {
-		path=tmp;
-		strncpy(tmp,config->sound.root.c_str(),MAX_NAME_LEN);
-		strncat(tmp,"/",MAX_NAME_LEN);
-		strncat(tmp,name,MAX_NAME_LEN);
-	}
-	//	cout << name << " is " << path << endl;
-	return path;
-}
-
 void
 SoundManager::selectChannels(std::vector<Play_ID>& mix) {
 	unsigned int selected=0;
@@ -687,11 +665,11 @@ SoundManager::PlayState::PlayState()
  * @brief Implements SoundManager, which provides sound effects and caching services, as well as mixing buffers for the SoundPlay process
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.14 $
- * $State: Rel $
- * $Date: 2003/07/25 20:18:08 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.15 $
+ * $State: Exp $
+ * $Date: 2004/10/08 00:07:25 $
  */
 
 
