@@ -87,7 +87,7 @@ public:
 	 * @param name can be either a full path, or a partial path relative to Config::sound_config::root
 	 * @return ID number for future references (can also use name)
 	 * The sound data will be cached until ReleaseFile() or Release() is called a matching number of times*/
-	Snd_ID LoadFile(const char* name);
+	Snd_ID LoadFile(std::string const &name);
 
 	//!loads raw samples from a buffer (assumes matches Config::sound_config settings)
 	/*!The sound data will be cached until Release() is called a matching number of times.\n
@@ -95,7 +95,7 @@ public:
 	Snd_ID LoadBuffer(const char buf[], unsigned int len);
 	
 	//!Marks the sound buffer to be released after the last play command completes (or right now if not being played)
-	void ReleaseFile(const char* name);
+	void ReleaseFile(std::string const &name);
 
 	//!Marks the sound buffer to be released after the last play command completes (or right now if not being played)
 	void Release(Snd_ID id);
@@ -105,7 +105,7 @@ public:
 	 * @param name can be either a full path, or a partial path relative to Config::sound_config::root
 	 * @return ID number for future references
 	 * The sound data will not be cached after done playing unless a call to LoadFile is made*/
-	Play_ID PlayFile(const char* name);
+	Play_ID PlayFile(std::string const &name);
 
 	//!loads raw samples from a buffer (assumes buffer matches Config::sound_config settings)
 	/*!The sound data will be released after done playing*/
@@ -118,7 +118,7 @@ public:
 	/*!if you chain more than once to the same base, the new buffers are appended
 	 * to the end of the chain - the new buffer doesn't replace the current chain
 	 * @return @a base - just for convenience of multiple calls*/
-	Play_ID ChainFile(Play_ID base, const char* next);
+	Play_ID ChainFile(Play_ID base, std::string const &next);
 
 	//!allows automatic queuing of sounds - good for dynamic sound sources!
 	/*!if you chain more than once to the same base, the new buffers are appended
@@ -173,13 +173,8 @@ protected:
 	//!Sets up a shared region to hold a sound - rounds to nearest page size
 	static RCRegion* initRegion(unsigned int size);
 
-	//!Looks to see if @a name matches any of the sounds in sndlist
-	Snd_ID lookup(const char* name) const;
-	//!Looks to see if @a name matches any of the sounds in sndlist (assumes is absolute path)
-	Snd_ID lookupPath(const char* path) const;
-
-	//!prepends config.sound.root to the name if necessary
-	static const char* makePath(const char* name, char tmp[MAX_NAME_LEN]);
+	//!Looks to see if @a name matches any of the sounds in sndlist (converts to absolute path if not already)
+	Snd_ID lookupPath(std::string const &name) const;
 
 	//!selects which of the channels are actually to be mixed together, depending on queue_mode
 	void selectChannels(std::vector<Play_ID>& mix);
@@ -250,11 +245,11 @@ extern SoundManager * sndman;
  * @brief Describes SoundManager, which provides sound effects and caching services, as well as mixing buffers for the SoundPlay process
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.11 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/10/08 00:07:25 $
  */
 
 #endif
