@@ -1,5 +1,5 @@
 //
-// Copyright 2002 Sony Corporation 
+// Copyright 2002,2003 Sony Corporation 
 //
 // Permission to use, copy, modify, and redistribute this software for
 // non-commercial use is hereby granted.
@@ -12,9 +12,21 @@
 #include <sys/stat.h>
 #include <sys/unistd.h>
 #include <OPENR/OSyslog.h>
+#include <OPENR/ODebug.h>
 #include <OPENR/OCalendarTime.h>
 #include <stdlib.h>
 #include "FtpDTP.h"
+#include <stdio.h>
+
+Port 
+FtpDTP::SetIP(IPAddress ip)
+{
+    connectIP = ip;
+    connectPort = FTP_PASV_DATA_PORT + (int)continuation;
+    passive = true;
+    Listen();
+    return connectPort;
+}
 
 bool
 FtpDTP::SetPort(char* ipport)
@@ -55,6 +67,7 @@ FtpDTP::SetPort(char* ipport)
     OSYSDEBUG(("FtpDTP::Port():Set IP:%x Port:%d\n", ip, port));
     connectIP   = (IPAddress)ip;
     connectPort = (Port)port;
+    passive = false;
     return true;
 }
 
@@ -83,7 +96,14 @@ FtpDTP::Store(char* filename)
 
     strncpy(ftpFile, filename, MAX_STRING_LENGTH);
 
-    Connect();
+    if (passive) {
+        if (connection.state == CONNECTION_CONNECTED) {
+            connection.recvSize = 0;
+            Receive();
+        }
+    } else {
+        Connect();
+    }
     return true;
 }
 
@@ -112,7 +132,13 @@ FtpDTP::Retrieve(char* filename)
 
     strncpy(ftpFile, filename, MAX_STRING_LENGTH);
 
-    Connect();
+    if (passive) {
+        if (connection.state == CONNECTION_CONNECTED) {
+            RetrieveSend();
+        }
+    } else {
+        Connect();
+    }
     return true;
 }
 
@@ -122,7 +148,6 @@ FtpDTP::RetrieveSend()
     if (dataType == FTP_DATA_A) {
        connection.recvSize
            = fread(connection.recvData, 1, FTP_BUFFER_SIZE / 2, fp);
-
        if (FTP_BUFFER_SIZE / 2 > connection.recvSize) {
             byte *cur_r = connection.recvData;
             byte *cur_s = connection.sendData;
@@ -163,7 +188,6 @@ FtpDTP::RetrieveSend()
     } else {
         connection.sendSize
             = fread(connection.sendData, 1, FTP_BUFFER_SIZE, fp);
-
         if (FTP_BUFFER_SIZE > connection.sendSize) {
             fclose(fp);
             method = FTP_METHOD_NOOP;
@@ -189,8 +213,7 @@ FtpDTP::RenameFrom(char *file)
     DirNorm(tmp);
 
     if (!strncmp(tmp, ftpHome, strlen(ftpHome))) {
-        //CHANGE_ET renamed fp to tfp to avoid shadow
-        FILE *tfp = fopen(tmp, "r");
+			FILE *tfp = fopen(tmp, "r"); //CHANGE_ET rename fp to tfp to avoid shadowed variable
         if (tfp != NULL) {
             strncpy(ftpFile, tmp, MAX_STRING_LENGTH);
             fclose(tfp);
@@ -230,6 +253,7 @@ bool
 FtpDTP::List(char* dir)
 {
     char tmp[MAX_STRING_LENGTH * 2];
+    total = true;
 
     if ((dir[0] != '\0') && (dir[0] == '/')) {
         sprintf(tmp, "%s/", dir);
@@ -242,14 +266,23 @@ FtpDTP::List(char* dir)
         listLong = false;
     }
 
+    listLong = true;
 
     DirNorm(tmp);
 
     if (!strncmp(tmp, ftpHome, strlen(ftpHome))) {
-        if ((dirp = opendir(tmp))) {
+			if ((dirp = opendir(tmp))) { //CHANGE_ET extra parenthesis to clarify assignment used as truth value
             method = FTP_METHOD_LIST;
             strcpy(ftpFile, tmp);
-            Connect();
+            if (passive) {
+                if (connection.state == CONNECTION_CONNECTED) {
+                    if (!ListSend()) {
+                        Close();
+                    }
+                }
+            } else {
+                Connect();
+            }
             return true;
         }
     }
@@ -262,30 +295,39 @@ FtpDTP::ListSend()
     dirent *entry;
     char tmp[MAX_STRING_LENGTH];
 
+    if (total) {
+        sprintf((char *)connection.sendData,
+                "total %d\r\n", 0);
+        connection.sendSize = strlen((char *)connection.sendData);
+        Send();
+        total = false;
+        return true;
+    }
+
     entry = readdir(dirp);
     if (entry) {
         struct stat statbuf;
         sprintf(tmp, "%s/%s", ftpFile, entry->d_name);
         DirNorm(tmp);
         
-        stat(tmp, &statbuf);
+        stat(tmp, &statbuf); //CHANGE_ET unused variable 'ret'
         if (listLong) {
             sprintf((char *)connection.sendData,
-                    "%c%c%c%c%c%c%c%c%c%c %x %s %s %-u %s %d %d %s\r\n",
+                    "%c%c%c%c%c%c%c%c%c%c %x %s %s %-d %s %d %d %s\r\n",
                     (statbuf.st_mode & S_IFMT) == S_IFDIR ? 'd' : '-',
                     (statbuf.st_mode & S_IRUSR) ? 'r' : '-',
                     (statbuf.st_mode & S_IWUSR) ? 'w' : '-',
-                    (statbuf.st_mode & S_IXUSR) ? 'x' : '-',
-                    (statbuf.st_mode & S_IRGRP) ? 'r' : '-',
-                    (statbuf.st_mode & S_IWGRP) ? 'w' : '-',
-                    (statbuf.st_mode & S_IXGRP) ? 'x' : '-',
-                    (statbuf.st_mode & S_IROTH) ? 'r' : '-',
-                    (statbuf.st_mode & S_IWOTH) ? 'w' : '-',
-                    (statbuf.st_mode & S_IXOTH) ? 'x' : '-',
+                    (statbuf.st_mode & S_IFMT) == S_IFDIR ? 'x' : '-',
+                    (statbuf.st_mode & S_IRUSR) ? 'r' : '-',
+                    (statbuf.st_mode & S_IWUSR) ? 'w' : '-',
+                    (statbuf.st_mode & S_IFMT) == S_IFDIR ? 'x' : '-',
+                    (statbuf.st_mode & S_IRUSR) ? 'r' : '-',
+                    (statbuf.st_mode & S_IWUSR) ? 'w' : '-',
+                    (statbuf.st_mode & S_IFMT) == S_IFDIR ? 'x' : '-',
                     0,
                     "AIBO",
                     "AIBO",
-                    (unsigned int)statbuf.st_size,
+                    statbuf.st_size,
                     "May",
                     11,
                     1999,
@@ -328,7 +370,7 @@ FtpDTP::ChangeDir(char* dir)
 
     if (!strncmp(tmp, ftpHome, strlen(ftpHome))) {
         DIR* tmpdirp;
-        if ((tmpdirp = opendir(tmp))) {
+        if ((tmpdirp = opendir(tmp))) { //CHANGE_ET extra parenthesis to clarify assignment used as truth value
             closedir(tmpdirp);
             strcpy(ftpDir, tmp);
             return true;
@@ -344,9 +386,9 @@ FtpDTP::MakeDir(char* dir)
     char tmp[MAX_STRING_LENGTH * 2];
 
     if (dir[0] == '/') {
-        sprintf(tmp, "%s/", dir);
+        sprintf(tmp, "%s", dir);
     } else {
-        sprintf(tmp, "%s%s/", ftpDir, dir);
+        sprintf(tmp, "%s%s", ftpDir, dir);
     }
 
     DirNorm(tmp);
@@ -366,9 +408,9 @@ FtpDTP::RemoveDir(char* dir)
     char tmp[MAX_STRING_LENGTH * 2];
 
     if (dir[0] == '/') {
-        sprintf(tmp, "%s/", dir);
+        sprintf(tmp, "%s", dir);
     } else {
-        sprintf(tmp, "%s%s/", ftpDir, dir);
+        sprintf(tmp, "%s%s", ftpDir, dir);
     }
 
     DirNorm(tmp);
@@ -388,9 +430,9 @@ FtpDTP::Delete(char* filename)
     char tmp[MAX_STRING_LENGTH * 2];
 
     if (filename[0] == '/') {
-        sprintf(tmp, "%s/", filename);
+        sprintf(tmp, "%s", filename);
     } else {
-        sprintf(tmp, "%s%s/", ftpDir, filename);
+        sprintf(tmp, "%s%s", ftpDir, filename);
     }
 
     DirNorm(tmp);
@@ -407,8 +449,8 @@ FtpDTP::Delete(char* filename)
 void
 FtpDTP::Save(byte *data, int length, bool end)
 {
-    OSYSDEBUG(("FtpDTP::Save %d\n", length));
-    fwrite(data, length, 1, fp);
+    OSYSDEBUG(("FtpDTP::Save %d %d\n", length, end));
+    if (length) fwrite(data, length, 1, fp);
     if (end) {
         fclose(fp);
         strcpy(ftpFile, "");
@@ -425,8 +467,6 @@ FtpDTP::GetFileSize(char *name)
     } else {
         return 0;
     }
-
-    return 0;
 }
 
 void
