@@ -1,5 +1,5 @@
 //
-// Copyright 2002 Sony Corporation 
+// Copyright 2002,2003 Sony Corporation 
 //
 // Permission to use, copy, modify, and redistribute this software for
 // non-commercial use is hereby granted.
@@ -17,6 +17,7 @@
 #include "FtpConfig.h"
 #include "FtpDTP.h"
 #include "def.h"
+#include "entry.h"
 
 class FtpPI
 {
@@ -24,7 +25,7 @@ public:
     FtpPI();
     virtual ~FtpPI() {}
 
-    OStatus Initialize(const OID& myoid, const OID& ipoid,
+    OStatus Initialize(const OID& myoid, const antStackRef& ipstack,
                        void* index, OList<Passwd, MAX_LOGIN> *pass);
 
     void ListenCont  (TCPEndpointListenMsg*  listenMsg);
@@ -32,6 +33,7 @@ public:
     void ReceiveCont (TCPEndpointReceiveMsg* receiveMsg);
     void CloseCont   (TCPEndpointCloseMsg*   closeMsg);
 
+    void ListenContforDTP (TCPEndpointListenMsg*  listenMsg);
     void ConnectContforDTP(TCPEndpointConnectMsg* connectMsg);
     void SendContforDTP   (TCPEndpointSendMsg*    sendMsg);
     void ReceiveContforDTP(TCPEndpointReceiveMsg* receiveMsg);
@@ -48,17 +50,18 @@ private:
     bool RequestProcess ();
     bool CommandParser  (char **cmd, char **param);
 
-    OID            myOID;
-    OID            ipstackOID;
+    OID myOID;
+    antStackRef ipstackRef;
     void* continuation;
     TCPConnection connection;
     FTPLoginState state;
     FtpDTP ftpDTP;
+    IPAddress ipaddr;
 
     OList<Passwd, MAX_LOGIN> *passwd;
 
-		FtpPI(const FtpPI&); //!< don't call
-		FtpPI& operator=(const FtpPI&); //!< don't call
+		FtpPI(const FtpPI&); //CHANGE_ET copy constructor, don't call
+		FtpPI operator=(const FtpPI&); //CHANGE_ET assignment operator, don't call
 };
 #endif /* _FtpPI_h_DEFINED */
 
