@@ -1,6 +1,8 @@
 #include "Socket.h"
 #include <stdio.h>
-#include "Wireless.h"
+#ifdef PLATFORM_APERIOS
+#  include "Wireless.h"
+#endif
 #include "Shared/Config.h"
 #include <unistd.h>
 
@@ -77,12 +79,16 @@ Socket::flush()
 				writeData=tempData;
 				sendSize=writeSize;
 				writeSize=tempSize;
-				wireless->send(sock); 
+#ifdef PLATFORM_APERIOS
+				wireless->send(sock);
+#endif
 			}
 		} else {
 			sendData=writeData;
 			sendSize=writeSize;
+#ifdef PLATFORM_APERIOS
 			wireless->blockingSend(sock);
+#endif
 			writeSize=0;
 		}
 	}
@@ -166,9 +172,9 @@ Socket::read(byte * /*buf*/, int /*size*/)
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.16 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2004/01/14 20:45:41 $
+ * $Date: 2004/10/04 20:38:05 $
  */
 
