@@ -3,7 +3,6 @@
 #include "Behaviors/Controller.h"
 #include "Behaviors/Controls/BatteryCheckControl.h"
 #include "Behaviors/Controls/ControlBase.h"
-#include "Behaviors/Controls/PostureEditor.h"
 #include "Behaviors/Controls/HelpControl.h"
 #include "Behaviors/Controls/RebootControl.h"
 #include "Behaviors/Controls/ShutdownControl.h"
@@ -42,7 +41,7 @@ void StartupBehavior::DoStart() {
 
 	//This will "fade" in the PIDs so the joints don't jerk to full
 	//power, also looks cooler
-	pid_id=motman->addMotion(SharedObject<PIDMC>(0),MotionManager::kEmergencyPriority+2,false);
+	pid_id=motman->addPersistentMotion(SharedObject<PIDMC>(0),MotionManager::kEmergencyPriority+2);
 	//also, pause before we start fading in, PIDs take effect right
 	//away, before the emergencystop is picked up
 	erouter->addTimer(this,0,4*FrameTime*NumFrames,true);
@@ -54,13 +53,13 @@ void StartupBehavior::DoStart() {
 	//Note that if you don't want to start in estop, you should then
 	//also uncomment the line at the end of this function
 	stop->setStopped(true,false); 
-	stop_id=motman->addMotion(stop,MotionManager::kEmergencyPriority);
+	stop_id=motman->addPersistentMotion(stop,MotionManager::kEmergencyPriority);
 	
 	//This displays the current battery conditions on the console
 	BatteryCheckControl batchk;
+	//	const SharedObject<LedMC> led;
+	//	batchk.activate(motman->addPrunableMotion(led,MotionManager::kEmergencyPriority+1),NULL);
 	batchk.activate(MotionManager::invalid_MC_ID,NULL);
-	//	const SharedObject<LedMC> led; //! @todo LedMC's don't support autopruning yet, it should for uses like this
-	//	batchk.activate(motman->addMotion(led,true));
 	batchk.deactivate();
 
 	//This is what runs the menu system
@@ -86,7 +85,7 @@ void StartupBehavior::DoStart() {
 		closeMouth->setOutputCmd(mouthOffset,outputRanges[mouthOffset][MaxRange]);
 		closeMouth->setPlayTime(3500); //and hold it for another .5 seconds
 		closeMouth->setOutputCmd(mouthOffset,outputRanges[mouthOffset][MaxRange]);
-		motman->addMotion(closeMouth,MotionManager::kEmergencyPriority+1,true);
+		motman->addPrunableMotion(closeMouth,MotionManager::kEmergencyPriority+1);
 		erouter->addTimer(this,1,3250,false);
 	}
 
@@ -157,8 +156,6 @@ StartupBehavior::SetupMenus() {
 		SetupTekkotsuMon();
 		SetupStatusReports();
 		SetupFileAccess();
-		SetupWalkEdit();
-		addItem(new PostureEditor());
 		SetupVision();
 		addItem(new ControlBase("Shutdown?","Confirms decision to reboot or shut down"));
 		startSubMenu();
