@@ -6,6 +6,7 @@
 #include "Behaviors/Controls/FreeMemReportControl.h"
 #include "Behaviors/Controls/ProfilerCheckControl.h"
 #include "Behaviors/Controls/EventLogger.h"
+#include "Behaviors/Controls/SensorObserverControl.h"
 
 ControlBase*
 StartupBehavior::SetupStatusReports() {
@@ -15,6 +16,7 @@ StartupBehavior::SetupStatusReports() {
 		addItem(new BatteryCheckControl());
 		addItem(new ProfilerCheckControl());
 		addItem(new EventLogger());
+		addItem(new SensorObserverControl());
 		FreeMemReportControl * tmp=new FreeMemReportControl();
 		tmp->DoStart();
 		addItem(tmp);
