@@ -9,10 +9,10 @@
  * @author PA Gov. School for the Sciences 2003 Team Project - Motion group: Haoqian Chen, Yantian Martin, Jon Stahlman (creators)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/02/26 01:03:00 $
+ * $Date: 2004/05/14 07:18:19 $
  */
 
 #include "StartupBehavior.h"
@@ -45,6 +45,8 @@ StartupBehavior::SetupWalkEdit() {
 			addItem(new ValueEditControl<double>("Hop",&walker->getWalkMC()->getWP().hop));
 			addItem(new ValueEditControl<double>("Sway",&walker->getWalkMC()->getWP().sway));
 			addItem(new ValueEditControl<long>("Period",&walker->getWalkMC()->getWP().period));
+			addItem(new ValueEditControl<long>("Use Diff Drive",&walker->getWalkMC()->getWP().useDiffDrive));
+			addItem(new ValueEditControl<float>("Sag",&walker->getWalkMC()->getWP().sag));
 		}
 		endSubMenu();
 
